@@ -58,7 +58,7 @@ typedef void (*_GLUfuncptr)();
 #include <wx/tokenzr.h>
 
 static const char* USAGE = R"""(
-Usage: opencpn-cli [options] <command> [arguments]
+Usage: opencpn-glutil [options] <command> [arguments]
 
 Options:
 
