@@ -35,15 +35,18 @@
 
 enum { ID_MUI_MENU = 21500 };
 
+/**
+ * Enumeration for animation types
+ */
 enum {
-  CO_ANIMATION_LINEAR = 0,
-  CO_ANIMATION_QUADRATIC,
-  CO_ANIMATION_CUBIC,
-  CO_ANIMATION_CUBIC_BOUNCE_IN,
-  CO_ANIMATION_CUBIC_BACK_IN,
-  CO_ANIMATION_CUBIC_REVERSE,
-  CO_PULL,
-  CO_PUSH
+  CO_ANIMATION_LINEAR = 0,       ///< Linear animation
+  CO_ANIMATION_QUADRATIC,        ///< Quadratic animation
+  CO_ANIMATION_CUBIC,            ///< Cubic animation
+  CO_ANIMATION_CUBIC_BOUNCE_IN,  ///< Cubic animation with bounce-in effect
+  CO_ANIMATION_CUBIC_BACK_IN,    ///< Cubic animation with back-in effect
+  CO_ANIMATION_CUBIC_REVERSE,    ///< Reversed cubic animation
+  CO_PULL,                       ///< Pull animation
+  CO_PUSH                        ///< Push animation
 };
 
 class MyFrame;
@@ -52,9 +55,11 @@ class MUIButton;
 class MUITextButton;
 class CanvasOptions;
 
-//----------------------------------------------------------------------------
-// MUIBar
-//----------------------------------------------------------------------------
+/**
+ * Modern User Interface Control Bar for OpenCPN. Provides a customizable
+ * control bar with various buttons and options for interacting with the chart
+ * canvas in OpenCPN.
+ */
 class MUIBar : public wxEvtHandler {
 public:
   MUIBar();
