@@ -30,6 +30,7 @@
 #include "model/ocpn_types.h"
 #include "color_types.h"
 #include "LLRegion.h"
+#include "viewport.h"
 
 //----------------------------------------------------------------------------
 //  Forward Declarations
@@ -110,10 +111,11 @@ public:
   float lnp;
 };
 
-// ----------------------------------------------------------------------------
-// ChartBase
-// ----------------------------------------------------------------------------
-
+/**
+ * Base class for all chart types. Defines the interface and common
+ * functionality for all chart types in OpenCPN. Provides methods for
+ * initialization, rendering, and querying chart properties and data.
+ */
 class ChartBase {
 public:
   ChartBase();
