@@ -115,13 +115,8 @@
 //          Some Memory Leak Detection Code
 //------------------------------------------------------------------------------
 
-#ifdef __MSVC__
-#ifdef _DEBUG
-#define _CRTDBG_MAP_ALLOC
-#include <crtdbg.h>
-#define DEBUG_NEW new (_NORMAL_BLOCK, __FILE__, __LINE__)
-#define new DEBUG_NEW
-#endif
+#ifdef __VISUALC__
+#include <wx/msw/msvcrt.h>
 #endif
 
 //----------------------------------------------------------------------------
