@@ -17,7 +17,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
  **************************************************************************/
 
-/** \file gui_lib.h General purpose GUI support. */
+/**
+ *  \file
+ *  General purpose GUI support.
+ */
 
 #ifndef GUI_LIB_H__
 #define GUI_LIB_H__
@@ -36,7 +39,35 @@ public:
   CopyableText(wxWindow* parent, const char* text);
 };
 
+/**
+ * Retrieves a font from FontMgr, optionally scaled for physical readability.
+ *
+ * Returns a font configured for a specific UI context, scaling based on
+ * system settings and preserving readability across different displays.
+ *
+ * @param item UI element identifier (e.g., "AISTargetAlert", "StatusBar")
+ * @param default_size Optional base font size in points. 0 uses platform
+ * default.
+ *
+ * @return Pointer to a dynamically scaled wxFont
+ *
+ * @note Font is managed by OpenCPN's central font cache
+ * @note Pointer is shared and should not be deleted by caller
+ */
 wxFont* GetOCPNScaledFont(wxString item, int default_size = 0);
+/**
+ * Retrieves a font optimized for touch and high-resolution interfaces.
+ *
+ * Generates a font specifically tuned for responsive and touch-friendly
+ * interfaces, with more aggressive scaling than standard font methods.
+ *
+ * @param item UI element identifier (e.g., "AISTargetAlert", "StatusBar")
+ *
+ * @return A wxFont object scaled for touch and high-resolution interfaces
+ *
+ * @note Ensures minimum physical font size for improved readability
+ * @note Particularly suitable for toolbars, buttons, and touch controls
+ */
 wxFont GetOCPNGUIScaledFont(wxString item);
 
 extern int OCPNMessageBox(wxWindow* parent, const wxString& message,
@@ -78,32 +109,6 @@ public:
   DECLARE_EVENT_TABLE()
 };
 
-class OCPN_TimedHTMLMessageDialog : public wxDialog {
-public:
-  OCPN_TimedHTMLMessageDialog(wxWindow* parent, const wxString& message,
-                              const wxString& caption = wxMessageBoxCaptionStr,
-                              int tSeconds = -1, long style = wxOK | wxCENTRE,
-                              bool bFixedFont = false,
-                              const wxPoint& pos = wxDefaultPosition);
-
-  void OnYes(wxCommandEvent& event);
-  void OnNo(wxCommandEvent& event);
-  void OnCancel(wxCommandEvent& event);
-  void OnClose(wxCloseEvent& event);
-  void OnTimer(wxTimerEvent& evt);
-  void RecalculateSize(void);
-  void OnHtmlLinkClicked(wxHtmlLinkEvent& event) {
-    wxLaunchDefaultBrowser(event.GetLinkInfo().GetHref());
-  }
-
-private:
-  int m_style;
-  wxTimer m_timer;
-  wxHtmlWindow* msgWindow;
-
-  DECLARE_EVENT_TABLE()
-};
-
 //----------------------------------------------------------------------------
 // Generic Auto Timed Window
 // Belongs to the creator, not deleted automatically on application close
@@ -131,20 +136,4 @@ private:
   DECLARE_EVENT_TABLE()
 };
 
-//-----------------------------------------------------------------------
-//          Dummy Text Control for global key events
-//-----------------------------------------------------------------------
-class DummyTextCtrl : public wxTextCtrl {
-public:
-  DummyTextCtrl(wxWindow* parent, wxWindowID id);
-  void OnChar(wxKeyEvent& event);
-  void OnMouseEvent(wxMouseEvent& event);
-
-  wxTimer m_MouseWheelTimer;
-  int m_mouse_wheel_oneshot;
-  int m_last_wheel_dir;
-
-  DECLARE_EVENT_TABLE()
-};
-
 #endif  // GUI_LIB_H__
