@@ -70,6 +70,7 @@
 #include "model/cutil.h"
 #include "model/logger.h"
 #include "model/ocpn_utils.h"
+#include "model/plugin_cache.h"
 #include "model/plugin_paths.h"
 #include "model/select.h"
 
@@ -577,6 +578,13 @@ void OCPNPlatform::Initialize_2(void) {
     ::wxMkdir(GRIBDir);
   }
 
+  wxString VDRDir = GetPrivateDataDir();
+  if (VDRDir.Last() != sep) VDRDir.Append(sep);
+  VDRDir.Append("VDR");
+  if (!::wxDirExists(VDRDir)) {
+    ::wxMkdir(VDRDir);
+  }
+
   // Set the default Import/Export directory for A11+
   if (g_Android_SDK_Version >= 30) {
     if (!g_gpx_path.StartsWith(androidGetDocumentsDirectory())) {
@@ -1459,19 +1467,29 @@ void OCPNPlatform::SetUpgradeOptions(wxString vNew, wxString vOld) {
     // Will get set to e.g. "/storage/emulated/0" later
     pInit_Chart_Dir->Clear();
 
+    // A few popular requests,
+    // which will take effect on next App startup.
     pConfig->SetPath(_T ( "/Settings/WMM" ));
     pConfig->Write(_T ( "ShowIcon" ), true);
     pConfig->Write(_T ( "ShowLiveIcon" ), true);
+
+    pConfig->SetPath("/Canvas/CanvasConfig1");
+    pConfig->Write(_T ( "canvasENCShowVisibleSectorLights" ), 0);
+
+    // Manage plugins
+    // Clear the cache, allowing deprecation of obsolete plugins
+    ocpn::cache_clear();
+
+    //  Remove any problematic plugins, so preparing for upgraded versions
+    //  Todo:  Scrub this list from time to time
+
+    //  VersionCode 123 (August, 2025)
+    AndroidRemoveSystemFile(
+        "/data/user/0/org.opencpn.opencpn/manPlug/libchartscale_pi.so");
   }
 
   // Set track default color to magenta
   g_colourTrackLineColour.Set(197, 69, 195);
-
-  // This is ugly hack
-  // TODO
-  // pConfig->SetPath( _T ( "/PlugIns/liboesenc_pi.so" ) );
-  // pConfig->Write( _T ( "bEnabled" ), true );
-
 #endif
 
   // Check for upgrade....
