@@ -34,10 +34,19 @@
 #include "model/navutil_base.h"
 #include "navutil.h"
 #include "ocpn_plugin.h"
+#include "print_dialog.h"
 #include "routemanagerdialog.h"
-#include "routeprintout.h"
+#include "route_printout.h"
 #include "RoutePropDlgImpl.h"
 #include "tcmgr.h"
+#include "model/navobj_db.h"
+
+#define UTCINPUT 0  //!< Format date/time in UTC.
+#define LTINPUT \
+  1  //!< Format date/time using timezone configured in the operating system.
+#define LMTINPUT 2  //!< Format date/time using the remote location LMT time.
+/** Format date/time according to global OpenCPN settings. */
+#define GLOBAL_SETTINGS_INPUT 3
 
 #define ID_RCLK_MENU_COPY_TEXT 7013
 #define ID_RCLK_MENU_EDIT_WP 7014
@@ -175,6 +184,23 @@ static double getLMT(double ut, double lon) {
     return (t + 24.);
 }
 
+/**
+ * Return the date/time timezone setting for the given selection.
+ */
+static wxString getDatetimeTimezoneSelector(int selection) {
+  switch (selection) {
+    case UTCINPUT:
+      return "UTC";
+    case LTINPUT:
+      return "Local Time";
+    case LMTINPUT:
+      return "LMT";
+    case GLOBAL_SETTINGS_INPUT:
+    default:
+      return wxEmptyString;
+  }
+}
+
 static int getDaylightStatus(double lat, double lon, wxDateTime utcDateTime) {
   if (fabs(lat) > 60.) return (0);
   int y = utcDateTime.GetYear();
@@ -232,7 +258,7 @@ RoutePropDlgImpl::RoutePropDlgImpl(wxWindow* parent, wxWindowID id,
                                    const wxString& title, const wxPoint& pos,
                                    const wxSize& size, long style)
     : RoutePropDlg(parent, id, title, pos, size, style) {
-  m_pRoute = NULL;
+  m_pRoute = nullptr;
 
   SetColorScheme(global_color_scheme);
 
@@ -281,7 +307,7 @@ RoutePropDlgImpl* RoutePropDlgImpl::getInstance(wxWindow* parent) {
 }
 
 void RoutePropDlgImpl::OnActivate(wxActivateEvent& event) {
-  wxFrame* pWin = wxDynamicCast(event.GetEventObject(), wxFrame);
+  auto pWin = dynamic_cast<wxFrame*>(event.GetEventObject());
   long int style = pWin->GetWindowStyle();
   if (event.GetActive())
     pWin->SetWindowStyle(style | wxSTAY_ON_TOP);
@@ -338,11 +364,13 @@ void RoutePropDlgImpl::UpdatePoints() {
                               pnode->GetData()->GetLongitude(), gLat, gLon,
                               &bearing, &distance);
       if (m_pRoute->m_PlannedDeparture.IsValid()) {
+        DateTimeFormatOptions opts =
+            DateTimeFormatOptions()
+                .SetTimezone(getDatetimeTimezoneSelector(m_tz_selection))
+                .SetLongitude(pnode->GetData()->m_lon);
         eta = wxString::Format(
-            "Start: %s", toUsrDateTime(m_pRoute->m_PlannedDeparture,
-                                       m_tz_selection, pnode->GetData()->m_lon)
-                             .Format(ETA_FORMAT_STR)
-                             .c_str());
+            "Start: %s", ocpn::toUsrDateTimeFormat(
+                             m_pRoute->m_PlannedDeparture.FromUTC(), opts));
         eta.Append(wxString::Format(
             _T(" (%s)"),
             GetDaylightString(getDaylightStatus(pnode->GetData()->m_lat,
@@ -362,9 +390,12 @@ void RoutePropDlgImpl::UpdatePoints() {
       distance = pnode->GetData()->GetDistance();
       bearing = pnode->GetData()->GetCourse();
       if (pnode->GetData()->GetETA().IsValid()) {
-        eta = toUsrDateTime(pnode->GetData()->GetETA(), m_tz_selection,
-                            pnode->GetData()->m_lon)
-                  .Format(ETA_FORMAT_STR);
+        DateTimeFormatOptions opts =
+            DateTimeFormatOptions()
+                .SetTimezone(getDatetimeTimezoneSelector(m_tz_selection))
+                .SetLongitude(pnode->GetData()->m_lon);
+        eta = ocpn::toUsrDateTimeFormat(pnode->GetData()->GetETA().FromUTC(),
+                                        opts);
         eta.Append(wxString::Format(
             _T(" (%s)"),
             GetDaylightString(getDaylightStatus(pnode->GetData()->m_lat,
@@ -386,12 +417,14 @@ void RoutePropDlgImpl::UpdatePoints() {
     wxString etd;
     if (pnode->GetData()->GetManualETD().IsValid()) {
       // GetManualETD() returns time in UTC, always. So use it as such.
-      etd = toUsrDateTime(pnode->GetData()->GetManualETD(),
-                          0 /*m_tz_selection*/, pnode->GetData()->m_lon)
-                .Format(ETA_FORMAT_STR);
-      if (pnode->GetData()->GetManualETD().IsValid() &&
-          pnode->GetData()->GetETA().IsValid() &&
-          pnode->GetData()->GetManualETD() < pnode->GetData()->GetETA()) {
+      RoutePoint* rt = pnode->GetData();
+      DateTimeFormatOptions opts =
+          DateTimeFormatOptions()
+              .SetTimezone(getDatetimeTimezoneSelector(m_tz_selection))
+              .SetLongitude(rt->m_lon);
+      etd = ocpn::toUsrDateTimeFormat(rt->GetManualETD().FromUTC(), opts);
+      if (rt->GetManualETD().IsValid() && rt->GetETA().IsValid() &&
+          rt->GetManualETD() < rt->GetETA()) {
         etd.Prepend(
             _T("!! "));  // Manually entered ETD is before we arrive here!
       }
@@ -449,56 +482,6 @@ void RoutePropDlgImpl::UpdatePoints() {
   }
 }
 
-wxDateTime RoutePropDlgImpl::toUsrDateTime(const wxDateTime ts,
-                                           const int format, const double lon) {
-  if (!ts.IsValid()) {
-    return ts;
-  }
-  wxDateTime dt;
-  switch (m_tz_selection) {
-    case 2:  // LMT@Location
-      if (std::isnan(lon)) {
-        dt = wxInvalidDateTime;
-      } else {
-        dt =
-            ts.Add(wxTimeSpan(wxTimeSpan(0, 0, wxLongLong(lon * 3600. / 15.))));
-      }
-      break;
-    case 1:  // Local@PC
-      dt = ts.FromUTC();
-      break;
-    case 0:  // UTC
-      dt = ts;
-      break;
-  }
-  return dt;
-}
-
-wxDateTime RoutePropDlgImpl::fromUsrDateTime(const wxDateTime ts,
-                                             const int format,
-                                             const double lon) {
-  if (!ts.IsValid()) {
-    return ts;
-  }
-  wxDateTime dt;
-  switch (m_tz_selection) {
-    case 2:  // LMT@Location
-      if (std::isnan(lon)) {
-        dt = wxInvalidDateTime;
-      } else {
-        dt = ts.Subtract(wxTimeSpan(0, 0, wxLongLong(lon * 3600. / 15.)));
-      }
-      break;
-    case 1:  // Local@PC
-      dt = ts.ToUTC();
-      break;
-    case 0:  // UTC
-      dt = ts;
-      break;
-  }
-  return dt;
-}
-
 void RoutePropDlgImpl::SetRouteAndUpdate(Route* pR, bool only_points) {
   if (NULL == pR) return;
 
@@ -521,15 +504,16 @@ void RoutePropDlgImpl::SetRouteAndUpdate(Route* pR, bool only_points) {
 
   //  Fetch any config file values
   if (!only_points) {
-    if (!pR->m_PlannedDeparture.IsValid())
+    if (!pR->m_PlannedDeparture.IsValid()) {
       pR->m_PlannedDeparture = wxDateTime::Now().ToUTC();
+    }
 
-    m_tz_selection = 1;  // Local PC time by default
+    m_tz_selection = GLOBAL_SETTINGS_INPUT;  // Honor global setting by default
     if (pR != m_pRoute) {
       if (pR->m_TimeDisplayFormat == RTE_TIME_DISP_UTC)
-        m_tz_selection = 0;
+        m_tz_selection = UTCINPUT;
       else if (pR->m_TimeDisplayFormat == RTE_TIME_DISP_LOCAL)
-        m_tz_selection = 2;
+        m_tz_selection = LMTINPUT;
       m_pEnroutePoint = NULL;
       m_bStartNow = false;
     }
@@ -544,15 +528,14 @@ void RoutePropDlgImpl::SetRouteAndUpdate(Route* pR, bool only_points) {
       for (unsigned int i = 0; i < kids.GetCount(); i++) {
         wxWindowListNode* node = kids.Item(i);
         wxWindow* win = node->GetData();
-        if (win->IsKindOf(CLASSINFO(wxHyperlinkCtrl))) {
-          ((wxHyperlinkCtrl*)win)
-              ->Disconnect(
-                  wxEVT_COMMAND_HYPERLINK,
-                  wxHyperlinkEventHandler(RoutePropDlgImpl::OnHyperlinkClick));
-          ((wxHyperlinkCtrl*)win)
-              ->Disconnect(
-                  wxEVT_RIGHT_DOWN,
-                  wxMouseEventHandler(RoutePropDlgImpl::HyperlinkContextMenu));
+        auto link_win = dynamic_cast<wxHyperlinkCtrl*>(win);
+        if (link_win) {
+          link_win->Disconnect(
+              wxEVT_COMMAND_HYPERLINK,
+              wxHyperlinkEventHandler(RoutePropDlgImpl::OnHyperlinkClick));
+          link_win->Disconnect(
+              wxEVT_RIGHT_DOWN,
+              wxMouseEventHandler(RoutePropDlgImpl::HyperlinkContextMenu));
           win->Destroy();
         }
       }
@@ -599,21 +582,17 @@ void RoutePropDlgImpl::SetRouteAndUpdate(Route* pR, bool only_points) {
     m_tcName->SetFocus();
     if (m_pRoute->m_PlannedDeparture.IsValid() &&
         m_pRoute->m_PlannedDeparture.GetValue() > 0) {
-      m_dpDepartureDate->SetValue(
-          toUsrDateTime(m_pRoute->m_PlannedDeparture, m_tz_selection,
-                        m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon)
-              .GetDateOnly());
-      m_tpDepartureTime->SetValue(toUsrDateTime(
+      wxDateTime t = toUsrDateTime(
           m_pRoute->m_PlannedDeparture, m_tz_selection,
-          m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon));
+          m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon);
+      m_dpDepartureDate->SetValue(t.GetDateOnly());
+      m_tpDepartureTime->SetValue(t);
     } else {
-      m_dpDepartureDate->SetValue(
-          toUsrDateTime(wxDateTime::Now(), m_tz_selection,
-                        m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon)
-              .GetDateOnly());
-      m_tpDepartureTime->SetValue(toUsrDateTime(
-          wxDateTime::Now(), m_tz_selection,
-          m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon));
+      wxDateTime t = toUsrDateTime(
+          wxDateTime::Now().ToUTC(), m_tz_selection,
+          m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon);
+      m_dpDepartureDate->SetValue(t.GetDateOnly());
+      m_tpDepartureTime->SetValue(t);
     }
   }
 
@@ -666,14 +645,13 @@ void RoutePropDlgImpl::DepartureTimeOnTimeChanged(wxDateEvent& event) {
 }
 
 void RoutePropDlgImpl::TimezoneOnChoice(wxCommandEvent& event) {
+  if (!m_pRoute) return;
   m_tz_selection = m_choiceTimezone->GetSelection();
-  m_dpDepartureDate->SetValue(
+  wxDateTime t =
       toUsrDateTime(m_pRoute->m_PlannedDeparture, m_tz_selection,
-                    m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon)
-          .GetDateOnly());
-  m_tpDepartureTime->SetValue(
-      toUsrDateTime(m_pRoute->m_PlannedDeparture, m_tz_selection,
-                    m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon));
+                    m_pRoute->pRoutePointList->GetFirst()->GetData()->m_lon);
+  m_dpDepartureDate->SetValue(t.GetDateOnly());
+  m_tpDepartureTime->SetValue(t);
   UpdatePoints();
   event.Skip();
 }
@@ -719,7 +697,7 @@ void RoutePropDlgImpl::WaypointsOnDataViewListCtrlItemEditingDone(
 void RoutePropDlgImpl::WaypointsOnDataViewListCtrlItemValueChanged(
     wxDataViewEvent& event) {
 #if wxCHECK_VERSION(3, 1, 2)
-  // wx 3.0.x crashes in the bellow code
+  // wx 3.0.x crashes in the below code
   if (!m_pRoute) return;
   wxDataViewModel* const model = event.GetModel();
   wxVariant value;
@@ -875,7 +853,8 @@ void RoutePropDlgImpl::OnRoutePropMenuSelected(wxCommandEvent& event) {
         pSelect->AddAllSelectableRouteSegments(m_pRoute);
         pSelect->AddAllSelectableRoutePoints(m_pRoute);
 
-        pConfig->UpdateRoute(m_pRoute);
+        // pConfig->UpdateRoute(m_pRoute);
+        NavObj_dB::GetInstance().UpdateRoute(m_pRoute);
 
         m_pRoute->FinalizeForRendering();
         m_pRoute->UpdateSegmentDistances();
@@ -904,6 +883,7 @@ void RoutePropDlgImpl::OnRoutePropMenuSelected(wxCommandEvent& event) {
             static_cast<int>(reinterpret_cast<long long>(selection.GetID())));
 
         g_pRouteMan->RemovePointFromRoute(pRP, m_pRoute, 0);
+
         gFrame->InvalidateAllGL();
         UpdatePoints();
       }
@@ -914,8 +894,7 @@ void RoutePropDlgImpl::OnRoutePropMenuSelected(wxCommandEvent& event) {
       RoutePoint* pRP = m_pRoute->GetPoint(
           static_cast<int>(reinterpret_cast<long long>(selection.GetID())));
 
-      RouteManagerDialog::WptShowPropertiesDialog(std::vector<RoutePoint*>{pRP},
-                                                  this);
+      RouteManagerDialog::WptShowPropertiesDialog(pRP, this);
       break;
     }
   }
@@ -934,14 +913,14 @@ void RoutePropDlgImpl::WaypointsOnDataViewListCtrlItemContextMenu(
     wxMenuItem* delItem =
         new wxMenuItem(&menu, ID_RCLK_MENU_DELETE, _("Remove Selected"));
 #ifdef __ANDROID__
-    wxFont* pf = OCPNGetFont(_T("Menu"), 0);
+    wxFont* pf = OCPNGetFont(_("Menu"));
     editItem->SetFont(*pf);
     moveUpItem->SetFont(*pf);
     moveDownItem->SetFont(*pf);
     delItem->SetFont(*pf);
 #endif
 #if defined(__WXMSW__)
-    wxFont* pf = GetOCPNScaledFont(_T("Menu"));
+    wxFont* pf = GetOCPNScaledFont(_("Menu"));
     editItem->SetFont(*pf);
     moveUpItem->SetFont(*pf);
     moveDownItem->SetFont(*pf);
@@ -971,7 +950,7 @@ void RoutePropDlgImpl::WaypointsOnDataViewListCtrlItemContextMenu(
       new wxMenuItem(&menu, ID_RCLK_MENU_COPY_TEXT, _("&Copy all as text"));
 
 #if defined(__WXMSW__)
-  wxFont* qFont = GetOCPNScaledFont(_T("Menu"));
+  wxFont* qFont = GetOCPNScaledFont(_("Menu"));
   copyItem->SetFont(*qFont);
 #endif
 
@@ -986,7 +965,7 @@ void RoutePropDlgImpl::ResetChanges() {
   if (!m_pRoute) return;
   m_pRoute->m_PlannedSpeed = m_OrigRoute.m_PlannedSpeed;
   m_pRoute->m_PlannedDeparture = m_OrigRoute.m_PlannedDeparture;
-  m_pRoute = NULL;
+  m_pRoute = nullptr;
 }
 
 void RoutePropDlgImpl::SaveChanges() {
@@ -1005,19 +984,24 @@ void RoutePropDlgImpl::SaveChanges() {
         (wxPenStyle)::StyleValues[m_choiceStyle->GetSelection()];
     m_pRoute->m_width = ::WidthValues[m_choiceWidth->GetSelection()];
     switch (m_tz_selection) {
-      case 1:
+      case LTINPUT:
         m_pRoute->m_TimeDisplayFormat = RTE_TIME_DISP_PC;
         break;
-      case 2:
+      case LMTINPUT:
         m_pRoute->m_TimeDisplayFormat = RTE_TIME_DISP_LOCAL;
         break;
+      case GLOBAL_SETTINGS_INPUT:
+        m_pRoute->m_TimeDisplayFormat = RTE_TIME_DISP_GLOBAL;
+        break;
+      case UTCINPUT:
       default:
         m_pRoute->m_TimeDisplayFormat = RTE_TIME_DISP_UTC;
     }
 
-    pConfig->UpdateRoute(m_pRoute);
+    // pConfig->UpdateRoute(m_pRoute);
+    NavObj_dB::GetInstance().UpdateRoute(m_pRoute);
     pConfig->UpdateSettings();
-    m_pRoute = NULL;
+    m_pRoute = nullptr;
   }
 }
 
@@ -1050,16 +1034,19 @@ void RoutePropDlgImpl::SplitOnButtonClick(wxCommandEvent& event) {
     m_pTail->CloneRoute(m_pRoute, nSelected, m_pRoute->GetnPoints(), _("_B"),
                         true);
     pRouteList->Append(m_pHead);
-    pConfig->AddNewRoute(m_pHead);
+    // pConfig->AddNewRoute(m_pHead);
+    NavObj_dB::GetInstance().InsertRoute(m_pHead);
 
     pRouteList->Append(m_pTail);
-    pConfig->AddNewRoute(m_pTail);
+    // pConfig->AddNewRoute(m_pTail);
+    NavObj_dB::GetInstance().InsertRoute(m_pTail);
 
-    pConfig->DeleteConfigRoute(m_pRoute);
+    // pConfig->DeleteConfigRoute(m_pRoute);
+    NavObj_dB::GetInstance().DeleteRoute(m_pRoute);
 
     pSelect->DeleteAllSelectableRoutePoints(m_pRoute);
     pSelect->DeleteAllSelectableRouteSegments(m_pRoute);
-    g_pRouteMan->DeleteRoute(m_pRoute, NavObjectChanges::getInstance());
+    g_pRouteMan->DeleteRoute(m_pRoute);
     pSelect->AddAllSelectableRouteSegments(m_pTail);
     pSelect->AddAllSelectableRoutePoints(m_pTail);
     pSelect->AddAllSelectableRouteSegments(m_pHead);
@@ -1074,12 +1061,20 @@ void RoutePropDlgImpl::SplitOnButtonClick(wxCommandEvent& event) {
 }
 
 void RoutePropDlgImpl::PrintOnButtonClick(wxCommandEvent& event) {
-  RoutePrintSelection* dlg = new RoutePrintSelection(this, m_pRoute);
-  DimeControl(dlg);
-  dlg->ShowWindowModalThenDo([this, dlg](int retcode) {
-    if (retcode == wxID_OK) {
-    }
-  });
+  static std::set<int> s_options;  // keep selected options
+  RoutePrintDialog dlg(this, s_options);
+  int result = dlg.ShowModal();
+
+  if (result == wxID_OK) {
+    dlg.GetSelected(s_options);
+    RoutePrintout printout(m_pRoute, s_options, m_tz_selection);
+    auto& printer = PrintDialog::GetInstance();
+    printer.Initialize(wxPORTRAIT);
+    printer.EnablePageNumbers(true);
+    printer.Print(this, &printout);
+  }
+
+  event.Skip();
 }
 
 void RoutePropDlgImpl::ExtendOnButtonClick(wxCommandEvent& event) {
@@ -1102,7 +1097,8 @@ void RoutePropDlgImpl::ExtendOnButtonClick(wxCommandEvent& event) {
 bool RoutePropDlgImpl::IsThisRouteExtendable() {
   m_pExtendRoute = NULL;
   m_pExtendPoint = NULL;
-  if (m_pRoute->m_bRtIsActive || m_pRoute->m_bIsInLayer) return false;
+  if (!m_pRoute || m_pRoute->m_bRtIsActive || m_pRoute->m_bIsInLayer)
+    return false;
 
   RoutePoint* pLastPoint = m_pRoute->GetLastPoint();
   wxArrayPtrVoid* pEditRouteArray;
@@ -1180,23 +1176,27 @@ wxString RoutePropDlgImpl::MakeTideInfo(wxString stationName, double lat,
   wxString tide_form = wxEmptyString;
 
   if (ev == 1) {
-    tide_form.Append(_T("LW: "));
+    tide_form.Append(_T("LW: "));  // High Water
   } else if (ev == 2) {
-    tide_form.Append(_T("HW: "));
+    tide_form.Append(_T("HW: "));  // Low Water
   } else if (ev == 0) {
     tide_form.Append(_("Unavailable: "));
   }
 
   int offset =
       ptcmgr->GetStationTimeOffset((IDX_entry*)ptcmgr->GetIDX_entry(stationID));
-
-  tide_form.Append(
-      toUsrDateTime(dtm, m_tz_selection, lon).Format(ETA_FORMAT_STR));
+  DateTimeFormatOptions opts =
+      DateTimeFormatOptions()
+          .SetTimezone(getDatetimeTimezoneSelector(m_tz_selection))
+          .SetLongitude(lon);
+  wxString tideDateTime = ocpn::toUsrDateTimeFormat(dtm.FromUTC(), opts);
+  tide_form.Append(tideDateTime);
   dtm.Add(wxTimeSpan(0, offset, 0));
-  tide_form.Append(wxString::Format(_T(" (") + _("Local") + _T(": %s) @ %s"),
-                                    dtm.Format(ETA_FORMAT_STR),
-                                    stationName.c_str()));
-
+  // Write next tide event using station timezone, formatted with explicit HH:MM
+  // offset from UTC.
+  tide_form.Append(wxString::Format(" (" + _("Local") + ": %s%+03d:%02d) @ %s",
+                                    dtm.Format("%a %x %H:%M:%S"), (offset / 60),
+                                    abs(offset) % 60, stationName.c_str()));
   return tide_form;
 }
 
@@ -1260,15 +1260,14 @@ void RoutePropDlgImpl::ItemDeleteOnMenuSelection(wxCommandEvent& event) {
     wxWindowListNode* node = kids.Item(i);
     wxWindow* win = node->GetData();
 
-    if (win->IsKindOf(CLASSINFO(wxHyperlinkCtrl))) {
-      ((wxHyperlinkCtrl*)win)
-          ->Disconnect(
-              wxEVT_COMMAND_HYPERLINK,
-              wxHyperlinkEventHandler(RoutePropDlgImpl::OnHyperlinkClick));
-      ((wxHyperlinkCtrl*)win)
-          ->Disconnect(
-              wxEVT_RIGHT_DOWN,
-              wxMouseEventHandler(RoutePropDlgImpl::HyperlinkContextMenu));
+    auto link_win = dynamic_cast<wxHyperlinkCtrl*>(win);
+    if (link_win) {
+      link_win->Disconnect(
+          wxEVT_COMMAND_HYPERLINK,
+          wxHyperlinkEventHandler(RoutePropDlgImpl::OnHyperlinkClick));
+      link_win->Disconnect(
+          wxEVT_RIGHT_DOWN,
+          wxMouseEventHandler(RoutePropDlgImpl::HyperlinkContextMenu));
       win->Destroy();
     }
   }
