@@ -1,10 +1,4 @@
-/******************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:  About Dialog
- * Author:   David Register
- *
- ***************************************************************************
+/**************************************************************************
  *   Copyright (C) 2010-2023 by David S. Register                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,12 +15,16 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
- ***************************************************************************
- *
- *
- *
+ **************************************************************************/
+
+/**
+ * \file
+ * Implement about.h
  */
 
+#include <fstream>
+#include <sstream>
+
 #include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
@@ -47,15 +45,15 @@
 #include "OCPNPlatform.h"
 #include "FontMgr.h"
 #include "navutil.h"
-#ifdef __OCPN__ANDROID__
+#include "std_filesystem.h"
+#ifdef __ANDROID__
 #include "androidUTIL.h"
 #endif
 #include "ocpn_frame.h"
 
 extern OCPNPlatform* g_Platform;
-extern MyFrame* gFrame;
 extern ocpnStyle::StyleManager* g_StyleManager;
-extern about* g_pAboutDlgLegacy;
+extern About* g_pAboutDlgLegacy;
 extern bool g_bresponsive;
 
 wxString OpenCPNVersion("\n      Version ");
@@ -65,129 +63,38 @@ wxString OpenCPNVersion("\n      Version ");
 // clang-format off
 
 const wxString AboutText =
-    wxT("<br>OpenCPN<br>")
-    wxT("(c) 2000-2024  The OpenCPN Authors<br><br>");
+    "<br>OpenCPN<br>"
+    "(c) 2000-2024  The OpenCPN Authors<br><br>";
 
 const wxString OpenCPNInfo =
-    wxT("<br><br>")
-    wxT("OpenCPN is a Free Software project, built by sailors. ")
-    wxT("It is freely available to download and distribute ")
-    wxT("without charge at opencpn.org.<br><br>")
-    wxT("If you use OpenCPN, please consider contributing ")
-    wxT("or donating funds to the project.<br><br>")
-    wxT("For more information, visit http://opencpn.org<br><br>");
+    "<br><br>"
+    "OpenCPN is a Free Software project, built by sailors. "
+    "It is freely available to download and distribute "
+    "without charge at opencpn.org.<br><br>"
+    "If you use OpenCPN, please consider contributing "
+    "or donating funds to the project.<br><br>"
+    "For more information, visit http://opencpn.org<br><br>";
 
 const wxString OpenCPNInfoAlt =
-    wxT("<br><br>")
-    wxT("OpenCPN is a Free Software project, built by sailors.")
-    wxT("The complete source code and many other resources ")
-    wxT("are freely available for your download and use, ")
-    wxT("subject to applicable License agreements.")
-    wxT("<br><br>")
-    wxT("For more information, visit http://opencpn.org<br><br>");
-
-
-const wxString AuthorText =
-    wxT("   David S Register\n")
-    wxT("      OpenCPN Lead Developer\n\n")
-    wxT("    Pavel Kalian\n")
-    wxT("      Packaging and PlugIn development\n\n")
-    wxT("    Håkan Svensson\n")
-    wxT("      Comms and Plugin integration\n\n")
-    wxT("    Rick Gleason\n")
-    wxT("      Plugin adaptation and maintenance\n\n")
-    wxT("    Sean D'Epagnier\n")
-    wxT("      OpenGL Architecture\n\n")
-    wxT("    J.P. Joubert\n")
-    wxT("      GRIB PlugIn enhancements\n\n")
-    wxT("    Thomas Höckne\n")
-    wxT("      Documentation and Wiki support\n\n")
-    wxT("    Didier Gautheron\n")
-    wxT("      App debugging and optimization\n\n")
-    wxT("    Wiets Wilken\n")
-    wxT("      Extended vector Icon implementation\n\n")
-    wxT("    Gene Seybold\n")
-    wxT("      Extended vector Icon design\n\n")
-    wxT("    Caesar Schinas\n")
-    wxT("      User Interface and OS X improvements\n\n")
-    wxT("    Jesper Weissglas\n")
-    wxT("      Vector Chart Rendering\n\n")
-    wxT("    Jean-Eudes Onfray\n")
-    wxT("      Dashboard and Dialog enhancements\n\n")
-    wxT("    Kathleen Boswell\n")
-    wxT("      Icon design\n\n")
-    wxT("    Flavius Bindea\n")
-    wxT("      CM93 Offset and AIS enhancements\n\n")
-    wxT("    Gunther Pilz\n")
-    wxT("      Windows Installer enhancements\n\n")
-    wxT("    Alan Bleasby\n")
-    wxT("      Garmin jeeps module\n\n")
-    wxT("    Piotr Carlson\n")
-    wxT("      General usability enhancements\n\n")
-    wxT("    Anders Lund\n")
-    wxT("      RouteManagerDialog\n\n")
-    wxT("    Gordon Mau\n")
-    wxT("      OpenCPN Documentation\n\n")
-    wxT("    Tim Francis\n")
-    wxT("      OpenCPN Documentation\n\n")
-    wxT("    Mark A Sikes\n")
-    wxT("      OpenCPN CoDeveloper\n\n")
-    wxT("    Thomas Haller\n")
-    wxT("      GPX Import/Export Implementation\n\n")
-    wxT("    Will Kamp\n")
-    wxT("      Toolbar Icon design\n\n")
-    wxT("    Richard Smith\n")
-    wxT("      OpenCPN CoDeveloper, MacOSX\n\n")
-    wxT("    David Herring\n")
-    wxT("      OpenCPN CoDeveloper, MacOSX\n\n")
-    wxT("    Philip Lange\n")
-    wxT("      OpenCPN Documentation\n\n")
-    wxT("    Ron Kuris\n")
-    wxT("      wxWidgets Support\n\n")
-    wxT("    Julian Smart, Robert Roebling et al\n")
-    wxT("      wxWidgets Authors\n\n")
-    wxT("    Sylvain Duclos\n")
-    wxT("      S52 Presentation Library code\n\n")
-    wxT("    Manish P. Pagey\n")
-    wxT("      Serial Port Library\n\n")
-    wxT("    David Flater\n")
-    wxT("      XTIDE tide and current code\n\n")
-    wxT("    Frank Warmerdam\n")
-    wxT("      GDAL Class Library\n\n")
-    wxT("    Mike Higgins\n")
-    wxT("      BSB Chart Format Detail\n\n")
-    wxT("    Samuel R. Blackburn\n")
-    wxT("      NMEA0183 Class Library\n\n")
-    wxT("    Atul Narkhede\n")
-    wxT("      Polygon Graphics utilities\n\n")
-    wxT("    Jan C. Depner\n")
-    wxT("      WVS Chart Library\n\n")
-    wxT("    Stuart Cunningham, et al\n")
-    wxT("      BSB Chart Georeferencing Algorithms\n\n")
-    wxT("    John F. Waers\n")
-    wxT("      UTM Conversion Algorithms\n\n")
-    wxT("    Carsten Tschach\n")
-    wxT("      UTM Conversion Algorithms\n\n")
-    wxT("    Ed Williams\n")
-    wxT("      Great Circle Formulary\n\n")
-    wxT("    Philippe Bekaert\n")
-    wxT("      CIE->RGB Color Conversion Matrix\n\n")
-    wxT("    Robert Lipe\n")
-    wxT("      Garmin USB GPS Interface\n");
+    "<br><br>"
+    "OpenCPN is a Free Software project, built by sailors."
+    "The complete source code and many other resources "
+    "are freely available for your download and use, "
+    "subject to applicable License agreements."
+    "<br><br>"
+    "For more information, visit http://opencpn.org<br><br>";
 
 // clang-format on
 
-IMPLEMENT_DYNAMIC_CLASS(about, wxDialog)
-
-BEGIN_EVENT_TABLE(about, wxDialog)
-EVT_BUTTON(xID_OK, about::OnXidOkClick)
-EVT_BUTTON(ID_DONATE, about::OnDonateClick)
-EVT_BUTTON(ID_COPYINI, about::OnCopyClick)
-EVT_BUTTON(ID_COPYLOG, about::OnCopyClick)
-EVT_CLOSE(about::OnClose)
+BEGIN_EVENT_TABLE(About, wxDialog)
+EVT_BUTTON(xID_OK, About::OnXidOkClick)
+EVT_BUTTON(ID_DONATE, About::OnDonateClick)
+EVT_BUTTON(ID_COPYINI, About::OnCopyClick)
+EVT_BUTTON(ID_COPYLOG, About::OnCopyClick)
+EVT_CLOSE(About::OnClose)
 END_EVENT_TABLE()
 
-about::about(void)
+About::About(void)
     : m_DataLocn(wxEmptyString), m_parent(NULL), m_btips_loaded(FALSE) {
   pAboutHTMLCtl = NULL;
   pLicenseHTMLCtl = NULL;
@@ -195,10 +102,14 @@ about::about(void)
   m_blicensePageSet = false;
 }
 
-about::about(wxWindow* parent, wxString Data_Locn, wxWindowID id,
+About::About(wxWindow* parent, wxString Data_Locn,
+             std::function<void()> launch_local_help, wxWindowID id,
              const wxString& caption, const wxPoint& pos, const wxSize& size,
              long style)
-    : m_DataLocn(Data_Locn), m_parent(parent), m_btips_loaded(FALSE) {
+    : m_DataLocn(Data_Locn),
+      m_parent(parent),
+      m_launch_local_help(launch_local_help),
+      m_btips_loaded(FALSE) {
   pAboutHTMLCtl = NULL;
   pLicenseHTMLCtl = NULL;
   pAuthorHTMLCtl = NULL;
@@ -212,7 +123,7 @@ about::about(wxWindow* parent, wxString Data_Locn, wxWindowID id,
   Create(parent, id, caption, pos, size, style);
 }
 
-bool about::Create(wxWindow* parent, wxWindowID id, const wxString& caption,
+bool About::Create(wxWindow* parent, wxWindowID id, const wxString& caption,
                    const wxPoint& pos, const wxSize& size, long style) {
   m_parent = parent;
 #ifdef __WXOSX__
@@ -233,7 +144,7 @@ bool about::Create(wxWindow* parent, wxWindowID id, const wxString& caption,
   return TRUE;
 }
 
-void about::SetColorScheme(void) {
+void About::SetColorScheme(void) {
   DimeControl(this);
   wxColor bg = GetBackgroundColour();
   if (pAboutHTMLCtl) pAboutHTMLCtl->SetBackgroundColour(bg);
@@ -256,14 +167,14 @@ void about::SetColorScheme(void) {
 #endif
 }
 
-void about::Populate(void) {
+void About::Populate(void) {
   wxColor bg = GetBackgroundColour();
   wxColor fg = wxColour(0, 0, 0);
 
   // The HTML Header
   wxString aboutText = wxString::Format(
-      _T( "<html><body bgcolor=#%02x%02x%02x><font color=#%02x%02x%02x>" ),
-      bg.Red(), bg.Blue(), bg.Green(), fg.Red(), fg.Blue(), fg.Green());
+      "<html><body bgcolor=#%02x%02x%02x><font color=#%02x%02x%02x>", bg.Red(),
+      bg.Blue(), bg.Green(), fg.Red(), fg.Blue(), fg.Green());
 
   wxFont* dFont = FontMgr::Get().GetFont(_("Dialog"));
 
@@ -279,13 +190,13 @@ void about::Populate(void) {
   wxString face = dFont->GetFaceName();
   pAboutHTMLCtl->SetFonts(face, face, sizes);
 
-  if (wxFONTSTYLE_ITALIC == dFont->GetStyle()) aboutText.Append(_T("<i>"));
+  if (wxFONTSTYLE_ITALIC == dFont->GetStyle()) aboutText.Append("<i>");
 
 #ifdef __OCPN__ANDROID__
   wxString msg;
-  msg.Printf(_T(" [%d]"), androidGetVersionCode());
+  msg.Printf(" [%d]", androidGetVersionCode());
   wxString OpenCPNVersionAndroid =
-      _T("OpenCPN for Android Version ") + androidGetVersionName() + msg;
+      "OpenCPN for Android Version " + androidGetVersionName() + msg;
 
   aboutText.Append(AboutText + OpenCPNVersionAndroid + OpenCPNInfoAlt);
 #else
@@ -293,42 +204,32 @@ void about::Populate(void) {
 #endif
 
   // Show where the log file is going to be placed
-  wxString log_string = _T("Logfile location: ") + g_Platform->GetLogFileName();
-  log_string.Replace(_T("/"),
-                     _T("/ "));  // allow line breaks, in a cheap way...
+  wxString log_string = "Logfile location: " + g_Platform->GetLogFileName();
+  log_string.Replace("/", "/ ");  // allow line breaks, in a cheap way...
 
   aboutText.Append(log_string);
 
   // Show where the config file is going to be placed
   wxString config_string =
-      _T("<br><br>Config file location: ") + g_Platform->GetConfigFileName();
-  config_string.Replace(_T("/"),
-                        _T("/ "));  // allow line breaks, in a cheap way...
+      "<br><br>Config file location: " + g_Platform->GetConfigFileName();
+  config_string.Replace("/", "/ ");  // allow line breaks, in a cheap way...
   aboutText.Append(config_string);
 
-  if (wxFONTSTYLE_ITALIC == dFont->GetStyle()) aboutText.Append(_T("</i>"));
+  if (wxFONTSTYLE_ITALIC == dFont->GetStyle()) aboutText.Append("</i>");
 
   // The HTML Footer
-  aboutText.Append(_T("</font></body></html>"));
+  aboutText.Append("</font></body></html>");
 
   pAboutHTMLCtl->SetPage(aboutText);
 
   /// Authors page
   // The HTML Header
-  wxString authorText = wxString::Format(
-      _T( "<html><body bgcolor=#%02x%02x%02x><font color=#%02x%02x%02x>" ),
-      bg.Red(), bg.Blue(), bg.Green(), fg.Red(), fg.Blue(), fg.Green());
-
-  pAuthorHTMLCtl->SetFonts(face, face, sizes);
-
-  wxString authorFixText = AuthorText;
-  authorFixText.Replace(_T("\n"), _T("<br>"));
-  authorText.Append(authorFixText);
-
-  // The HTML Footer
-  authorText.Append(_T("</font></body></html>"));
-
-  pAuthorHTMLCtl->SetPage(authorFixText);
+  //
+  fs::path data_path(g_Platform->GetSharedDataDir().ToStdString());
+  std::ifstream istream(data_path / "Authors.html");
+  std::stringstream ss;
+  ss << istream.rdbuf();
+  pAuthorHTMLCtl->SetPage(ss.str());
 
   /// License page
   // Deferred....
@@ -368,7 +269,7 @@ void about::Populate(void) {
   SetColorScheme();
 }
 
-void about::RecalculateSize(void) {
+void About::RecalculateSize(void) {
   //  Make an estimate of the dialog size, without scrollbars showing
 
   wxSize esize;
@@ -389,7 +290,7 @@ void about::RecalculateSize(void) {
   Centre();
 }
 
-void about::CreateControls(void) {
+void About::CreateControls(void) {
   //  Set the nominal vertical size of the embedded controls
 
   wxBoxSizer* mainSizer = new wxBoxSizer(wxVERTICAL);
@@ -413,7 +314,7 @@ void about::CreateControls(void) {
   mainSizer->Add(buttonSizer, 0, wxALL, 0);
 
   wxButton* donateButton = new wxBitmapButton(
-      this, ID_DONATE, g_StyleManager->GetCurrentStyle()->GetIcon(_T("donate")),
+      this, ID_DONATE, g_StyleManager->GetCurrentStyle()->GetIcon("donate"),
       wxDefaultPosition, wxDefaultSize, 0);
 
   buttonSizer->Add(
@@ -434,7 +335,7 @@ void about::CreateControls(void) {
                              wxSize(-1, -1), wxNB_TOP);
 
   pNotebook->Connect(wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED,
-                     wxNotebookEventHandler(about::OnNBPageChange), NULL, this);
+                     wxNotebookEventHandler(About::OnNBPageChange), NULL, this);
 
   pNotebook->InheritAttributes();
   mainSizer->Add(pNotebook, 1,
@@ -505,11 +406,11 @@ void about::CreateControls(void) {
   mainSizer->Add(closeButton, 0, wxALIGN_RIGHT | wxALL, 5);
 }
 
-void about::OnNBPageChange(wxNotebookEvent& event) {
+void About::OnNBPageChange(wxNotebookEvent& event) {
   unsigned int i = event.GetSelection();
 
   if (i == 3) {
-    g_Platform->LaunchLocalHelp();
+    m_launch_local_help();
     pNotebook->ChangeSelection(0);
   }
 
@@ -535,31 +436,31 @@ void about::OnNBPageChange(wxNotebookEvent& event) {
 
     // The HTML Header
     wxString licenseText = wxString::Format(
-        _T( "<html><body bgcolor=#%02x%02x%02x><font color=#%02x%02x%02x>" ),
+        "<html><body bgcolor=#%02x%02x%02x><font color=#%02x%02x%02x>",
         bg.Red(), bg.Blue(), bg.Green(), fg.Red(), fg.Blue(), fg.Green());
 
     pLicenseHTMLCtl->SetFonts(face, face, sizes);
 
-    wxTextFile license_filea(m_DataLocn + _T("license.txt"));
+    wxTextFile license_filea(m_DataLocn + "license.txt");
     if (license_filea.Open()) {
       for (wxString str = license_filea.GetFirstLine(); !license_filea.Eof();
            str = license_filea.GetNextLine())
-        licenseText.Append(str + _T("<br>"));
+        licenseText.Append(str + "<br>");
       license_filea.Close();
     } else {
-      wxLogMessage(_T("Could not open License file: ") + m_DataLocn);
+      wxLogMessage("Could not open License file: " + m_DataLocn);
     }
 
     wxString suppLicense = g_Platform->GetSupplementalLicenseString();
 
-    wxStringTokenizer st(suppLicense, _T("\n"), wxTOKEN_DEFAULT);
+    wxStringTokenizer st(suppLicense, "\n", wxTOKEN_DEFAULT);
     while (st.HasMoreTokens()) {
       wxString s1 = st.GetNextToken();
-      licenseText.Append(s1 + _T("<br>"));
+      licenseText.Append(s1 + "<br>");
     }
 
     // The HTML Footer
-    licenseText.Append(_T("</font></body></html>"));
+    licenseText.Append("</font></body></html>");
 
     pLicenseHTMLCtl->SetPage(licenseText);
 
@@ -570,22 +471,22 @@ void about::OnNBPageChange(wxNotebookEvent& event) {
   }
 }
 
-void about::OnXidOkClick(wxCommandEvent& event) { Close(); }
+void About::OnXidOkClick(wxCommandEvent& event) { Close(); }
 
-void about::OnClose(wxCloseEvent& event) {
+void About::OnClose(wxCloseEvent& event) {
 #ifdef __WXGTK__
-  gFrame->Raise();
+  wxTheApp->GetTopWindow()->Raise();
 #endif
   Destroy();
   g_pAboutDlgLegacy = NULL;
 }
 
-void about::OnDonateClick(wxCommandEvent& event) {
+void About::OnDonateClick(wxCommandEvent& event) {
   wxLaunchDefaultBrowser(
-      _T("https://sourceforge.net/donate/index.php?group_id=180842"));
+      "https://sourceforge.net/donate/index.php?group_id=180842");
 }
 
-void about::OnCopyClick(wxCommandEvent& event) {
+void About::OnCopyClick(wxCommandEvent& event) {
   wxString filename = event.GetId() == ID_COPYLOG
                           ? g_Platform->GetLogFileName()
                           : g_Platform->GetConfigFileName();
@@ -593,7 +494,7 @@ void about::OnCopyClick(wxCommandEvent& event) {
   wxFFile file(filename);
 
   if (!file.IsOpened()) {
-    wxLogMessage(_T("Failed to open file for Copy to Clipboard."));
+    wxLogMessage("Failed to open file for Copy to Clipboard.");
     return;
   }
 
@@ -609,10 +510,10 @@ void about::OnCopyClick(wxCommandEvent& event) {
 
   if (event.GetId() == ID_COPYLOG) {
     wxString lastLogs = fileContent;
-    int pos = lastLogs.Find(_T("________"));
+    int pos = lastLogs.Find("________");
     while (pos != wxNOT_FOUND && lastLogs.Length() > 65000) {
       lastLogs = lastLogs.Right(lastLogs.Length() - pos - 8);
-      pos = lastLogs.Find(_T("________"));
+      pos = lastLogs.Find("________");
     }
     fileContent = lastLogs;
   }
@@ -620,10 +521,10 @@ void about::OnCopyClick(wxCommandEvent& event) {
   ::wxBeginBusyCursor();
   if (wxTheClipboard->Open()) {
     if (!wxTheClipboard->SetData(new wxTextDataObject(fileContent)))
-      wxLogMessage(_T("wxTheClipboard->Open() failed."));
+      wxLogMessage("wxTheClipboard->Open() failed.");
     wxTheClipboard->Close();
   } else {
-    wxLogMessage(_T("wxTheClipboard->Open() failed."));
+    wxLogMessage("wxTheClipboard->Open() failed.");
   }
   ::wxEndBusyCursor();
 }
