@@ -17,7 +17,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
  **************************************************************************/
 
-/** \file gui_lib.cpp Implements gui_lib.h */
+/**
+ *  \file
+ *  Implements gui_lib.h
+ */
 
 #include <wx/artprov.h>
 #include <wx/dialog.h>
@@ -272,132 +275,7 @@ void TimedMessageBox::OnTimer(wxTimerEvent& evt) {
   if (dlg) dlg->EndModal(wxID_CANCEL);
 }
 
-BEGIN_EVENT_TABLE(OCPN_TimedHTMLMessageDialog, wxDialog)
-EVT_BUTTON(wxID_YES, OCPN_TimedHTMLMessageDialog::OnYes)
-EVT_BUTTON(wxID_NO, OCPN_TimedHTMLMessageDialog::OnNo)
-EVT_BUTTON(wxID_CANCEL, OCPN_TimedHTMLMessageDialog::OnCancel)
-EVT_CLOSE(OCPN_TimedHTMLMessageDialog::OnClose)
-EVT_TIMER(-1, OCPN_TimedHTMLMessageDialog::OnTimer)
-EVT_HTML_LINK_CLICKED(wxID_ANY, OCPN_TimedHTMLMessageDialog::OnHtmlLinkClicked)
-END_EVENT_TABLE()
-
-OCPN_TimedHTMLMessageDialog::OCPN_TimedHTMLMessageDialog(
-    wxWindow* parent, const wxString& message, const wxString& caption,
-    int tSeconds, long style, bool bFixedFont, const wxPoint& pos)
-    : wxDialog(parent, wxID_ANY, caption, pos, wxDefaultSize,
-               wxDEFAULT_DIALOG_STYLE | wxSTAY_ON_TOP) {
-  m_style = style;
-  if (bFixedFont) {
-    wxFont* dFont = GetOCPNScaledFont_PlugIn(_("Dialog"));
-    double font_size = dFont->GetPointSize();
-    wxFont* qFont =
-        wxTheFontList->FindOrCreateFont(font_size, wxFONTFAMILY_TELETYPE,
-                                        dFont->GetStyle(), dFont->GetWeight());
-    SetFont(*qFont);
-  }
-
-  wxBoxSizer* topsizer = new wxBoxSizer(wxVERTICAL);
-
-  msgWindow = new wxHtmlWindow(this, wxID_ANY, wxDefaultPosition, wxDefaultSize,
-                               wxHW_SCROLLBAR_AUTO | wxHW_NO_SELECTION);
-  msgWindow->SetBorders(30);
-
-  topsizer->Add(msgWindow, 1, wxEXPAND, 5);
-
-  wxString html;
-  html << message;
-
-  wxCharBuffer buf = html.ToUTF8();
-  if (buf.data())  // string OK?
-    msgWindow->SetPage(html);
-
-  // 3) buttons
-  int AllButtonSizerFlags =
-      wxOK | wxCANCEL | wxYES | wxNO | wxHELP | wxNO_DEFAULT;
-  int center_flag = wxEXPAND;
-  if (style & wxYES_NO) center_flag = wxALIGN_CENTRE;
-  wxSizer* sizerBtn = CreateSeparatedButtonSizer(style & AllButtonSizerFlags);
-  if (sizerBtn) topsizer->Add(sizerBtn, 0, center_flag | wxALL, 10);
-
-  SetSizer(topsizer);
-
-  topsizer->Fit(this);
-
-  RecalculateSize();
-  //       wxSize szyv = msgWindow->GetVirtualSize();
-
-  //       SetClientSize(szyv.x + 20, szyv.y + 20);
-
-  CentreOnScreen();
-
-  // msgWindow->SetBackgroundColour(wxColour(191, 183, 180));
-  msgWindow->SetBackgroundColour(GetBackgroundColour());
-
-  m_timer.SetOwner(this, -1);
-
-  if (tSeconds > 0) m_timer.Start(tSeconds * 1000, wxTIMER_ONE_SHOT);
-}
-
-void OCPN_TimedHTMLMessageDialog::RecalculateSize(void) {
-  wxSize esize;
-  esize.x = GetCharWidth() * 60;
-  int sx, sy;
-  sx = g_monitor_info[g_current_monitor].width;
-  esize.x = wxMin(esize.x, sx * 6 / 10);
-  esize.y = -1;
-  SetClientSize(esize);  // This will force a recalc of internal representation
-
-  int height1 = msgWindow->GetInternalRepresentation()->GetHeight();
-
-  int client_size_y =
-      wxMin(::wxGetDisplaySize().y - 100, height1 + 70);  // Must fit on screen
-
-  SetClientSize(wxSize(
-      esize.x, client_size_y));  // constant is 2xBorders + a little slop.
-}
-
-void OCPN_TimedHTMLMessageDialog::OnYes(wxCommandEvent& WXUNUSED(event)) {
-  SetReturnCode(wxID_YES);
-  if (IsModal())
-    EndModal(wxID_YES);
-  else
-    Hide();
-}
-
-void OCPN_TimedHTMLMessageDialog::OnNo(wxCommandEvent& WXUNUSED(event)) {
-  SetReturnCode(wxID_NO);
-  if (IsModal())
-    EndModal(wxID_NO);
-  else
-    Hide();
-}
-
-void OCPN_TimedHTMLMessageDialog::OnCancel(wxCommandEvent& WXUNUSED(event)) {
-  // Allow cancellation via ESC/Close button except if
-  // only YES and NO are specified.
-  if ((m_style & wxYES_NO) != wxYES_NO || (m_style & wxCANCEL)) {
-    SetReturnCode(wxID_CANCEL);
-    EndModal(wxID_CANCEL);
-  }
-}
-
-void OCPN_TimedHTMLMessageDialog::OnClose(wxCloseEvent& event) {
-  SetReturnCode(wxID_CANCEL);
-  if (IsModal())
-    EndModal(wxID_CANCEL);
-  else
-    Hide();
-}
-
-void OCPN_TimedHTMLMessageDialog::OnTimer(wxTimerEvent& evt) {
-  if (IsModal())
-    EndModal(m_style & wxNO_DEFAULT ? wxID_NO : wxID_YES);
-  else
-    Hide();
-}
-
-//      Auto timed popup Window implementation
-
+// Auto timed popup Window implementation
 BEGIN_EVENT_TABLE(TimedPopupWin, wxWindow)
 EVT_PAINT(TimedPopupWin::OnPaint)
 EVT_TIMER(POPUP_TIMER, TimedPopupWin::OnTimer)
