@@ -47,8 +47,6 @@
 #include "ocpn_frame.h"
 #include "ocpn_plugin.h"
 
-extern MyFrame* gFrame;
-
 class PriorityEntry : public wxTreeItemData {
 public:
   PriorityEntry(int category, int index) {
@@ -77,7 +75,7 @@ PriorityDlg::PriorityDlg(wxWindow* parent)
 
   m_prioTree = new wxTreeCtrl(this, wxID_ANY, wxDefaultPosition, wxDefaultSize);
   stcSizer->Add(m_prioTree, 1, wxALL | wxEXPAND, 5);
-  wxFont* pF = OCPNGetFont(_T("Dialog"), 0);
+  wxFont* pF = OCPNGetFont(_("Dialog"));
   m_pF = pF;
   m_prioTree->SetFont(*pF);
 #ifdef __ANDROID__
@@ -145,16 +143,22 @@ PriorityDlg::PriorityDlg(wxWindow* parent)
   dc.GetTextExtent("W", &char_width, &char_height, NULL, NULL, m_pF);
 
   int stcw = wxMax(m_maxStringLength * 15 / 10, 15 * char_width);
+  wxWindow* top_frame = wxTheApp->GetTopWindow();
   wxSize min_size = wxSize(
-      stcw, wxMin(gFrame->GetSize().y * 2 / 4, n_lines * GetCharHeight()));
+      stcw, wxMin(top_frame->GetSize().y * 2 / 4, n_lines * GetCharHeight()));
 
   stcSizer->SetMinSize(min_size);
 
-  SetMaxSize(gFrame->GetSize());
-
   Layout();
+#ifdef __ANDROID__
+  wxSize max_size =
+      wxSize(top_frame->GetSize().x, top_frame->GetSize().y * 7 / 10);
+  SetSize(max_size);
+  Centre();
+#else
   Fit();
   Centre();
+#endif
 
 #ifdef __ANDROID__
   androidDisableRotation();
