@@ -18,14 +18,10 @@ wxValidator* RoutePointNameValidator::Clone() const {
  * Validate the route point name.
  */
 wxString RoutePointNameValidator::IsValid(const wxString& val) const {
-  if (val.Len() < 3) {
-    return wxString("Name must be at least 3 characters");
+  Route* route = FindRouteContainingWaypoint(m_wp_ptr);
+  if (route) {
+    return route->IsPointNameValid(m_wp_ptr, val);
   } else {
-    Route* route = FindRouteContainingWaypoint(m_wp_ptr);
-    if (route) {
-      return route->IsPointNameValid(m_wp_ptr, val);
-    } else {
-      return wxEmptyString;
-    }
+    return wxEmptyString;
   }
-}
\ No newline at end of file
+}
