@@ -52,13 +52,14 @@
 #include "routeman_gui.h"
 #include "TrackPropDlg.h"
 #include "vector2D.h"
+#include "model/navobj_db.h"
 
 extern bool g_bShowShipToActive;
 extern bool g_bAdvanceRouteWaypointOnArrivalOnly;
 
 extern MyFrame *gFrame;
 
-extern ConsoleCanvas *console;
+extern APConsole *console;
 
 extern std::vector<Track *> g_TrackList;
 extern ActiveTrack *g_pActiveTrack;
@@ -83,7 +84,7 @@ RoutemanDlgCtx RoutemanGui::GetDlgCtx() {
     if (console) console->ShowWithFreshFonts();
   };
   ctx.clear_console_background = []() {
-    console->pCDI->ClearBackground();
+    console->GetCDI()->ClearBackground();
     console->Show(false);
   };
   ctx.route_mgr_dlg_update_list_ctrl = []() {
@@ -210,6 +211,12 @@ bool RoutemanGui::UpdateProgress() {
 
     bool bDidArrival = false;
 
+    // Duplicate points can result in NaN for normal crossing range.
+    if (isnan(m_routeman.CurrentRangeToActiveNormalCrossing)) {
+      m_routeman.CurrentRangeToActiveNormalCrossing =
+          m_routeman.CurrentRngToActivePoint;
+    }
+
     // Special signal:  if ArrivalRadius < 0, NEVER arrive...
     //  Used for MOB auto-created routes.
     if (m_routeman.pActivePoint->GetWaypointArrivalRadius() > 0) {
@@ -305,16 +312,9 @@ void RoutemanGui::DeleteAllTracks() {
     if (ptrack->m_bIsInLayer) continue;
 
     g_pAIS->DeletePersistentTrack(ptrack);
-    NavObjectChanges::getInstance()->m_bSkipChangeSetUpdate = true;
-    NavObjectChanges::getInstance()->DeleteConfigTrack(ptrack);
+    NavObj_dB::GetInstance().DeleteTrack(ptrack);
     DeleteTrack(ptrack);
-    NavObjectChanges::getInstance()->m_bSkipChangeSetUpdate = false;
   }
-
-  if (pConfig && pConfig->IsChangesFileDirty()) {
-    pConfig->UpdateNavObj(true);
-  }
-
   ::wxEndBusyCursor();
 }
 
@@ -326,8 +326,7 @@ void RoutemanGui::DoAdvance(void) {
     m_routeman.DeactivateRoute(true);  // this is an arrival
 
     if (pthis_route->m_bDeleteOnArrival && !pthis_route->m_bIsBeingEdited) {
-      NavObjectChanges::getInstance()->DeleteConfigRoute(pthis_route);
-      m_routeman.DeleteRoute(pthis_route, NavObjectChanges::getInstance());
+      m_routeman.DeleteRoute(pthis_route);
     }
 
     if (pRouteManagerDialog) pRouteManagerDialog->UpdateRouteListCtrl();
