@@ -140,9 +140,19 @@ bool SVGDocumentPixelSize(const wxString filename, unsigned int& width,
                           unsigned int& height) {
   width = 0;
   height = 0;
+  float viewBoxWidth = 0, viewBoxHeight = 0;
   pugi::xml_document svgDoc;
   if (svgDoc.load_file(filename.fn_str())) {
     pugi::xml_node svgNode = svgDoc.child("svg");
+
+    // Check for viewBox attribute.
+    if (const char* viewBox = svgNode.attribute("viewBox").value()) {
+      std::istringstream iss(viewBox);
+      float minX, minY;
+      iss >> minX >> minY >> viewBoxWidth >> viewBoxHeight;
+    }
+
+    // Check width/height attributes
     for (pugi::xml_attribute attr = svgNode.first_attribute(); attr;
          attr = attr.next_attribute()) {
       const char* pca = attr.name();
@@ -152,6 +162,30 @@ bool SVGDocumentPixelSize(const wxString filename, unsigned int& width,
         height = get_px_length(attr.as_string());
       }
     }
+    // SVG sizing rules: https://svgwg.org/specs/integration/#svg-css-sizing
+    if (width == 0 && height == 0) {
+      if (viewBoxWidth > 0 && viewBoxHeight > 0) {
+        // Use viewBox dimensions
+        width = viewBoxWidth;
+        height = viewBoxHeight;
+      } else {
+        // Default sizes per spec
+        width = 300;
+        height = 150;
+      }
+    } else if (width == 0) {
+      if (viewBoxWidth > 0 && viewBoxHeight > 0) {
+        width = height * (viewBoxWidth / viewBoxHeight);
+      } else {
+        width = 300;
+      }
+    } else if (height == 0) {
+      if (viewBoxWidth > 0 && viewBoxHeight > 0) {
+        height = width * (viewBoxHeight / viewBoxWidth);
+      } else {
+        height = 150;
+      }
+    }
   }
   return false;
 }
