@@ -1,11 +1,6 @@
-/***************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:
- * Author:   David Register, Alec Leamas
- *
- ***************************************************************************
- *   Copyright (C) 2022 by David Register, Alec Leamas                     *
+/**************************************************************************
+ *   Copyright (C) 2022 David Register                                     *
+ *   Copyright (C) 2022 Alec Leamas                                        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
  **************************************************************************/
+
+/**
+ *  \file
+ *  NMEA0183 drivers common base.
+ */
+
 #ifndef _COMMDRIVERN0183_H__
 #define _COMMDRIVERN0183_H__
 
@@ -30,6 +31,7 @@
 
 #include "model/comm_driver.h"
 
+/** NMEA0183 drivers common part. */
 class CommDriverN0183 : public AbstractCommDriver {
 public:
   CommDriverN0183();
@@ -45,8 +47,6 @@ public:
   virtual std::shared_ptr<NavAddr> GetAddress() {
     return std::make_shared<NavAddr>(NavAddr0183(iface));
   }
-
-  void Activate() override;
 };
 
-#endif  // guarstring
+#endif  // guardstring
