@@ -33,6 +33,7 @@
 #include "config.h"
 #include "model/comm_drv_n2k.h"
 #include "model/conn_params.h"
+#include "model/comm_drv_stats.h"
 
 #ifndef __ANDROID__
 #include "serial/serial.h"
@@ -47,20 +48,20 @@
 
 #define MsgTypeN2kData 0x93
 #define MsgTypeN2kRequest 0x94
+using namespace std::literals::chrono_literals;
 
 class CommDriverN2KSerialThread;  // fwd
 class CommDriverN2KSerialEvent;
 
-class CommDriverN2KSerial : public CommDriverN2K, public wxEvtHandler {
+class CommDriverN2KSerial : public CommDriverN2K,
+                            public wxEvtHandler,
+                            public DriverStatsProvider {
 public:
   CommDriverN2KSerial();
   CommDriverN2KSerial(const ConnectionParams* params, DriverListener& listener);
 
   virtual ~CommDriverN2KSerial();
 
-  /** Register driver and possibly do other post-ctor steps. */
-  void Activate() override;
-
   void SetListener(DriverListener& l) override {};
 
   bool Open();
@@ -69,6 +70,8 @@ public:
   bool SendMessage(std::shared_ptr<const NavMsg> msg,
                    std::shared_ptr<const NavAddr> addr) override;
 
+  void AddTxPGN(int pgn);
+
   int SetTXPGN(int pgn) override;
 
   //    Secondary thread life toggle
@@ -89,10 +92,18 @@ public:
   void handle_N2K_SERIAL_RAW(CommDriverN2KSerialEvent& event);
   int GetMfgCode();
 
+  DriverStats GetDriverStats() const override;
+
   std::atomic_int m_Thread_run_flag;
+  ConnectionParams m_params;
 
 private:
   void ProcessManagementPacket(std::vector<unsigned char>* payload);
+  /**
+   * Sends a management message over NMEA 2000 serial interface.
+   *
+   * @note This implementation is excluded on Android platforms
+   */
   int SendMgmtMsg(unsigned char* string, size_t string_size,
                   unsigned char cmd_code, int timeout_msec,
                   bool* response_flag);
@@ -105,7 +116,6 @@ private:
   CommDriverN2KSerialThread* m_pSecondary_Thread;
   bool m_bsec_thread_active;
 
-  ConnectionParams m_params;
   DriverListener& m_listener;
 
   bool m_bmg47_resp;
@@ -118,6 +128,10 @@ private:
   uint64_t NAME;
   int m_manufacturers_code;
   bool m_got_mfg_code;
+  StatsTimer m_stats_timer;
+  DriverStats m_driver_stats;
+  std::vector<int> pgn_tx_list;
+  bool m_closing;
 };
 
 #endif  // guard
