@@ -26,22 +26,22 @@
 #ifndef _COMMDRIVERN2KSOCKETCAN_H
 #define _COMMDRIVERN2KSOCKETCAN_H
 
+#include <chrono>
 #include <memory>
 #include <string>
 
 #include "model/comm_drv_n2k.h"
+#include "model/comm_drv_stats.h"
 #include "model/conn_params.h"
 
-class CommDriverN2KSocketCAN : public CommDriverN2K {
+class CommDriverN2KSocketCAN : public CommDriverN2K,
+                               public DriverStatsProvider {
 public:
-  static std::shared_ptr<CommDriverN2KSocketCAN> Create(
+  static std::unique_ptr<CommDriverN2KSocketCAN> Create(
       const ConnectionParams* params, DriverListener& listener);
 
   virtual ~CommDriverN2KSocketCAN();
 
-  /** Register driver and possibly do other post-ctor steps. */
-  void Activate() override;
-
   void SetListener(DriverListener& l) override { m_listener = l; }
 
   bool SendMessage(std::shared_ptr<const NavMsg> msg,
@@ -51,17 +51,21 @@ public:
   virtual void Close() = 0;
 
   void UpdateAttrCanAddress();
+  DriverStats GetDriverStats() const override { return m_driver_stats; }
+  void SetDriverStats(DriverStats _stats) { m_driver_stats = _stats; }
 
 protected:
   CommDriverN2KSocketCAN(const ConnectionParams* params,
                          DriverListener& listener);
   ConnectionParams m_params;
   DriverListener& m_listener;
+  StatsTimer m_stats_timer;
 
 private:
   bool m_ok;
   std::string m_portstring;
   std::string m_baudrate;
+  DriverStats m_driver_stats;
 };
 
 #endif  // guard
