@@ -1,11 +1,6 @@
-/***************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:  Driver registration container, a singleton.
- * Author:   David Register, Alec Leamas
- *
- ***************************************************************************
- *   Copyright (C) 2022 by David Register, Alec Leamas                     *
+/**************************************************************************
+ *   Copyright (C) 2022 by David Register                                  *
+ *   Copyright (C) 2022  Alec Leamas                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,19 +18,29 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
  **************************************************************************/
 
+/**
+ * \file
+ * Driver registration container, a singleton.
+ */
+
 #ifndef _COMMDRIVERREGISTRY_H__
 #define _COMMDRIVERREGISTRY_H__
 
 #include "model/comm_driver.h"
 #include "observable_evtvar.h"
 
-typedef std::shared_ptr<AbstractCommDriver> DriverPtr;
+using DriverPtr = std::unique_ptr<AbstractCommDriver>;
 
 /**
- * The global driver registry, a singleton. Drivers register here when
- * activated, transport layer finds them.
+ * The global driver registry, a singleton. Drivers are registered here
+ * when activated, transport layer finds them.
  *
- * Also used as exchange point for messages for USB devices hotplug events.
+ * Also used as exchange point for some driver related events>.
+ *
+ * This interface is not synchronized and must only be used from main
+ * thread. The exception is the various EventVar which can be notified
+ * from driver threads. As usual, listening to these events must be done
+ * in main thread.
  */
 class CommDriverRegistry final {
 public:
@@ -45,13 +50,13 @@ public:
   void Activate(DriverPtr driver);
 
   /** Remove driver from list of active drivers. */
-  void Deactivate(DriverPtr driver);
+  void Deactivate(DriverPtr& driver);
 
   /** Close and destroy all drivers completely. */
   void CloseAllDrivers();
 
   /** @return List of all activated drivers. */
-  const std::vector<DriverPtr>& GetDrivers();
+  const std::vector<DriverPtr>& GetDrivers() const;
 
   /** Notified by all driverlist updates. */
   EventVar evt_driverlist_change;
@@ -62,6 +67,9 @@ public:
   /** Notified with a printable message on first detected overrun. */
   EventVar evt_comm_overrun;
 
+  /** Regularly notified by drivers with a DriverStats shared_ptr */
+  EventVar evt_driver_stats;
+
   /**
    *  Notified for messages from drivers. The generated event contains:
    *  - A wxLogLevel stored as an int.
@@ -81,9 +89,13 @@ private:
 /**
  * Search list of drivers for a driver with given interface string.
  * @return First found driver or shared_ptr<>(nullptr), which is false.
+ *
+ * @note The driver list is const in the sense that elements cannot be
+ * added, removed, etc. However, the driver returned needs to be non-const
+ * since most driver operations (notably sending) are non-const.
  */
-const DriverPtr FindDriver(const std::vector<DriverPtr>& drivers,
-                           const std::string& iface,
-                           const NavAddr::Bus _bus = NavAddr::Bus::Undef);
+DriverPtr& FindDriver(const std::vector<DriverPtr>& drivers,
+                      const std::string& iface,
+                      const NavAddr::Bus _bus = NavAddr::Bus::Undef);
 
 #endif  // guard
