@@ -74,8 +74,6 @@
 #define PI 3.1415926535897931160E0 /* pi */
 #endif
 
-#define TIMER_SOCKET 7006
-
 //----------------------------------------------------------------------------
 // Garmin Device Management
 // Handle USB and Serial Port Garmin PVT protocol data interface.
@@ -177,6 +175,8 @@ typedef struct {
 
 enum { rs_fromintr, rs_frombulk };
 
+using SendMsgFunc = std::function<void(const std::vector<unsigned char> &)>;
+
 #define TIMER_GARMIN1 7005
 
 class GARMIN_Serial_Thread;
@@ -184,8 +184,7 @@ class GARMIN_USB_Thread;
 
 class GarminProtocolHandler : public wxEvtHandler {
 public:
-  GarminProtocolHandler(wxString port, wxEvtHandler *MessageTarget,
-                        bool bsel_usb);
+  GarminProtocolHandler(wxString port, SendMsgFunc send_msg_func, bool sel_usb);
   ~GarminProtocolHandler();
 
   void Close(void);
@@ -199,7 +198,7 @@ public:
 
   bool FindGarminDeviceInterface();
 
-  wxEvtHandler *m_pMainEventHandler;
+  SendMsgFunc m_send_msg_func;
   void *m_pparent;
 
   int m_max_tx_size;
@@ -249,14 +248,14 @@ public:
 //-------------------------------------------------------------------------------------------------------------
 class GARMIN_Serial_Thread : public wxThread {
 public:
-  GARMIN_Serial_Thread(GarminProtocolHandler *parent,
-                       wxEvtHandler *MessageTarget, wxString port);
+  GARMIN_Serial_Thread(GarminProtocolHandler *parent, SendMsgFunc send_msg_func,
+                       wxString port);
   ~GARMIN_Serial_Thread(void);
   void *Entry();
   void string(wxCharBuffer mb_str);
 
 private:
-  wxEvtHandler *m_pMessageTarget;
+  SendMsgFunc m_send_msg_func;
   GarminProtocolHandler *m_parent;
 
   wxString m_port;
@@ -274,7 +273,7 @@ private:
 //-------------------------------------------------------------------------------------------------------------
 class GARMIN_USB_Thread : public wxThread {
 public:
-  GARMIN_USB_Thread(GarminProtocolHandler *parent, wxEvtHandler *MessageTarget,
+  GARMIN_USB_Thread(GarminProtocolHandler *parent, SendMsgFunc send_msg_func,
                     unsigned int device_handle, size_t max_tx_size);
   ~GARMIN_USB_Thread(void);
   void *Entry();
@@ -284,7 +283,7 @@ private:
   int gusb_win_get_bulk(garmin_usb_packet *ibuf, size_t sz);
   int gusb_cmd_get(garmin_usb_packet *ibuf, size_t sz);
 
-  wxEvtHandler *m_pMessageTarget;
+  SendMsgFunc m_send_msg_func;
   GarminProtocolHandler *m_parent;
 
   int m_receive_state;
