@@ -34,31 +34,43 @@
 #endif  // precompiled headers
 
 #include "model/comm_navmsg.h"
+#include "model/nmea_log.h"
 
 class Multiplexer;  // forward
 
-extern Multiplexer *g_pMUX;
+extern Multiplexer* g_pMUX;
 
 struct MuxLogCallbacks {
   std::function<bool()> log_is_active;
-  std::function<void(const std::string &)> log_message;
+  std::function<void(Logline)> log_message;
   MuxLogCallbacks()
-      : log_is_active([]() { return false; }),
-        log_message([](const std::string &s) {}) {}
+      : log_is_active([]() { return false; }), log_message([](Logline) {}) {}
 };
 
 class Multiplexer : public wxEvtHandler {
 public:
   Multiplexer(MuxLogCallbacks log_callbacks,
-              bool &legacy_input_filter_behaviour);
+              bool& legacy_input_filter_behaviour);
   ~Multiplexer();
 
-  void LogOutputMessage(const wxString &msg, wxString stream_name,
-                        bool b_filter);
-  void LogOutputMessageColor(const wxString &msg, const wxString &stream_name,
-                             const wxString &color);
-  void LogInputMessage(const wxString &msg, const wxString &stream_name,
-                       bool b_filter, bool b_error = false);
+  void LogOutputMessage(const std::shared_ptr<const NavMsg>& msg,
+                        NavmsgStatus status);
+
+  // void LogOutputMessageColor(const std::shared_ptr<const NavMsg>& msg,
+  //                            NavmsgStatus status);
+  /**
+   * Logs an input message with context information.
+   *
+   * @param msg The message to be logged.
+   * @param stream_name The name of the stream from which the message
+   * originated.
+   * @param b_filter Indicates whether the message was filtered.
+   * @param b_error Indicates whether the message has an error such as bad CRC.
+   * @param error_msg The error message to be logged.
+   */
+  void LogInputMessage(const std::shared_ptr<const NavMsg>& msg,
+                       bool is_filtered, bool is_error,
+                       const wxString error_msg = "");
 
   bool IsLogActive() { return m_log_callbacks.log_is_active(); }
 
@@ -71,12 +83,11 @@ private:
 
   void HandleN0183(std::shared_ptr<const Nmea0183Msg> n0183_msg);
   bool HandleN2K_Log(std::shared_ptr<const Nmea2000Msg> n2k_msg);
-  std::string N2K_LogMessage_Detail(unsigned int pgn,
-                                    std::shared_ptr<const Nmea2000Msg> n2k_msg);
+  std::string N2K_LogMessage_Detail(unsigned int pgn);
 
   MuxLogCallbacks m_log_callbacks;
   unsigned int last_pgn_logged;
   int n_N2K_repeat;
-  bool &m_legacy_input_filter_behaviour;
+  bool& m_legacy_input_filter_behaviour;
 };
 #endif  // _MULTIPLEXER_H__
