@@ -31,6 +31,7 @@
 #include <wx/utils.h>
 
 #include "model/config_vars.h"
+#include "model/gpx_document.h"
 
 enum { SPEED_KTS = 0, SPEED_MPH, SPEED_KMH, SPEED_MS };
 enum { WSPEED_KTS = 0, WSPEED_MS, WSPEED_MPH, WSPEED_KMH };
@@ -48,15 +49,6 @@ enum {
   DISTANCE_CM
 };
 
-class GpxDocument {
-public:
-  static wxString GetUUID(void);
-  static void SeedRandom();
-
-private:
-  static int GetRandomNumber(int min, int max);
-};
-
 extern wxString toSDMM(int NEflag, double a, bool hi_precision = true);
 extern double toUsrSpeed(double kts_speed, int unit = -1);
 extern double toUsrWindSpeed(double kts_speed, int unit = -1);
@@ -75,6 +67,19 @@ extern double toUsrDepth(double cel_depth, int unit = -1);
 extern double fromUsrDepth(double usr_depth, int unit = -1);
 extern wxString getUsrDepthUnit(int unit = -1);
 
+/**
+ * This function parses a string containing a GPX time representation
+ * and returns a wxDateTime containing the UTC corresponding to the
+ * input. The function return value is a pointer past the last valid
+ * character parsed (if successful) or NULL (if the string is invalid).
+ *
+ * Valid GPX time strings are in ISO 8601 format as follows:
+ *
+ *   [-]<YYYY>-<MM>-<DD>T<hh>:<mm>:<ss>Z|(+|-<hh>:<mm>)
+ *
+ * For example, 2010-10-30T14:34:56Z and 2010-10-30T14:34:56-04:00
+ * are the same time. The first is UTC and the second is EDT.
+ */
 const wxChar *ParseGPXDateTime(wxDateTime &dt, const wxChar *datetime);
 
 extern wxString formatTimeDelta(wxTimeSpan span);
@@ -85,4 +90,6 @@ extern double fromDMM(wxString sdms);
 
 extern double toMagnetic(double deg_true);
 extern double toMagnetic(double deg_true, double variation);
+
+wxString SanitizeFileName(const wxString &input);
 #endif  // _NAVUTIL_BASE__
