@@ -36,6 +36,7 @@
 #include <wx/string.h>
 
 #include "model/MarkIcon.h"
+
 #include "model/nav_object_database.h"
 #include "model/nmea_log.h"
 #include "model/ocpn_types.h"
@@ -116,25 +117,96 @@ class Routeman {
 
 public:
   Routeman(struct RoutePropDlgCtx prop_dlg_ctx,
-           struct RoutemanDlgCtx route_dlg_ctx, NmeaLog &nmea_log);
+           struct RoutemanDlgCtx route_dlg_ctx);
   ~Routeman();
 
   bool DeleteTrack(Track *pTrack);
-  bool DeleteRoute(Route *pRoute, NavObjectChanges *nav_obj_changes);
-  void DeleteAllRoutes(NavObjectChanges *nav_obj_changes);
+  bool DeleteRoute(Route *pRoute);
+  void DeleteAllRoutes();
 
   bool IsRouteValid(Route *pRoute);
 
   Route *FindRouteByGUID(const wxString &guid);
   Track *FindTrackByGUID(const wxString &guid);
   Route *FindRouteContainingWaypoint(RoutePoint *pWP);
+  Route *FindRouteContainingWaypoint(const std::string &guid);
   Route *FindVisibleRouteContainingWaypoint(RoutePoint *pWP);
+  /**
+   * Find all routes that contain the given waypoint.
+   *
+   * This function searches through all routes in the route list
+   * and returns an array of route pointers for each route that
+   * contains the specified waypoint.
+   *
+   * @param pWP Pointer to the waypoint to search for.
+   * @return Pointer to wxArrayPtrVoid containing routes, or nullptr if no
+   * routes contain the waypoint. The caller is responsible for deleting the
+   * returned array when done with it.
+   */
   wxArrayPtrVoid *GetRouteArrayContaining(RoutePoint *pWP);
   bool DoesRouteContainSharedPoints(Route *pRoute);
   void RemovePointFromRoute(RoutePoint *point, Route *route, int route_state);
 
+  /**
+   * Activates a route for navigation.
+   *
+   * This function sets up a route for active navigation by:
+   * 1. Setting up the route for plugin notifications
+   * 2. Configuring output drivers for navigation data
+   * 3. Creating a "virtual" waypoint at the vessel's current position if
+   * starting at the beginning of the route
+   * 4. Activating the first/selected waypoint as the active navigation target
+   * 5. Initializing arrival detection parameters
+   *
+   * When a route is activated, OpenCPN starts providing navigation data to
+   * autopilot systems and plugins, updating the display to show the active
+   * route, and monitoring for waypoint arrivals.
+   *
+   * @param pRouteToActivate Pointer to the Route object to activate
+   * @param pStartPoint Optional pointer to a specific RoutePoint to start from
+   *                    (if NULL, starts from the first point in the route)
+   * @return true if route was successfully activated
+   */
   bool ActivateRoute(Route *pRouteToActivate, RoutePoint *pStartPoint = NULL);
+  /**
+   * Activates a specific waypoint within a route for navigation.
+   *
+   * This function sets up navigation to a specific waypoint by:
+   * 1. Setting up waypoint plugin notifications
+   * 2. Establishing the active waypoint and its preceding segment
+   * 3. Creating a "virtual" waypoint at the vessel's current position if this
+   * is the first point in the route
+   * 4. Setting up visual indicators (making the active point blink)
+   * 5. Initializing arrival detection parameters
+   *
+   * This function is called by ActivateRoute() and is also used when manually
+   * changing the active waypoint during navigation.
+   *
+   * @param pA Pointer to the route containing the waypoint
+   * @param pRP_target Pointer to the RoutePoint to set as the active target
+   * @return true if waypoint was successfully activated
+   */
   bool ActivateRoutePoint(Route *pA, RoutePoint *pRP);
+  /**
+   * Activates the next waypoint in a route when the current waypoint is
+   * reached.
+   *
+   * This function handles the transition between waypoints by:
+   * 1. Deactivating the current waypoint
+   * 2. Sending arrival notifications to plugins
+   * 3. Finding and activating the next waypoint in sequence
+   * 4. Setting up visual indicators for the new active waypoint
+   * 5. Resetting arrival detection parameters
+   *
+   * This function is called automatically when a waypoint arrival is detected,
+   * or manually when skipping a waypoint.
+   *
+   * @param pr Pointer to the active route
+   * @param skipped Boolean indicating if this is a manual skip (true) or normal
+   * arrival (false)
+   * @return true if successfully activated the next waypoint, false if at the
+   * end of the route
+   */
   bool ActivateNextPoint(Route *pr, bool skipped);
   RoutePoint *FindBestActivatePoint(Route *pR, double lat, double lon,
                                     double cog, double sog);
@@ -142,8 +214,13 @@ public:
   bool UpdateAutopilot();
   bool DeactivateRoute(bool b_arrival = false);
   bool IsAnyRouteActive(void) { return (pActiveRoute != NULL); }
+  bool GetArrival() { return m_bArrival; }
 
   Route *GetpActiveRoute() { return pActiveRoute; }
+  RoutePoint *GetpActiveRouteSegmentBeginPoint() {
+    return pActiveRouteSegmentBeginPoint;
+  }
+
   RoutePoint *GetpActivePoint() { return pActivePoint; }
   double GetCurrentRngToActivePoint() { return CurrentRngToActivePoint; }
   double GetCurrentBrgToActivePoint() { return CurrentBrgToActivePoint; }
@@ -171,7 +248,9 @@ public:
   wxString GetRouteReverseMessage(void);
   wxString GetRouteResequenceMessage(void);
   struct RoutemanDlgCtx &GetDlgContext() { return m_route_dlg_ctx; }
-
+  NMEA0183 GetNMEA0183() { return m_NMEA0183; }
+  EventVar &GetMessageSentEventVar() { return on_message_sent; }
+  std::vector<DriverHandle> GetOutpuDriverArray() { return m_output_drivers; }
   bool m_bDataValid;
 
   /**
@@ -223,10 +302,12 @@ private:
   int m_arrival_test;
   struct RoutePropDlgCtx m_prop_dlg_ctx;
   struct RoutemanDlgCtx m_route_dlg_ctx;
-  NmeaLog &m_nmea_log;
 
   ObsListener msg_sent_listener;
   ObsListener active_route_listener;
+  std::vector<DriverHandle> m_output_drivers;
+  bool m_have_n0183_out;
+  bool m_have_n2000_out;
 };
 
 //----------------------------------------------------------------------------
@@ -241,12 +322,17 @@ class WayPointman {
 public:
   WayPointman(GlobalColourFunc colour_func);
   ~WayPointman();
-  wxBitmap *GetIconBitmap(const wxString &icon_key);
-  bool GetIconPrescaled(const wxString &icon_key);
-  int GetIconIndex(const wxBitmap *pbm);
-  int GetIconImageListIndex(const wxBitmap *pbm);
-  int GetXIconImageListIndex(const wxBitmap *pbm);
-  int GetFIconImageListIndex(const wxBitmap *pbm);
+  wxBitmap *GetIconBitmap(const wxString &icon_key) const;
+  bool GetIconPrescaled(const wxString &icon_key) const;
+  int GetIconIndex(const wxBitmap *pbm) const;
+  int GetIconImageListIndex(const wxBitmap *pbm) const;
+
+  /** index of "X-ed out" icon in the image list */
+  int GetXIconImageListIndex(const wxBitmap *pbm) const;
+
+  /** index of "fixed viz" icon in the image list  */
+  int GetFIconImageListIndex(const wxBitmap *pbm) const;
+
   int GetNumIcons(void) { return m_pIconArray->Count(); }
   wxString CreateGUID(RoutePoint *pRP);
   RoutePoint *FindWaypointByGuid(const std::string &guid);
@@ -262,16 +348,28 @@ public:
   void ClearRoutePointFonts(void);
 
   bool DoesIconExist(const wxString &icon_key) const;
-  wxBitmap GetIconBitmapForList(int index, int height);
-  wxString *GetIconDescription(int index);
-  wxString *GetIconKey(int index);
-  wxString GetIconDescription(wxString icon_key);
+  wxBitmap GetIconBitmapForList(int index, int height) const;
+  wxString *GetIconDescription(int index) const;
+  wxString *GetIconKey(int index) const;
+  wxString GetIconDescription(wxString icon_key) const;
 
   wxImageList *Getpmarkicon_image_list(int nominal_height);
 
+  /**
+   * Add a point to list which owns it.
+   * @param prp RoutePoint allocated by caller.
+   * @return true if successfully added.
+   */
   bool AddRoutePoint(RoutePoint *prp);
+
+  /**
+   *  Remove a routepoint from list if present, deallocate it all cases.
+   *  @param prp RoutePoint possibly part of list.
+   *  @return true if prp != nullptr.
+   */
   bool RemoveRoutePoint(RoutePoint *prp);
-  RoutePointList *GetWaypointList(void) { return m_pWayPointList; }
+
+  const RoutePointList *GetWaypointList(void) { return m_pWayPointList; }
 
 private:
   wxImage CreateDimImage(wxImage &image, double factor);
