@@ -32,6 +32,7 @@
 #include <list>
 #include <vector>
 
+#include "model/datetime.h"
 #include "bbox.h"
 #include "hyperlink.h"
 #include "route.h"
@@ -46,6 +47,9 @@ struct SubTrack {
   double m_scale;
 };
 
+/**
+ * Represents a single point in a track.
+ */
 class TrackPoint {
 public:
   TrackPoint(double lat, double lon, wxString ts = "");
@@ -53,7 +57,26 @@ public:
   TrackPoint(TrackPoint *orig);
   ~TrackPoint();
 
+  /**
+   * Retrieves the creation timestamp of a track point as a wxDateTime object.
+   *
+   * @return wxDateTime object representing the creation time in UTC.
+   *         If the internal timestamp string is invalid or empty, the
+   *         returned wxDateTime may be invalid.
+   */
   wxDateTime GetCreateTime(void);
+  /**
+   * Sets the creation timestamp for a track point.
+   *
+   * @param dt The wxDateTime object containing the timestamp to set.
+   *           Should be in UTC time already, as no time zone conversion is
+   * performed. The time is directly formatted and marked with 'Z' (UTC
+   * indicator). If the provided datetime is invalid, an empty string will be
+   * stored.
+   *
+   * Format: YYYY-MM-DDThh:mm:ssZ
+   * Example: 2023-04-15T14:22:38Z
+   */
   void SetCreateTime(wxDateTime dt);
   const char *GetTimeString() { return m_stimestring.c_str(); }
   bool HasValidTimestamp() {
@@ -65,14 +88,26 @@ public:
   int m_GPXTrkSegNo;
 
 private:
+  /**
+   * Sets the creation timestamp for a track point from a string.
+   *
+   * @param ts The timestamp string to store. Should be in ISO 8601 format.
+   *           If empty, the track point will have no timestamp.
+   *
+   * For example:
+   * - "2023-04-15T14:22:38Z" (UTC)
+   * - "2023-04-15T10:22:38-04:00" (EDT, 4 hours west of UTC)
+   *
+   * Time zone information will be correctly interpreted when the timestamp is
+   * read via GetCreateTime() which will return a wxDateTime object in UTC.
+   */
   void SetCreateTime(wxString ts);
   std::string m_stimestring;
 };
 
-//----------------------------------------------------------------------------
-//    Track
-//----------------------------------------------------------------------------
-
+/**
+ * Represents a track, which is a series of connected track points.
+ */
 class Track {
   friend class TrackGui;
 
@@ -104,36 +139,26 @@ public:
 
   void ClearHighlights();
 
+  /* Return the name of the track, or the start date/time of the track if no
+   * name has been set. */
   wxString GetName(bool auto_if_empty = false) const {
     if (!auto_if_empty || !m_TrackNameString.IsEmpty()) {
       return m_TrackNameString;
     } else {
-      wxString name;
-      TrackPoint *rp = NULL;
-      if ((int)TrackPoints.size() > 0) rp = TrackPoints[0];
-      if (rp && rp->GetCreateTime().IsValid())
-        name = rp->GetCreateTime().FormatISODate() + _T(" ") +
-               rp->GetCreateTime()
-                   .FormatISOTime();  // name = rp->m_CreateTime.Format();
-      else
-        name = _("(Unnamed Track)");
-      return name;
+      return GetDateTime(_("(Unnamed Track)"));
     }
   }
   void SetName(const wxString name) { m_TrackNameString = name; }
 
-  wxString GetDate(bool auto_if_empty = false) const {
-    wxString name;
-    TrackPoint *rp = NULL;
-    if ((int)TrackPoints.size() > 0) rp = TrackPoints[0];
-    if (rp && rp->GetCreateTime().IsValid())
-      name = rp->GetCreateTime().FormatISODate() + _T(" ") +
-             rp->GetCreateTime()
-                 .FormatISOTime();  // name = rp->m_CreateTime.Format();
-    else
-      name = _("(Unknown Date)");
-    return name;
-  }
+  /* Return the start date/time of the track, formatted as ISO 8601 timestamp.
+   * The separator between date and time is a space character. */
+  wxString GetIsoDateTime(
+      const wxString label_for_invalid_date = _("(Unknown Date)")) const;
+
+  /* Return the start date/time of the track, formatted using the global
+   * timezone settings. */
+  wxString GetDateTime(
+      const wxString label_for_invalid_date = _("(Unknown Date)")) const;
 
   wxString m_GUID;
   bool m_bIsInLayer;
@@ -154,15 +179,13 @@ public:
 
   int m_CurrentTrackSeg;
 
-  HyperlinkList *m_HyperlinkList;
+  HyperlinkList *m_TrackHyperlinkList;
   int m_HighlightedTrackPoint;
 
   void Clone(Track *psourcetrack, int start_nPoint, int end_nPoint,
              const wxString &suffix);
 
 protected:
-  //  void Segments(ChartCanvas *cc, std::list<std::list<wxPoint> > &pointlists,
-  //                const LLBBox &box, double scale);
   void DouglasPeuckerReducer(std::vector<TrackPoint *> &list,
                              std::vector<bool> &keeplist, int from, int to,
                              double delta);
@@ -174,9 +197,6 @@ protected:
   std::vector<std::vector<SubTrack> > SubTracks;
 
 private:
-  //  void GetPointLists(ChartCanvas *cc,
-  //                     std::list<std::list<wxPoint> > &pointlists, ViewPort
-  //                     &VP, const LLBBox &box);
   void Finalize();
   double ComputeScale(int left, int right);
   void InsertSubTracks(LLBBox &box, int level, int pos);
@@ -195,6 +215,9 @@ private:
 };
 
 class Route;
+/**
+ * Represents an active track that is currently being recorded.
+ */
 class ActiveTrack : public wxEvtHandler, public Track {
 public:
   ActiveTrack();
