@@ -1,11 +1,6 @@
-/***************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:  Implements comm_drv_registry.h
- * Author:   David Register, Alec Leamas
- *
- ***************************************************************************
- *   Copyright (C) 2022 by David Register, Alec Leamas                     *
+/**************************************************************************
+ *   Copyright (C) 2022 by David Register                                  *
+ *   Copyright (C) 2022  Alec Leamas                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,12 +17,11 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
  **************************************************************************/
-// For compilers that support precompilation, includes "wx.h".
-#include <wx/wxprec.h>
 
-#ifndef WX_PRECOMP
-#include <wx/wx.h>
-#endif  // precompiled headers
+/**
+ * \file
+ * Implement comm_drv_registry.h
+ */
 
 #include <algorithm>
 #include <memory>
@@ -36,20 +30,23 @@
 #include "model/comm_drv_registry.h"
 
 void CommDriverRegistry::Activate(DriverPtr driver) {
-  auto found = std::find(drivers.begin(), drivers.end(), driver);
-  if (found != drivers.end()) return;
-  drivers.push_back(driver);
+  if (!driver) return;
+  AbstractCommDriver* found = nullptr;
+  for (auto& d : drivers)
+    if (d->iface == driver->iface && d->bus == driver->bus) found = d.get();
+  if (found) return;
+  drivers.push_back(std::move(driver));
   evt_driverlist_change.Notify();
 };
 
-void CommDriverRegistry::Deactivate(DriverPtr driver) {
+void CommDriverRegistry::Deactivate(DriverPtr& driver) {
   auto found = std::find(drivers.begin(), drivers.end(), driver);
   if (found == drivers.end()) return;
   drivers.erase(found);
   evt_driverlist_change.Notify();
 }
 
-const std::vector<DriverPtr>& CommDriverRegistry::GetDrivers() {
+const std::vector<DriverPtr>& CommDriverRegistry::GetDrivers() const {
   return drivers;
 };
 
@@ -64,26 +61,20 @@ CommDriverRegistry& CommDriverRegistry::GetInstance() {
   return instance;
 }
 
-const std::shared_ptr<AbstractCommDriver> kNoDriver(nullptr);
+std::unique_ptr<AbstractCommDriver> kNoDriver(nullptr);
 
-const DriverPtr FindDriver(const std::vector<DriverPtr>& drivers,
-                           const std::string& iface, const NavAddr::Bus _bus) {
+DriverPtr& FindDriver(const std::vector<DriverPtr>& drivers,
+                      const std::string& iface, const NavAddr::Bus _bus) {
   if (_bus != NavAddr::Bus::Undef) {
-    auto func = [iface, _bus](const DriverPtr d) {
-      return ((d->iface == iface) && (d->bus == _bus));
-    };
-    auto found = std::find_if(drivers.begin(), drivers.end(), func);
-    return found != drivers.end() ? *found : kNoDriver;
+    for (const DriverPtr& d : drivers) {
+      if (d->iface == iface && d->bus == _bus) {
+        return const_cast<DriverPtr&>(d);
+      }
+    }
+    return kNoDriver;
   } else {
-    auto func = [iface](const DriverPtr d) { return d->iface == iface; };
-    auto found = std::find_if(drivers.begin(), drivers.end(), func);
-    return found != drivers.end() ? *found : kNoDriver;
+    for (auto&& d : drivers)
+      if (d->iface == iface) return const_cast<DriverPtr&>(d);
+    return kNoDriver;
   }
 }
-
-const DriverPtr FindDriver(const std::vector<DriverPtr>& drivers,
-                           const std::string& key) {
-  auto func = [key](const DriverPtr d) { return d->Key() == key; };
-  auto found = std::find_if(drivers.begin(), drivers.end(), func);
-  return found != drivers.end() ? *found : kNoDriver;
-}
