@@ -29,22 +29,21 @@
 #include "model/select.h"
 #include "model/track.h"
 #include "model/route.h"
+#include "model/navobj_db.h"
 
 #ifdef __ANDROID__
 #include <QDebug>
 #endif
 
-NavObjectCollection1::NavObjectCollection1()
-    : pugi::xml_document(), m_bSkipChangeSetUpdate(false) {}
+NavObjectCollection1::NavObjectCollection1() : pugi::xml_document() {}
 
 NavObjectCollection1::~NavObjectCollection1() {}
 
 RoutePoint *GPXLoadWaypoint1(pugi::xml_node &wpt_node, wxString def_symbol_name,
                              wxString GUID, bool b_fullviz, bool b_layer,
-                             bool b_layerviz, int layer_id) {
+                             bool b_layerviz, int layer_id, bool b_nameviz) {
   bool bviz = false;
   bool bviz_name = false;
-  bool bauto_name = false;
   bool bshared = false;
   bool b_propvizname = false;
   bool b_propviz = false;
@@ -146,10 +145,6 @@ RoutePoint *GPXLoadWaypoint1(pugi::xml_node &wpt_node, wxString def_symbol_name,
             wxString s = wxString::FromUTF8(ext_child.first_child().value());
             long v = 0;
             if (s.ToLong(&v)) bviz_name = (v != 0);
-          } else if (ext_name == _T ( "opencpn:auto_name" )) {
-            wxString s = wxString::FromUTF8(ext_child.first_child().value());
-            long v = 0;
-            if (s.ToLong(&v)) bauto_name = (v != 0);
           } else if (ext_name == _T ( "opencpn:shared" )) {
             wxString s = wxString::FromUTF8(ext_child.first_child().value());
             long v = 0;
@@ -195,6 +190,9 @@ RoutePoint *GPXLoadWaypoint1(pugi::xml_node &wpt_node, wxString def_symbol_name,
               if (!strcmp(attr.name(), "planned_speed"))
                 plan_speed = attr.as_double();
               else if (!strcmp(attr.name(), "etd"))
+                // The timestamp is serialized without timezone information,
+                // e.g., etd="2025-04-03T20:00:27"
+                // So assume the ETD has always been saved in UTC.
                 etd = attr.as_string();
             }
           }
@@ -240,6 +238,9 @@ RoutePoint *GPXLoadWaypoint1(pugi::xml_node &wpt_node, wxString def_symbol_name,
   else
     pWP->m_bShowName = false;
 
+  // Special case handling of un-named points in a route
+  if (!b_nameviz && !b_propvizname) pWP->m_bShowName = false;
+
   if (b_propviz)
     pWP->m_bIsVisible = bviz;
   else if (b_fullviz)
@@ -253,7 +254,6 @@ RoutePoint *GPXLoadWaypoint1(pugi::xml_node &wpt_node, wxString def_symbol_name,
   }
 
   pWP->SetShared(bshared);
-  pWP->m_bDynamicName = bauto_name;
 
   if (TimeString.Len()) {
     pWP->m_timestring = TimeString;
@@ -426,8 +426,8 @@ Track *GPXLoadTrack1(pugi::xml_node &trk_node, bool b_fullviz, bool b_layer,
   }
 
   if (linklist) {
-    delete pTentTrack->m_HyperlinkList;  // created in TrackPoint ctor
-    pTentTrack->m_HyperlinkList = linklist;
+    delete pTentTrack->m_TrackHyperlinkList;  // created in TrackPoint ctor
+    pTentTrack->m_TrackHyperlinkList = linklist;
   }
 
   return pTentTrack;
@@ -525,6 +525,9 @@ Route *GPXLoadRoute1(pugi::xml_node &wpt_node, bool b_fullviz, bool b_layer,
           if (RouteExists(pTentRoute->m_GUID)) {  // we are loading a different
                                                   // route with the same guid so
                                                   // let's generate a new guid
+            // HACK FOR TESTING NAVOBJ_DB
+            return nullptr;
+
             pTentRoute->m_GUID = pWayPointMan->CreateGUID(NULL);
             route_existing = true;
           }
@@ -533,7 +536,7 @@ Route *GPXLoadRoute1(pugi::xml_node &wpt_node, bool b_fullviz, bool b_layer,
       else if (load_points && ChildName == _T ( "rtept" )) {
         RoutePoint *tpWp =
             ::GPXLoadWaypoint1(tschild, _T("square"), _T(""), b_fullviz,
-                               b_layer, b_layerviz, layer_id);
+                               b_layer, b_layerviz, layer_id, false);
         RoutePoint *erp = NULL;
         if (!b_layer) erp = ::WaypointExists(tpWp->m_GUID);
         // 1) if b_change is true, that means we are after crash - load the
@@ -731,9 +734,8 @@ static bool GPXCreateWpt(pugi::xml_node node, RoutePoint *pr,
   }
 
   if ((flags & OUT_GUID) || (flags & OUT_VIZ) || (flags & OUT_VIZ_NAME) ||
-      (flags & OUT_SHARED) || (flags & OUT_AUTO_NAME) ||
-      (flags & OUT_EXTENSION) || (flags & OUT_TIDE_STATION) ||
-      (flags & OUT_RTE_PROPERTIES)) {
+      (flags & OUT_SHARED) || (flags & OUT_EXTENSION) ||
+      (flags & OUT_TIDE_STATION) || (flags & OUT_RTE_PROPERTIES)) {
     pugi::xml_node child_ext = node.append_child("extensions");
 
     if (!pr->m_GUID.IsEmpty() && (flags & OUT_GUID)) {
@@ -751,10 +753,6 @@ static bool GPXCreateWpt(pugi::xml_node node, RoutePoint *pr,
       child.append_child(pugi::node_pcdata).set_value("1");
     }
 
-    if ((flags & OUT_AUTO_NAME) && pr->m_bDynamicName) {
-      child = child_ext.append_child("opencpn:auto_name");
-      child.append_child(pugi::node_pcdata).set_value("1");
-    }
     if ((flags & OUT_SHARED) && pr->IsShared()) {
       child = child_ext.append_child("opencpn:shared");
       child.append_child(pugi::node_pcdata).set_value("1");
@@ -812,8 +810,12 @@ static bool GPXCreateWpt(pugi::xml_node node, RoutePoint *pr,
         use.set_value(
             wxString::Format(_T("%.1lf"), pr->GetPlannedSpeed()).mb_str());
       }
-      if (pr->m_manual_etd) {
+      if (pr->m_manual_etd && pr->GetManualETD().IsValid()) {
         pugi::xml_attribute use = child.append_attribute("etd");
+        // Currently, the serialization format is YYYY-MM-DDTHH:MM:SS
+        // without timezone information, e.g., etd="2025-04-03T20:00:27"
+        // TODO: serialize using ISO 8601 or RFC 3339 format to ensure
+        // the serialized date/time is unambiguous.
         use.set_value(pr->GetManualETD().FormatISOCombined().mb_str());
       }
     }
@@ -862,7 +864,7 @@ static bool GPXCreateTrk(pugi::xml_node node, Track *pTrack,
   }
 
   // Hyperlinks
-  HyperlinkList *linklist = pTrack->m_HyperlinkList;
+  HyperlinkList *linklist = pTrack->m_TrackHyperlinkList;
   if (linklist && linklist->GetCount()) {
     wxHyperlinkListNode *linknode = linklist->GetFirst();
     while (linknode) {
@@ -1137,10 +1139,9 @@ bool InsertRouteA(Route *pTentRoute, NavObjectCollection1 *navobj) {
         prp->m_bIsInRoute =
             false;  // Take this point out of this (and only) track/route
         if (!prp->IsShared()) {
-          navobj->m_bSkipChangeSetUpdate = true;
-          NavObjectChanges::getInstance()->DeleteWayPoint(prp);
-          navobj->m_bSkipChangeSetUpdate = false;
-          delete prp;
+          if (navobj) {
+            delete prp;
+          }
         }
       }
 
@@ -1208,17 +1209,14 @@ bool InsertWpt(RoutePoint *pWp, bool overwrite) {
   return res;
 }
 
-static void UpdateRouteA(Route *pTentRoute, NavObjectCollection1 *navobj,
-                         NavObjectChanges *nav_obj_changes) {
+static void UpdateRouteA(Route *pTentRoute, NavObjectCollection1 *navobj) {
   if (!pTentRoute) return;
   if (pTentRoute->GetnPoints() < 2) return;
 
   // first delete the route to be modified if exists
   Route *pExisting = ::RouteExists(pTentRoute->m_GUID);
   if (pExisting) {
-    navobj->m_bSkipChangeSetUpdate = true;
-    g_pRouteMan->DeleteRoute(pExisting, nav_obj_changes);
-    navobj->m_bSkipChangeSetUpdate = false;
+    g_pRouteMan->DeleteRoute(pExisting);
   }
 
   // create a new route
@@ -1365,9 +1363,9 @@ bool NavObjectCollection1::CreateNavObjGPXTracks(void) {
 bool NavObjectCollection1::CreateAllGPXObjects() {
   SetRootGPXNode();
 
-  CreateNavObjGPXPoints();
-  CreateNavObjGPXRoutes();
-  CreateNavObjGPXTracks();
+  // CreateNavObjGPXPoints();
+  // CreateNavObjGPXRoutes();
+  //  CreateNavObjGPXTracks();
 
   return true;
 }
@@ -1488,6 +1486,7 @@ bool NavObjectCollection1::LoadAllGPXObjects(bool b_full_viz,
           WaypointExists(pWp->GetName(), pWp->m_lat, pWp->m_lon);
       if (!pExisting) {
         if (NULL != pWayPointMan) pWayPointMan->AddRoutePoint(pWp);
+        NavObj_dB::GetInstance().InsertRoutePoint(pWp);
         pSelect->AddSelectableRoutePoint(pWp->m_lat, pWp->m_lon, pWp);
         LLBBox wptbox;
         wptbox.Set(pWp->m_lat, pWp->m_lon, pWp->m_lat, pWp->m_lon);
@@ -1498,13 +1497,15 @@ bool NavObjectCollection1::LoadAllGPXObjects(bool b_full_viz,
       }
     } else if (!strcmp(object.name(), "trk")) {
       Track *pTrack = GPXLoadTrack1(object, b_full_viz, false, false, 0);
-      if (InsertTrack(pTrack) && b_compute_bbox && pTrack->IsVisible()) {
-        // BBox.Expand(pTrack->GetBBox());
+      if (InsertTrack(pTrack)) {
+        NavObj_dB::GetInstance().InsertTrack(pTrack);
       }
     } else if (!strcmp(object.name(), "rte")) {
       Route *pRoute = GPXLoadRoute1(object, b_full_viz, false, false, 0, false);
-      if (InsertRouteA(pRoute, this) && b_compute_bbox && pRoute->IsVisible()) {
-        BBox.Expand(pRoute->GetBBox());
+      if (InsertRouteA(pRoute, this)) {
+        NavObj_dB::GetInstance().InsertRoute(pRoute);
+        if (b_compute_bbox && pRoute->IsVisible())
+          BBox.Expand(pRoute->GetBBox());
       }
     }
   }
@@ -1551,302 +1552,47 @@ int NavObjectCollection1::LoadAllGPXObjectsAsLayer(int layer_id,
   return n_obj;
 }
 
-NavObjectChanges::NavObjectChanges(wxString file_name)
-    : NavObjectCollection1() {
-  m_filename = file_name;
-  m_changes_file = fopen(m_filename.mb_str(), "a");
-  m_bdirty = false;
-}
+bool NavObjectCollection1::LoadAllGPXTrackObjects() {
+  pugi::xml_node objects = this->child("gpx");
 
-NavObjectChanges::~NavObjectChanges() {
-  if (m_changes_file) fclose(m_changes_file);
-  if (::wxFileExists(m_filename)) ::wxRemoveFile(m_filename);
-}
-
-void NavObjectChanges::AddRoute(Route *pr, const char *action) {
-  SetRootGPXNode();
-
-  pugi::xml_node object = root().append_child("rte");
-  GPXCreateRoute(object, pr);
-
-  pugi::xml_node xchild = object.child("extensions");
-  // FIXME  What if extensions do not exist?
-  pugi::xml_node child = xchild.append_child("opencpn:action");
-  child.append_child(pugi::node_pcdata).set_value(action);
-
-  if (m_changes_file) {
-    pugi::xml_writer_file writer(m_changes_file);
-    object.print(writer, " ");
-    fflush(m_changes_file);
-    m_bdirty = true;
-  }
-}
-
-void NavObjectChanges::AddTrack(Track *pr, const char *action) {
-  SetRootGPXNode();
-
-  pugi::xml_node object = root().append_child("trk");
-  GPXCreateTrk(object, pr, RT_OUT_NO_RTPTS);  // emit a void track, no waypoints
-
-  pugi::xml_node xchild = object.child("extensions");
-  pugi::xml_node child = xchild.append_child("opencpn:action");
-  child.append_child(pugi::node_pcdata).set_value(action);
-
-  if (m_changes_file) {
-    pugi::xml_writer_file writer(m_changes_file);
-    object.print(writer, " ");
-    fflush(m_changes_file);
-    m_bdirty = true;
-  }
-}
-
-void NavObjectChanges::AddWP(RoutePoint *pWP, const char *action) {
-  SetRootGPXNode();
-
-  pugi::xml_node object = root().append_child("wpt");
-
-  int flags = OPT_WPT;
-  // If the action is a simple deletion, simplify the output flags
-  if (!strncmp(action, "delete", 6)) flags = OUT_GUID | OUT_NAME;
-
-  GPXCreateWpt(object, pWP, flags);
-
-  pugi::xml_node xchild = object.child("extensions");
-  pugi::xml_node child = xchild.append_child("opencpn:action");
-  child.append_child(pugi::node_pcdata).set_value(action);
-
-  if (m_changes_file) {
-    pugi::xml_writer_file writer(m_changes_file);
-    object.print(writer, " ");
-    fflush(m_changes_file);
-    m_bdirty = true;
-  }
-}
-
-void NavObjectChanges::AddTrackPoint(TrackPoint *pWP, const char *action,
-                                     const wxString &parent_GUID) {
-  SetRootGPXNode();
-
-  pugi::xml_node object = root().append_child("tkpt");
-  GPXCreateTrkpt(object, pWP, OPT_TRACKPT);
-
-  pugi::xml_node xchild = object.append_child("extensions");
-
-  pugi::xml_node child = xchild.append_child("opencpn:action");
-  child.append_child(pugi::node_pcdata).set_value(action);
-
-  pugi::xml_node gchild = xchild.append_child("opencpn:track_GUID");
-  gchild.append_child(pugi::node_pcdata).set_value(parent_GUID.mb_str());
-
-  if (m_changes_file) {
-    pugi::xml_writer_file writer(m_changes_file);
-    object.print(writer, " ");
-    fflush(m_changes_file);
-    m_bdirty = true;
-  }
-}
-
-bool NavObjectChanges::ApplyChanges(void) {
-  // Let's reconstruct the unsaved changes
-
-  pugi::xml_node object = this->first_child();
-
-  while (strlen(object.name())) {
-    if (!strcmp(object.name(), "wpt") && pWayPointMan) {
-      RoutePoint *pWp = ::GPXLoadWaypoint1(object, _T("circle"), _T(""), false,
-                                           false, false, 0);
-
-      pWp->m_bIsolatedMark = true;
-      RoutePoint *pExisting = WaypointExists(pWp->m_GUID);
-
-      pugi::xml_node xchild = object.child("extensions");
-      pugi::xml_node child = xchild.child("opencpn:action");
-
-      if (!strcmp(child.first_child().value(), "add")) {
-        if (!pExisting) pWayPointMan->AddRoutePoint(pWp);
-        pSelect->AddSelectableRoutePoint(pWp->m_lat, pWp->m_lon, pWp);
-      }
-
-      else if (!strcmp(child.first_child().value(), "update")) {
-        if (pExisting) {
-          pWayPointMan->RemoveRoutePoint(pExisting);
-          pWayPointMan->DestroyWaypoint(pExisting, false);
-          delete pExisting;
-          pWayPointMan->AddRoutePoint(pWp);
-          pSelect->AddSelectableRoutePoint(pWp->m_lat, pWp->m_lon, pWp);
-        } else {
-          delete pWp;
-        }
-      }
-
-      else if (!strcmp(child.first_child().value(), "delete")) {
-        if (pExisting) pWayPointMan->DestroyWaypoint(pExisting, false);
-        delete pExisting;
-        delete pWp;
-      } else
-        delete pWp;
-    } else if (!strcmp(object.name(), "trk") && g_pRouteMan) {
-      Track *pTrack = GPXLoadTrack1(object, false, false, false, 0);
-
-      if (pTrack) {
-        pugi::xml_node xchild = object.child("extensions");
-        pugi::xml_node child = xchild.child("opencpn:action");
-
-        Track *pExisting = TrackExists(pTrack->m_GUID);
-        if (!strcmp(child.first_child().value(), "update")) {
-          if (pExisting) {
-            pExisting->SetName(pTrack->GetName());
-            pExisting->m_TrackStartString = pTrack->m_TrackStartString;
-            pExisting->m_TrackEndString = pTrack->m_TrackEndString;
-          }
-          delete pTrack;
-        }
-
-        else if (!strcmp(child.first_child().value(), "delete")) {
-          if (pExisting) {
-            m_bSkipChangeSetUpdate = true;
-            // evt_delete_track.Notify(std::make_shared<Track>(*pExisting), "");
-            // // Why were we doing this? pExisting got destroyed immediately...
-            g_pRouteMan->DeleteTrack(pExisting);
-            m_bSkipChangeSetUpdate = false;
-          }
-          delete pTrack;
-        }
-
-        else if (!strcmp(child.first_child().value(), "add")) {
-          if (!pExisting) ::InsertTrack(pTrack, true);
-        }
-
-        else
-          delete pTrack;
-      }
+  for (pugi::xml_node object = objects.first_child(); object;
+       object = object.next_sibling()) {
+    if (!strcmp(object.name(), "trk")) {
+      Track *pTrack = GPXLoadTrack1(object, true, false, false, 0);
+      InsertTrack(pTrack);
     }
-
-    else if (!strcmp(object.name(), "rte") && g_pRouteMan) {
-      Route *pRoute =
-          GPXLoadRoute1(object, false, false, false, 0, true, false);
-
-      if (pRoute) {
-        Route *pExisting = RouteExists(pRoute->m_GUID);
-        pugi::xml_node xchild = object.child("extensions");
-        pugi::xml_node child = xchild.child("opencpn:action");
-
-        if (!strcmp(child.first_child().value(), "add")) {
-          delete pRoute;
-          pRoute = GPXLoadRoute1(object, false, false, false, 0, true, true);
-          ::UpdateRouteA(pRoute, this, this);
-          delete pRoute;
-        }
-
-        else if (!strcmp(child.first_child().value(), "update")) {
-          if (pExisting) {
-            delete pRoute;
-            pRoute = GPXLoadRoute1(object, false, false, false, 0, true, true);
-            ::UpdateRouteA(pRoute, this, this);
-          }
-          delete pRoute;
-        }
-
-        else if (!strcmp(child.first_child().value(), "delete")) {
-          if (pExisting) {
-            m_bSkipChangeSetUpdate = true;
-            // evt_delete_route.Notify(std::make_shared<Route>(*pExisting), "");
-            // // Why were we doing this? pExisting got destroyed immediately...
-            g_pRouteMan->DeleteRoute(pExisting, this);
-            m_bSkipChangeSetUpdate = false;
-          }
-          delete pRoute;
-        }
-
-        else {
-          delete pRoute;
-        }
-      }
-    } else if (!strcmp(object.name(), "tkpt") && pWayPointMan) {
-      TrackPoint *pWp = ::GPXLoadTrackPoint1(object);
-
-      //                        RoutePoint *pExisting = WaypointExists(
-      //                        pWp->GetName(), pWp->m_lat, pWp->m_lon );
-
-      pugi::xml_node xchild = object.child("extensions");
-      pugi::xml_node child = xchild.child("opencpn:action");
-
-      pugi::xml_node guid_child = xchild.child("opencpn:track_GUID");
-      wxString track_GUID(guid_child.first_child().value(), wxConvUTF8);
-
-      Track *pExistingTrack = TrackExists(track_GUID);
-
-      if (!strcmp(child.first_child().value(), "add") && pExistingTrack &&
-          pWp) {
-        pExistingTrack->AddPoint(pWp);
-        pWp->m_GPXTrkSegNo = pExistingTrack->GetCurrentTrackSeg() + 1;
-      } else
-        delete pWp;
-    }
-
-    object = object.next_sibling();
-  }
-  // Check to make sure we haven't loaded tracks with less than 2 points
-  auto it = g_TrackList.begin();
-  while (it != g_TrackList.end()) {
-    Track *pTrack = *it;
-    if (pTrack->GetnPoints() < 2) {
-      auto to_erase = it;
-      --it;
-      g_TrackList.erase(to_erase);
-      delete pTrack;
-    }
-    ++it;
   }
 
   return true;
 }
 
-void NavObjectChanges::AddNewRoute(Route *pr) {
-  //    if( pr->m_bIsInLayer )
-  //        return true;
-  if (!m_bSkipChangeSetUpdate) AddRoute(pr, "add");
+bool NavObjectCollection1::LoadAllGPXRouteObjects() {
+  pugi::xml_node objects = this->child("gpx");
+
+  for (pugi::xml_node object = objects.first_child(); object;
+       object = object.next_sibling()) {
+    if (!strcmp(object.name(), "rte")) {
+      Route *route = GPXLoadRoute1(object, true, false, false, 0, false, true);
+      InsertRouteA(route, nullptr);
+    }
+  }
+
+  return true;
 }
 
-void NavObjectChanges::UpdateRoute(Route *pr) {
-  //    if( pr->m_bIsInLayer ) return true;
-  if (!m_bSkipChangeSetUpdate) AddRoute(pr, "update");
-}
+bool NavObjectCollection1::LoadAllGPXPointObjects() {
+  pugi::xml_node objects = this->child("gpx");
 
-void NavObjectChanges::DeleteConfigRoute(Route *pr) {
-  //    if( pr->m_bIsInLayer )
-  //        return true;
-  if (!m_bSkipChangeSetUpdate) AddRoute(pr, "delete");
-}
-
-void NavObjectChanges::AddNewTrack(Track *pt) {
-  if (!pt->m_bIsInLayer && !m_bSkipChangeSetUpdate) AddTrack(pt, "add");
-}
-
-void NavObjectChanges::UpdateTrack(Track *pt) {
-  if (pt->m_bIsInLayer && !m_bSkipChangeSetUpdate) AddTrack(pt, "update");
-}
-
-void NavObjectChanges::DeleteConfigTrack(Track *pt) {
-  if (!pt->m_bIsInLayer && !m_bSkipChangeSetUpdate) AddTrack(pt, "delete");
-}
-
-void NavObjectChanges::AddNewWayPoint(RoutePoint *pWP, int crm) {
-  if (!pWP->m_bIsInLayer && pWP->m_bIsolatedMark && !m_bSkipChangeSetUpdate)
-    AddWP(pWP, "add");
-}
-
-void NavObjectChanges::UpdateWayPoint(RoutePoint *pWP) {
-  if (!pWP->m_bIsInLayer && !m_bSkipChangeSetUpdate) AddWP(pWP, "update");
-}
-
-void NavObjectChanges::DeleteWayPoint(RoutePoint *pWP) {
-  if (!pWP->m_bIsInLayer && !m_bSkipChangeSetUpdate) AddWP(pWP, "delete");
-}
-
-void NavObjectChanges::AddNewTrackPoint(TrackPoint *pWP,
-                                        const wxString &parent_GUID) {
-  if (!m_bSkipChangeSetUpdate) AddTrackPoint(pWP, "add", parent_GUID);
+  for (pugi::xml_node object = objects.first_child(); object;
+       object = object.next_sibling()) {
+    if (!strcmp(object.name(), "wpt")) {
+      RoutePoint *rp =
+          GPXLoadWaypoint1(object, "circle", "", false, false, false, 0);
+      rp->m_bIsolatedMark = true;
+      pWayPointMan->AddRoutePoint(rp);
+    }
+  }
+  return true;
 }
 
 RoutePoint *WaypointExists(const wxString &name, double lat, double lon) {
