@@ -26,6 +26,7 @@
 #include <memory>
 #include <vector>
 #include <string>
+#include <iomanip>
 #include <wx/dir.h>
 
 #include "model/base_platform.h"
@@ -1452,6 +1453,7 @@ bool NavObj_dB::UpdateDBRoutePointAttributes(RoutePoint* point) {
     if (point->GetManualETD().IsValid()) etd = point->GetManualETD().GetTicks();
     sqlite3_bind_int(stmt, 8, etd);
     sqlite3_bind_text(stmt, 9, "type", -1, SQLITE_TRANSIENT);
+    std::string timit = point->m_timestring.ToStdString().c_str();
     sqlite3_bind_text(stmt, 10, point->m_timestring.ToStdString().c_str(), -1,
                       SQLITE_TRANSIENT);
     sqlite3_bind_double(stmt, 11, point->m_WaypointArrivalRadius);
@@ -1674,7 +1676,8 @@ bool NavObj_dB::LoadAllRoutes() {
         "p.visibility, "
         "p.viz_name, "
         "p.shared, "
-        "p.isolated "
+        "p.isolated, "
+        "p.created_at "
         "FROM routepoints_link tp "
         "JOIN routepoints p ON p.guid = tp.point_guid "
         "WHERE tp.route_guid = ? "
@@ -1749,6 +1752,8 @@ bool NavObj_dB::LoadAllRoutes() {
       int viz_name = sqlite3_column_int(stmtp, col++);
       int shared = sqlite3_column_int(stmtp, col++);
       int isolated = sqlite3_column_int(stmtp, col++);
+      std::string point_created_at =
+          reinterpret_cast<const char*>(sqlite3_column_text(stmtp, col++));
 
       RoutePoint* point;
       // RoutePoint exists already, in another route?
@@ -1787,6 +1792,16 @@ bool NavObj_dB::LoadAllRoutes() {
         point->SetShared(shared == 1);
         point->m_bIsolatedMark = (isolated == 1);
 
+        if (point_created_at.size()) {
+          // Convert from sqLite default date/time format to wxDateTime
+          // sqLite format uses UTC, so conversion to epoch_time is clear.
+          std::tm tm = {};
+          std::istringstream ss(point_created_at);
+          ss >> std::get_time(&tm, "%Y-%m-%d %H:%M:%S");
+          time_t epoch_time = mktime(&tm);
+          point->m_CreateTimeX = epoch_time;
+        }
+
         //    Add the point HTML links
         const char* sqlh = R"(
         SELECT guid, html_link, html_description, html_type
@@ -1916,7 +1931,8 @@ bool NavObj_dB::LoadAllPoints() {
       "p.visibility, "
       "p.viz_name, "
       "p.shared, "
-      "p.isolated "
+      "p.isolated, "
+      "p.created_at "
       "FROM routepoints p ";
 
   RoutePoint* point = nullptr;
@@ -1964,6 +1980,8 @@ bool NavObj_dB::LoadAllPoints() {
     int viz_name = sqlite3_column_int(stmtp, col++);
     int shared = sqlite3_column_int(stmtp, col++);
     int isolated = sqlite3_column_int(stmtp, col++);
+    std::string point_created_at =
+        reinterpret_cast<const char*>(sqlite3_column_text(stmtp, col++));
 
     if (isolated) {
       point =
@@ -1978,8 +1996,8 @@ bool NavObj_dB::LoadAllPoints() {
       point->m_fWaypointRangeRingsStep = range_ring_step;
       point->m_iWaypointRangeRingsStepUnits = range_ring_units;
       point->SetShowWaypointRangeRings(range_ring_visible == 1);
-      // TODO
-      //  point->m_wxcWaypointRangeRingsColour = range_ring_color;
+      
+      point->m_wxcWaypointRangeRingsColour.Set(range_ring_color);
 
       point->SetScaMin(scamin);
       point->SetScaMax(scamax);
@@ -1990,11 +2008,16 @@ bool NavObj_dB::LoadAllPoints() {
       point->SetShared(shared == 1);
       point->m_bIsolatedMark = (isolated == 1);
 
-      if (point_time_string.size()) {
-        wxString sdt(point_time_string.c_str());
-        point->m_timestring = sdt;
-        ParseGPXDateTime(point->m_CreateTimeX, sdt);
+      if (point_created_at.size()) {
+        // Convert from sqLite default date/time format to wxDateTime
+        // sqLite format uses UTC, so conversion to epoch_time is clear.
+        std::tm tm = {};
+        std::istringstream ss(point_created_at);
+        ss >> std::get_time(&tm, "%Y-%m-%d %H:%M:%S");
+        time_t epoch_time = mktime(&tm);
+        point->m_CreateTimeX = epoch_time;
       }
+
       // Add it here
       pWayPointMan->AddRoutePoint(point);
       pSelect->AddSelectableRoutePoint(point->m_lat, point->m_lon, point);
