@@ -34,7 +34,6 @@
 #include <wx/math.h>
 #include <wx/string.h>
 #include <wx/translation.h>
-#include <wx/utils.h>
 
 #include "model/navutil_base.h"
 #include "model/own_ship.h"
@@ -563,18 +562,6 @@ double vVectorMagnitude(pVector2D v0) {
   return (dMagnitude);
 }
 
-// This function parses a string containing a GPX time representation
-// and returns a wxDateTime containing the UTC corresponding to the
-// input. The function return value is a pointer past the last valid
-// character parsed (if successful) or NULL (if the string is invalid).
-//
-// Valid GPX time strings are in ISO 8601 format as follows:
-//
-//   [-]<YYYY>-<MM>-<DD>T<hh>:<mm>:<ss>Z|(+|-<hh>:<mm>)
-//
-// For example, 2010-10-30T14:34:56Z and 2010-10-30T14:34:56-04:00
-// are the same time. The first is UTC and the second is EDT.
-
 const wxChar *ParseGPXDateTime(wxDateTime &dt, const wxChar *datetime) {
   long sign, hrs_west, mins_west;
   const wxChar *end;
@@ -678,51 +665,6 @@ wxString formatTimeDelta(wxLongLong secs) {
   return formatTimeDelta(span);
 }
 
-// RFC4122 version 4 compliant random UUIDs generator.
-wxString GpxDocument::GetUUID(void) {
-  wxString str;
-  struct {
-    int time_low;
-    int time_mid;
-    int time_hi_and_version;
-    int clock_seq_hi_and_rsv;
-    int clock_seq_low;
-    int node_hi;
-    int node_low;
-  } uuid;
-
-  uuid.time_low = GetRandomNumber(
-      0, 2147483647);  // FIXME: the max should be set to something like
-                       // MAXINT32, but it doesn't compile un gcc...
-  uuid.time_mid = GetRandomNumber(0, 65535);
-  uuid.time_hi_and_version = GetRandomNumber(0, 65535);
-  uuid.clock_seq_hi_and_rsv = GetRandomNumber(0, 255);
-  uuid.clock_seq_low = GetRandomNumber(0, 255);
-  uuid.node_hi = GetRandomNumber(0, 65535);
-  uuid.node_low = GetRandomNumber(0, 2147483647);
-
-  /* Set the two most significant bits (bits 6 and 7) of the
-   * clock_seq_hi_and_rsv to zero and one, respectively. */
-  uuid.clock_seq_hi_and_rsv = (uuid.clock_seq_hi_and_rsv & 0x3F) | 0x80;
-
-  /* Set the four most significant bits (bits 12 through 15) of the
-   * time_hi_and_version field to 4 */
-  uuid.time_hi_and_version = (uuid.time_hi_and_version & 0x0fff) | 0x4000;
-
-  str.Printf(_T("%08x-%04x-%04x-%02x%02x-%04x%08x"), uuid.time_low,
-             uuid.time_mid, uuid.time_hi_and_version, uuid.clock_seq_hi_and_rsv,
-             uuid.clock_seq_low, uuid.node_hi, uuid.node_low);
-
-  return str;
-}
-
-int GpxDocument::GetRandomNumber(int range_min, int range_max) {
-  long u = (long)wxRound(
-      ((double)rand() / ((double)(RAND_MAX) + 1) * (range_max - range_min)) +
-      range_min);
-  return (int)u;
-}
-
 /****************************************************************************/
 // Modified from the code posted by Andy Ross at
 //     http://www.mail-archive.com/flightgear-devel@flightgear.org/msg06702.html
@@ -834,3 +776,17 @@ double toMagnetic(double deg_true, double variation) {
   else
     return degm >= 0. ? degm : degm + 360.;
 }
+
+// Function to remove invalid Windows filename characters from a wxString
+wxString SanitizeFileName(const wxString &input) {
+  // List of invalid characters for Windows filenames
+  static const wxString invalidChars = wxT("<>:\"/\\|?*");
+  wxString result;
+  for (wxUniChar ch : input) {
+    if (invalidChars.Contains(ch))
+      result += wxT('_');
+    else
+      result += ch;
+  }
+  return result;
+}
