@@ -37,13 +37,13 @@
 #pragma hdrstop
 #endif
 
-
 //************************************************************************************************************************
 // History of barometic pressure
 //************************************************************************************************************************
 
 DashboardInstrument_BaroHistory::DashboardInstrument_BaroHistory(
-    wxWindow* parent, wxWindowID id, wxString title, InstrumentProperties* Properties)
+    wxWindow* parent, wxWindowID id, wxString title,
+    InstrumentProperties* Properties)
     : DashboardInstrument(parent, id, title, OCPN_DBP_STC_MDA, Properties) {
   SetDrawSoloInPane(true);
 
@@ -57,9 +57,9 @@ DashboardInstrument_BaroHistory::DashboardInstrument_BaroHistory(
   int w, h;
   wxFont f;
   if (m_Properties)
-      f = m_Properties->m_DataFont.GetChosenFont();
+    f = m_Properties->m_DataFont.GetChosenFont();
   else
-      f = g_pFontData->GetChosenFont();
+    f = g_pFontData->GetChosenFont();
   dc.GetTextExtent("hPa----", &w, &h, 0, 0, &f);
   m_TopLineHeight = wxMax(30, h);
   m_SpdRecCnt = 0;
@@ -87,9 +87,9 @@ wxSize DashboardInstrument_BaroHistory::GetSize(int orient, wxSize hint) {
   int w;
   wxFont f;
   if (m_Properties)
-      f = m_Properties->m_TitleFont.GetChosenFont();
+    f = m_Properties->m_TitleFont.GetChosenFont();
   else
-      f = g_pFontTitle->GetChosenFont();
+    f = g_pFontTitle->GetChosenFont();
   dc.GetTextExtent(m_title, &w, &m_TitleHeight, 0, 0, &f);
   if (orient == wxHORIZONTAL) {
     return wxSize(DefaultWidth, wxMax(m_TitleHeight + 140, hint.y));
@@ -100,7 +100,7 @@ wxSize DashboardInstrument_BaroHistory::GetSize(int orient, wxSize hint) {
 }
 void DashboardInstrument_BaroHistory::SetData(DASH_CAP st, double data,
                                               wxString unit) {
-  if (st == OCPN_DBP_STC_MDA && data > 700.0 && data < 2000.0 ) {
+  if (st == OCPN_DBP_STC_MDA && data > 700.0 && data < 2000.0) {
     if (m_SetNewData < 1) {
       m_Press = data;
       if (m_SpdRecCnt++ <= 5) m_SpdStartVal += data;
@@ -108,12 +108,12 @@ void DashboardInstrument_BaroHistory::SetData(DASH_CAP st, double data,
       if (m_SpdRecCnt == 5) {
         m_Press = m_SpdStartVal / 5;
       }
-      // start working after we collected 5 records each, as start values for the
-      // smoothed curves
+      // start working after we collected 5 records each, as start values for
+      // the smoothed curves
       if (m_SpdRecCnt > 5) {
         m_IsRunning = true;
         m_SampleCount = m_SampleCount < BARO_RECORD_COUNT ? m_SampleCount + 1
-          : BARO_RECORD_COUNT;
+                                                          : BARO_RECORD_COUNT;
         m_MaxPress = 0;
         ;
         // data shifting
@@ -131,8 +131,8 @@ void DashboardInstrument_BaroHistory::SetData(DASH_CAP st, double data,
           m_ExpSmoothArrayPressure[BARO_RECORD_COUNT - 2] = m_Press;
         }
         m_ExpSmoothArrayPressure[BARO_RECORD_COUNT - 1] =
-          alpha * m_ArrayPressHistory[BARO_RECORD_COUNT - 2] +
-          (1 - alpha) * m_ExpSmoothArrayPressure[BARO_RECORD_COUNT - 2];
+            alpha * m_ArrayPressHistory[BARO_RECORD_COUNT - 2] +
+            (1 - alpha) * m_ExpSmoothArrayPressure[BARO_RECORD_COUNT - 2];
         m_ArrayRecTime[BARO_RECORD_COUNT - 1] = wxDateTime::Now().GetTm();
         m_MaxPress = wxMax(m_Press, m_MaxPress);
 
@@ -146,8 +146,8 @@ void DashboardInstrument_BaroHistory::SetData(DASH_CAP st, double data,
         // Wait two turns until new data.
         m_SetNewData = 2;
       }
-    }
-    else m_SetNewData--;
+    } else
+      m_SetNewData--;
   } else {
     //  Check for watchdog timeout
     if (isnan(data)) m_Press = data;
@@ -172,15 +172,13 @@ void DashboardInstrument_BaroHistory::DrawWindSpeedScale(wxGCDC* dc) {
   wxColour cl;
   int width, height;
   cl = wxColour(61, 61, 204, 255);
-  if (m_Properties)
-  {
-      dc->SetTextForeground(GetColourSchemeFont(m_Properties->m_SmallFont.GetColour()));
-      dc->SetFont(m_Properties->m_SmallFont.GetChosenFont());
-  }
-  else
-  {
-      dc->SetTextForeground(GetColourSchemeFont(g_pFontSmall->GetColour()));
-      dc->SetFont(g_pFontSmall->GetChosenFont());
+  if (m_Properties) {
+    dc->SetTextForeground(
+        GetColourSchemeFont(m_Properties->m_SmallFont.GetColour()));
+    dc->SetFont(m_Properties->m_SmallFont.GetChosenFont());
+  } else {
+    dc->SetTextForeground(GetColourSchemeFont(g_pFontSmall->GetColour()));
+    dc->SetFont(g_pFontSmall->GetChosenFont());
   }
   // round m_MaxPress up to the next hpa ...
   if (m_MaxPress > 1100) m_MaxPress = 1100;
@@ -220,40 +218,40 @@ void DashboardInstrument_BaroHistory::DrawWindSpeedScale(wxGCDC* dc) {
   }
   wxFont f;
   if (m_Properties)
-      f = m_Properties->m_SmallFont.GetChosenFont();
+    f = m_Properties->m_SmallFont.GetChosenFont();
   else
-      f = g_pFontSmall->GetChosenFont();
+    f = g_pFontSmall->GetChosenFont();
   dc->GetTextExtent(label1, &m_LeftLegend, &height, 0, 0, &f);
   dc->DrawText(label1, 4, (int)(m_TopLineHeight - height / 2));
   if (m_Properties)
-      f = m_Properties->m_SmallFont.GetChosenFont();
+    f = m_Properties->m_SmallFont.GetChosenFont();
   else
-      f = g_pFontSmall->GetChosenFont();
+    f = g_pFontSmall->GetChosenFont();
   dc->GetTextExtent(label2, &width, &height, 0, 0, &f);
   dc->DrawText(label2, 4,
                (int)(m_TopLineHeight + m_DrawAreaRect.height / 4 - height / 2));
   m_LeftLegend = wxMax(width, m_LeftLegend);
   if (m_Properties)
-      f = m_Properties->m_SmallFont.GetChosenFont();
+    f = m_Properties->m_SmallFont.GetChosenFont();
   else
-      f = g_pFontSmall->GetChosenFont();
+    f = g_pFontSmall->GetChosenFont();
   dc->GetTextExtent(label3, &width, &height, 0, 0, &f);
   dc->DrawText(label3, 4,
                (int)(m_TopLineHeight + m_DrawAreaRect.height / 2 - height / 2));
   m_LeftLegend = wxMax(width, m_LeftLegend);
   if (m_Properties)
-      f = m_Properties->m_SmallFont.GetChosenFont();
+    f = m_Properties->m_SmallFont.GetChosenFont();
   else
-      f = g_pFontSmall->GetChosenFont();
+    f = g_pFontSmall->GetChosenFont();
   dc->GetTextExtent(label4, &width, &height, 0, 0, &f);
   dc->DrawText(
       label4, 4,
       (int)(m_TopLineHeight + m_DrawAreaRect.height * 0.75 - height / 2));
   m_LeftLegend = wxMax(width, m_LeftLegend);
   if (m_Properties)
-      f = m_Properties->m_SmallFont.GetChosenFont();
+    f = m_Properties->m_SmallFont.GetChosenFont();
   else
-      f = g_pFontSmall->GetChosenFont();
+    f = g_pFontSmall->GetChosenFont();
   dc->GetTextExtent(label5, &width, &height, 0, 0, &f);
   dc->DrawText(label5, 4,
                (int)(m_TopLineHeight + m_DrawAreaRect.height - height / 2));
@@ -321,44 +319,40 @@ void DashboardInstrument_BaroHistory::DrawForeground(wxGCDC* dc) {
   //---------------------------------------------------------------------------------
   // Pressure
   //---------------------------------------------------------------------------------
-  //col = wxColour(61, 61, 204, 255);  // blue, opaque
+  // col = wxColour(61, 61, 204, 255);  // blue, opaque
   wxFont f;
-  if (m_Properties)
-  {
-      dc->SetFont(m_Properties->m_DataFont.GetChosenFont());
-      dc->SetTextForeground(GetColourSchemeFont(m_Properties->m_DataFont.GetColour()));
-  }
-  else
-  {
-      dc->SetFont(g_pFontData->GetChosenFont());
-      dc->SetTextForeground(GetColourSchemeFont(g_pFontData->GetColour()));
+  if (m_Properties) {
+    dc->SetFont(m_Properties->m_DataFont.GetChosenFont());
+    dc->SetTextForeground(
+        GetColourSchemeFont(m_Properties->m_DataFont.GetColour()));
+  } else {
+    dc->SetFont(g_pFontData->GetChosenFont());
+    dc->SetTextForeground(GetColourSchemeFont(g_pFontData->GetColour()));
   }
   if (!std::isnan(m_Press))
     WindSpeed = wxString::Format(_T("hPa %3.1f  "), m_Press);
   else
     WindSpeed = wxString::Format(_T("hPa ---  "));
   if (m_Properties)
-      f = m_Properties->m_DataFont.GetChosenFont();
+    f = m_Properties->m_DataFont.GetChosenFont();
   else
-      f = g_pFontData->GetChosenFont();
+    f = g_pFontData->GetChosenFont();
   dc->GetTextExtent(WindSpeed, &degw, &degh, 0, 0, &f);
 
   dc->DrawText(WindSpeed, m_LeftLegend + 3, 1);
-  if (m_Properties)
-  {
-      dc->SetFont(m_Properties->m_LabelFont.GetChosenFont());
-      dc->SetTextForeground(GetColourSchemeFont(m_Properties->m_LabelFont.GetColour()));
-  }
-  else
-  {
-      dc->SetFont(g_pFontLabel->GetChosenFont());
-      dc->SetTextForeground(GetColourSchemeFont(g_pFontLabel->GetColour()));
+  if (m_Properties) {
+    dc->SetFont(m_Properties->m_LabelFont.GetChosenFont());
+    dc->SetTextForeground(
+        GetColourSchemeFont(m_Properties->m_LabelFont.GetColour()));
+  } else {
+    dc->SetFont(g_pFontLabel->GetChosenFont());
+    dc->SetTextForeground(GetColourSchemeFont(g_pFontLabel->GetColour()));
   }
   int labelw, labelh;
   if (m_Properties)
-      f = m_Properties->m_LabelFont.GetChosenFont();
+    f = m_Properties->m_LabelFont.GetChosenFont();
   else
-      f = g_pFontLabel->GetChosenFont();
+    f = g_pFontLabel->GetChosenFont();
   dc->GetTextExtent(WindSpeed, &labelw, &labelh, 0, 0, &f);
   // determine the time range of the available data (=oldest data value)
   int i = 0;
@@ -373,13 +367,13 @@ void DashboardInstrument_BaroHistory::DrawForeground(wxGCDC* dc) {
     hour = localTime.GetHour();
   }
   m_DrawAreaRect.SetWidth(m_WindowRect.width - 3 - m_LeftLegend -
-    m_RightLegend);
+                          m_RightLegend);
   m_ratioW = double(m_DrawAreaRect.width) / (BARO_RECORD_COUNT - 1);
 
   dc->DrawText(wxString::Format(
                    _(" Max %.1f since %02d:%02d  Overall Max %.1f Min %.1f "),
                    m_MaxPress, hour, min, m_TotalMaxPress, m_TotalMinPress),
-                   m_LeftLegend + 2 + degw, m_TopLineHeight - 2 - labelh);
+               m_LeftLegend + 2 + degw, m_TopLineHeight - 2 - labelh);
   pen.SetStyle(wxPENSTYLE_SOLID);
   pen.SetColour(wxColour(61, 61, 204, 255));  // blue, opaque
   pen.SetWidth(3);
@@ -390,8 +384,9 @@ void DashboardInstrument_BaroHistory::DrawForeground(wxGCDC* dc) {
   wxPoint bdDraw[BARO_RECORD_COUNT + 2];
   int ls = 0;
   bdDraw[ls].x = 1 * m_ratioW + 3 + m_LeftLegend;
-  bdDraw[ls].y = m_TopLineHeight + m_DrawAreaRect.height -
-    ((m_ArrayPressHistory[1] - (double)m_TotalMinPress + 18) * ratioH);
+  bdDraw[ls].y =
+      m_TopLineHeight + m_DrawAreaRect.height -
+      ((m_ArrayPressHistory[1] - (double)m_TotalMinPress + 18) * ratioH);
 
   //---------------------------------------------------------------------------------
   // live pressure data
@@ -400,17 +395,17 @@ void DashboardInstrument_BaroHistory::DrawForeground(wxGCDC* dc) {
   for (int idx = 1; idx < BARO_RECORD_COUNT; idx++) {
     pointsSpd[idx].x = idx * m_ratioW + 3 + m_LeftLegend;
     // Print the smoothed value to avoid jumps in the single line.
-    pointsSpd[idx].y = m_TopLineHeight + m_DrawAreaRect.height -
+    pointsSpd[idx].y =
+        m_TopLineHeight + m_DrawAreaRect.height -
         ((m_ExpSmoothArrayPressure[idx] - m_TotalMinPress + 18.0) * ratioH);
     if (BARO_RECORD_COUNT - m_SampleCount <= idx &&
-      pointsSpd[idx].y > m_TopLineHeight &&
-      pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
+        pointsSpd[idx].y > m_TopLineHeight &&
+        pointsSpd[idx].y <= m_TopLineHeight + m_DrawAreaRect.height) {
       bdDraw[ls] = pointsSpd[idx];
       ls++;
     }
   }
-  if (ls > 1)
-    dc->DrawLines(ls, bdDraw);
+  if (ls > 1) dc->DrawLines(ls, bdDraw);
 
   //---------------------------------------------------------------------------------
   // exponential smoothing of barometric pressure
