@@ -5,7 +5,7 @@
  * Purpose:  Dashboard Plugin
  * Author:   Jean-Eudes Onfray
  * expanded: Bernd Cirotzki 2023 (special colour design)
- * 
+ *
  ***************************************************************************
  *   Copyright (C) 2010 by David S. Register                               *
  *                                                                         *
@@ -97,52 +97,56 @@ class DashboardInstrumentContainer;
 #define wxFontPickerCtrl OCPNFontButton
 class OCPNFontButton;
 
-WX_DEFINE_ARRAY(InstrumentProperties*, wxArrayOfInstrumentProperties);
+WX_DEFINE_ARRAY(InstrumentProperties *, wxArrayOfInstrumentProperties);
 
-class EditDialog : public wxDialog
-{
+class EditDialog : public wxDialog {
 private:
-
 protected:
-    wxStaticText* m_staticText1;
-    wxStaticText* m_staticText5;
-    wxStaticText* m_staticText2;
-    wxStaticText* m_staticText6;
-    wxStaticText* m_staticText3;
-    wxStaticText* m_staticText4;
-    wxStaticLine* m_staticline1;
-    wxStaticLine* m_staticline2;
-    wxStaticText* m_staticText7;
-    wxStaticText* m_staticText9;
-    wxStaticText* m_staticText10;
-    wxStdDialogButtonSizer* m_sdbSizer3;
-    wxButton* m_sdbSizer3OK;
-    wxButton* m_sdbSizer3Cancel;
+  wxStaticText *m_staticText1;
+  wxStaticText *m_staticText5;
+  wxStaticText *m_staticText2;
+  wxStaticText *m_staticText6;
+  wxStaticText *m_staticText3;
+  wxStaticText *m_staticText4;
+  wxStaticLine *m_staticline1;
+  wxStaticLine *m_staticline2;
+  wxStaticText *m_staticText7;
+  wxStaticText *m_staticText9;
+  wxStaticText *m_staticText10;
+  wxStdDialogButtonSizer *m_sdbSizer3;
+  wxButton *m_sdbSizer3OK;
+  wxButton *m_sdbSizer3Cancel;
 
-    // Virtual event handlers, override them in your derived class
-    virtual void OnSetdefault(wxCommandEvent& event);
+  // Virtual event handlers, override them in your derived class
+  virtual void OnSetdefault(wxCommandEvent &event);
 
 public:
-    wxFontPickerCtrl* m_fontPicker2;
-    wxColourPickerCtrl* m_colourPicker1;
-    wxFontPickerCtrl* m_fontPicker4;
-    wxColourPickerCtrl* m_colourPicker2;
-    wxFontPickerCtrl* m_fontPicker5;
-    wxFontPickerCtrl* m_fontPicker6;
-    wxColourPickerCtrl* m_colourPicker3;
-    wxColourPickerCtrl* m_colourPicker4;
-    wxButton* m_button1;
+  wxFontPickerCtrl *m_fontPicker2;
+  wxColourPickerCtrl *m_colourPicker1;
+  wxFontPickerCtrl *m_fontPicker4;
+  wxColourPickerCtrl *m_colourPicker2;
+  wxFontPickerCtrl *m_fontPicker5;
+  wxFontPickerCtrl *m_fontPicker6;
+  wxColourPickerCtrl *m_colourPicker3;
+  wxColourPickerCtrl *m_colourPicker4;
+  wxButton *m_button1;
 
-    EditDialog(wxWindow* parent, InstrumentProperties& Properties, wxWindowID id = wxID_ANY, const wxString& title = wxT("Edit Instrument"), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize(-1, -1), long style = wxDEFAULT_DIALOG_STYLE);
+  EditDialog(wxWindow *parent, InstrumentProperties &Properties,
+             wxWindowID id = wxID_ANY,
+             const wxString &title = wxT("Edit Instrument"),
+             const wxPoint &pos = wxDefaultPosition,
+             const wxSize &size = wxSize(-1, -1),
+             long style = wxDEFAULT_DIALOG_STYLE);
 
-    ~EditDialog();
+  ~EditDialog();
 };
 
 class DashboardWindowContainer {
 public:
   DashboardWindowContainer(DashboardWindow *dashboard_window, wxString name,
                            wxString caption, wxString orientation,
-                           wxArrayInt inst, wxArrayOfInstrumentProperties inProberty) {
+                           wxArrayInt inst,
+                           wxArrayOfInstrumentProperties inProberty) {
     m_pDashboardWindow = dashboard_window;
     m_sName = name;
     m_sCaption = caption;
@@ -154,11 +158,10 @@ public:
   }
 
   ~DashboardWindowContainer() {
-      for (unsigned int i = 0; i < m_aInstrumentPropertyList.GetCount(); i++)
-      {
-          InstrumentProperties* Inst = m_aInstrumentPropertyList.Item(i);
-          delete Inst;
-      }
+    for (unsigned int i = 0; i < m_aInstrumentPropertyList.GetCount(); i++) {
+      InstrumentProperties *Inst = m_aInstrumentPropertyList.Item(i);
+      delete Inst;
+    }
   }
   DashboardWindow *m_pDashboardWindow;
   bool m_bIsVisible;
@@ -172,6 +175,7 @@ public:
   wxArrayOfInstrumentProperties m_aInstrumentPropertyList;
   wxSize m_best_size;
   wxSize m_conf_best_size;
+  wxSize m_persist_size;
 };
 
 class DashboardInstrumentContainer {
@@ -224,7 +228,7 @@ public:
 
   //    The optional method overrides
   void SetNMEASentence(wxString &sentence);
-  void SetPositionFixEx(PlugIn_Position_Fix_Ex& pfix);
+  void SetPositionFixEx(PlugIn_Position_Fix_Ex &pfix);
   void SetCursorLatLon(double lat, double lon);
   int GetToolbarToolCount(void);
   void OnToolbarToolCallback(int id);
@@ -238,6 +242,7 @@ public:
   int GetToolbarItemId() { return m_toolbar_item_id; }
   int GetDashboardWindowShownCount();
   void SetPluginMessage(wxString &message_id, wxString &message_body);
+  void UpdateSumLog(bool);
 
 private:
   bool LoadConfig(void);
@@ -260,6 +265,7 @@ private:
   void HandleN2K_128259(ObservedEvt ev);
   void HandleN2K_128267(ObservedEvt ev);
   void HandleN2K_128275(ObservedEvt ev);
+  void HandleN2K_128777(ObservedEvt ev);
   void HandleN2K_129029(ObservedEvt ev);
   void HandleN2K_129540(ObservedEvt ev);
   void HandleN2K_130306(ObservedEvt ev);
@@ -270,13 +276,13 @@ private:
   std::shared_ptr<ObservableListener> listener_128259;
   std::shared_ptr<ObservableListener> listener_128267;
   std::shared_ptr<ObservableListener> listener_128275;
+  std::shared_ptr<ObservableListener> listener_128777;
   std::shared_ptr<ObservableListener> listener_129029;
   std::shared_ptr<ObservableListener> listener_129540;
   std::shared_ptr<ObservableListener> listener_130306;
   std::shared_ptr<ObservableListener> listener_130310;
   std::shared_ptr<ObservableListener> listener_130313;
 
-
   std::string prio127245;
   std::string prio127257;
   std::string prio128259;
@@ -308,6 +314,21 @@ private:
   int mSatsInUse;
   int mSatsInView;
   double mHdm;
+
+  /**
+   * The current time in UTC.
+   *
+   * Holds the current UTC time, which is obtained from various sources in the
+   * following order of priority:
+   * 1. SignalK navigation.datetime
+   * 2. NMEA ZDA sentence
+   * 3. NMEA RMC sentence
+   * 4. GNSS (Global Navigation Satellite System)
+   * 5. Local system clock
+   *
+   * The priority order ensures that the most accurate and reliable source is
+   * used to set the UTC time.
+   */
   wxDateTime mUTCDateTime;
   int m_config_version;
   wxString m_VDO_accumulator;
@@ -335,9 +356,13 @@ private:
   int mLOG_Watchdog;
   int mTrLOG_Watchdog;
   int mHUM_Watchdog;
+  int mWCC_Watchdog;
 
   iirfilter mSOGFilter;
   iirfilter mCOGFilter;
+  iirfilter mAWSFilter;
+  iirfilter mAWAFilter;
+
   // protected:
   //      DECLARE_EVENT_TABLE();
 };
@@ -358,7 +383,8 @@ public:
   void OnInstrumentDelete(wxCommandEvent &event);
   void OnInstrumentUp(wxCommandEvent &event);
   void OnInstrumentDown(wxCommandEvent &event);
-  void OnDashboarddefaultFont(wxCommandEvent& event);  
+  void OnDashboarddefaultFont(wxCommandEvent &event);
+  void OnDistanceUnitSelect(wxCommandEvent &event);
   void SaveDashboardConfig();
   void RecalculateSize(void);
 
@@ -370,12 +396,17 @@ public:
   wxSpinCtrl *m_pSpinSpeedMax;
   wxSpinCtrl *m_pSpinCOGDamp;
   wxSpinCtrl *m_pSpinSOGDamp;
+  wxSpinCtrl *m_pSpinAWSDamp;
+  wxSpinCtrl *m_pSpinAWADamp;
   wxChoice *m_pChoiceUTCOffset;
   wxChoice *m_pChoiceSpeedUnit;
   wxChoice *m_pChoiceDepthUnit;
   wxSpinCtrlDouble *m_pSpinDBTOffset;
   wxChoice *m_pChoiceDistanceUnit;
   wxChoice *m_pChoiceWindSpeedUnit;
+  wxCheckBox *m_pUseInternSumLog;
+  wxStaticText *m_SumLogUnit;
+  wxTextCtrl *m_pSumLogValue;
   wxCheckBox *m_pUseTrueWinddata;
   wxChoice *m_pChoiceTempUnit;
 
@@ -442,12 +473,16 @@ public:
 #endif
 
   bool isInstrumentListEqual(const wxArrayInt &list);
-  void SetInstrumentList(wxArrayInt list, wxArrayOfInstrumentProperties* InstrumentPropertyList);
+  void SetInstrumentList(wxArrayInt list,
+                         wxArrayOfInstrumentProperties *InstrumentPropertyList);
   void SendSentenceToAllInstruments(DASH_CAP st, double value, wxString unit);
   void SendSatInfoToAllInstruments(int cnt, int seq, wxString talk,
                                    SAT_INFO sats[4]);
   void SendUtcTimeToAllInstruments(wxDateTime value);
-  void ChangePaneOrientation(int orient, bool updateAUImgr);
+
+  // Default FloatingPosition (100.100) included.
+  void ChangePaneOrientation(int orient, bool updateAUImgr, int fpx = 100,
+                             int fpy = 100);
   /*TODO: OnKeyPress pass event to main window or disable focus*/
 
   DashboardWindowContainer *m_Container;
@@ -481,8 +516,7 @@ private:
 class OCPNFontButton : public wxButton {
 public:
   OCPNFontButton() {}
-  OCPNFontButton(wxWindow *parent, wxWindowID id,
-                 const wxFontData &initial,
+  OCPNFontButton(wxWindow *parent, wxWindowID id, const wxFontData &initial,
                  const wxPoint &pos = wxDefaultPosition,
                  const wxSize &size = wxDefaultSize,
                  long style = wxFONTBTN_DEFAULT_STYLE,
@@ -493,9 +527,9 @@ public:
 
   virtual wxColour GetSelectedColour() const { return m_data.GetColour(); }
   virtual void SetSelectedFont(const wxFont &font) {
-      m_data.SetChosenFont(font);
-      m_selectedFont = m_data.GetChosenFont();
-      UpdateFont();
+    m_data.SetChosenFont(font);
+    m_selectedFont = m_data.GetChosenFont();
+    UpdateFont();
   }
   virtual void SetSelectedColour(const wxColour &colour) {
     m_data.SetColour(colour);
@@ -515,8 +549,7 @@ public:  // API extensions specific for OCPNFontButton
   wxFont GetSelectedFont() const { return m_selectedFont; }
 
 public:
-  bool Create(wxWindow *parent, wxWindowID id,
-              const wxFontData &initial,
+  bool Create(wxWindow *parent, wxWindowID id, const wxFontData &initial,
               const wxPoint &pos = wxDefaultPosition,
               const wxSize &size = wxDefaultSize,
               long style = wxFONTBTN_DEFAULT_STYLE,
@@ -531,9 +564,6 @@ protected:
   wxFontData m_data;
 
   wxFont m_selectedFont;
-
-private:
-  DECLARE_DYNAMIC_CLASS(OCPNFontButton)
 };
 
 #endif
