@@ -38,92 +38,90 @@
 #include "qdebug.h"
 #endif
 
- // ColorScheme ... Try only make a simple darker in Night mode. this could be made better.
+// ColorScheme ... Try only make a simple darker in Night mode. this could be
+// made better.
 extern PI_ColorScheme aktuellColorScheme;
 
-wxColour GetColourSchemeBackgroundColour(wxColour co)
-{
-    wxColour ret_val = co;
-    #if wxCHECK_VERSION(3, 1, 6)
-    unsigned int red = co.GetRed();
-    unsigned int Green = co.GetGreen();
-    unsigned int Blue = co.GetBlue();
-    #else
-    unsigned int red = co.Red();
-    unsigned int Green = co.Green();
-    unsigned int Blue = co.Blue();
-    #endif
-    switch (aktuellColorScheme) {
+wxColour GetColourSchemeBackgroundColour(wxColour co) {
+  wxColour ret_val = co;
+#if wxCHECK_VERSION(3, 1, 6)
+  unsigned int red = co.GetRed();
+  unsigned int Green = co.GetGreen();
+  unsigned int Blue = co.GetBlue();
+#else
+  unsigned int red = co.Red();
+  unsigned int Green = co.Green();
+  unsigned int Blue = co.Blue();
+#endif
+  switch (aktuellColorScheme) {
     case PI_GLOBAL_COLOR_SCHEME_RGB:
-        break;
+      break;
     case PI_GLOBAL_COLOR_SCHEME_DAY:
-        break;
+      break;
     case PI_GLOBAL_COLOR_SCHEME_DUSK:
-        red *= .8;
-        Green *= .8;
-        Blue *= .8;
-        ret_val = wxColour(red, Green, Blue);
-        break;
+      red *= .8;
+      Green *= .8;
+      Blue *= .8;
+      ret_val = wxColour(red, Green, Blue);
+      break;
     case PI_GLOBAL_COLOR_SCHEME_NIGHT:
-        red *= .5;
-        Green *= .5;
-        Blue *= .5;
-        ret_val = wxColour(red, Green, Blue);
-        break;
-    default: break;
-    }
-    return ret_val;
+      red *= .5;
+      Green *= .5;
+      Blue *= .5;
+      ret_val = wxColour(red, Green, Blue);
+      break;
+    default:
+      break;
+  }
+  return ret_val;
 }
 
-
-wxColour GetColourSchemeFont(wxColour co)
-{
-    wxColour ret_val = co;
-    #if wxCHECK_VERSION(3, 1, 6)
-    unsigned int red = co.GetRed();
-    unsigned int Green = co.GetGreen();
-    unsigned int Blue = co.GetBlue();
-    #else
-    unsigned int red = co.Red();
-    unsigned int Green = co.Green();
-    unsigned int Blue = co.Blue();
-    #endif
-    switch (aktuellColorScheme) {
+wxColour GetColourSchemeFont(wxColour co) {
+  wxColour ret_val = co;
+#if wxCHECK_VERSION(3, 1, 6)
+  unsigned int red = co.GetRed();
+  unsigned int Green = co.GetGreen();
+  unsigned int Blue = co.GetBlue();
+#else
+  unsigned int red = co.Red();
+  unsigned int Green = co.Green();
+  unsigned int Blue = co.Blue();
+#endif
+  switch (aktuellColorScheme) {
     case PI_GLOBAL_COLOR_SCHEME_RGB:
-        break;
+      break;
     case PI_GLOBAL_COLOR_SCHEME_DAY:
-        break;
+      break;
     case PI_GLOBAL_COLOR_SCHEME_DUSK:
-        red *= .8;
-        Green *= .8;
-        Blue *= .8;
-        //if (red + Green + Blue < 10) {
-        //  red = Green = Blue = 50;
-        //}
-        ret_val = wxColour(red, Green, Blue);
-        break;
+      red *= .8;
+      Green *= .8;
+      Blue *= .8;
+      // if (red + Green + Blue < 10) {
+      //   red = Green = Blue = 50;
+      // }
+      ret_val = wxColour(red, Green, Blue);
+      break;
     case PI_GLOBAL_COLOR_SCHEME_NIGHT:
-        red *= .5;
-        Green *= .5;
-        Blue *= .5;
-        if (red + Green + Blue < 10) {
-          red = Green = Blue = 50;
-        }
-        ret_val = wxColour(red, Green, Blue);
-        break;
-    default: break;
-    }
-    return ret_val;
+      red *= .5;
+      Green *= .5;
+      Blue *= .5;
+      if (red + Green + Blue < 10) {
+        red = Green = Blue = 50;
+      }
+      ret_val = wxColour(red, Green, Blue);
+      break;
+    default:
+      break;
+  }
+  return ret_val;
 }
 
-
 //----------------------------------------------------------------
 //
 //    Generic DashboardInstrument Implementation
 //
 //----------------------------------------------------------------
 
-
 DashboardInstrument::DashboardInstrument(wxWindow* pparent, wxWindowID id,
                                          wxString title, DASH_CAP cap_flag,
                                          InstrumentProperties* Properties)
@@ -160,18 +158,17 @@ DashboardInstrument::DashboardInstrument(wxWindow* pparent, wxWindowID id,
 #endif
 
 #ifdef HAVE_WX_GESTURE_EVENTS
-  if (!EnableTouchEvents( wxTOUCH_PRESS_GESTURES)) {
+  if (!EnableTouchEvents(wxTOUCH_PRESS_GESTURES)) {
     wxLogError("Failed to enable touch events on dashboard Instrument");
   }
 
   Bind(wxEVT_LONG_PRESS, &DashboardInstrument::OnLongPress, this);
   Bind(wxEVT_LEFT_UP, &DashboardInstrument::OnLeftUp, this);
 #endif
-
 }
 
 #ifdef HAVE_WX_GESTURE_EVENTS
-void DashboardInstrument::OnLongPress(wxLongPressEvent &event) {
+void DashboardInstrument::OnLongPress(wxLongPressEvent& event) {
   /* we defer the popup menu call upon the leftup event
   else the menu disappears immediately,
    */
@@ -179,7 +176,7 @@ void DashboardInstrument::OnLongPress(wxLongPressEvent &event) {
 }
 #endif
 
-void DashboardInstrument::OnLeftUp(wxMouseEvent &event) {
+void DashboardInstrument::OnLeftUp(wxMouseEvent& event) {
   wxPoint pos = event.GetPosition();
 
   if (!m_popupWanted) {
@@ -198,7 +195,7 @@ void DashboardInstrument::OnLeftUp(wxMouseEvent &event) {
 }
 
 void DashboardInstrument::MouseEvent(wxMouseEvent& event) {
-  if (event.GetEventType() == wxEVT_RIGHT_DOWN){
+  if (event.GetEventType() == wxEVT_RIGHT_DOWN) {
     wxContextMenuEvent evtCtx(wxEVT_CONTEXT_MENU, this->GetId(),
                               this->ClientToScreen(event.GetPosition()));
     evtCtx.SetEventObject(this);
@@ -214,15 +211,16 @@ void DashboardInstrument::OnEraseBackground(wxEraseEvent& WXUNUSED(evt)) {
   // intentionally empty
 }
 
-void DashboardInstrument::InitDataTextHeight(const wxString &sampleText, int &sampleWidth) {
+void DashboardInstrument::InitDataTextHeight(const wxString& sampleText,
+                                             int& sampleWidth) {
   wxClientDC dc(this);
   wxFont f;
   int w;
 
   if (m_Properties) {
-      f = m_Properties->m_DataFont.GetChosenFont();
+    f = m_Properties->m_DataFont.GetChosenFont();
   } else {
-      f = g_pFontData->GetChosenFont();
+    f = g_pFontData->GetChosenFont();
   }
   dc.GetTextExtent(sampleText, &sampleWidth, &m_DataTextHeight, 0, 0, &f);
 }
@@ -233,9 +231,10 @@ void DashboardInstrument::InitTitleSize() {
   m_InstrumentSpacing = g_iInstrumentSpacing;
 
   if (m_Properties) {
-    if ( !m_Properties->m_Title.IsEmpty() ) m_title=m_Properties->m_Title;
+    if (!m_Properties->m_Title.IsEmpty()) m_title = m_Properties->m_Title;
     f = m_Properties->m_TitleFont.GetChosenFont();
-    if ( m_Properties->m_InstrumentSpacing >= 0 ) m_InstrumentSpacing = m_Properties->m_InstrumentSpacing;
+    if (m_Properties->m_InstrumentSpacing >= 0)
+      m_InstrumentSpacing = m_Properties->m_InstrumentSpacing;
   } else {
     f = g_pFontTitle->GetChosenFont();
   }
@@ -244,82 +243,83 @@ void DashboardInstrument::InitTitleSize() {
 
 void DashboardInstrument::InitTitleAndDataPosition(int drawHeight) {
   m_DataRightAlign = (g_DataAlignment & wxALIGN_RIGHT) != 0;
-  m_DataMargin=g_iDataMargin;
+  m_DataMargin = g_iDataMargin;
 
   if (m_Properties) {
-      if ( m_Properties->m_DataAlignment!=wxALIGN_INVALID ) m_DataRightAlign = (m_Properties->m_DataAlignment & wxALIGN_RIGHT) != 0;
-      if ( m_Properties->m_DataMargin>=0 ) m_DataMargin = m_Properties->m_DataMargin;
+    if (m_Properties->m_DataAlignment != wxALIGN_INVALID)
+      m_DataRightAlign = (m_Properties->m_DataAlignment & wxALIGN_RIGHT) != 0;
+    if (m_Properties->m_DataMargin >= 0)
+      m_DataMargin = m_Properties->m_DataMargin;
   }
 
   m_TitleRightAlign = (g_TitleAlignment & wxALIGN_RIGHT) != 0;
   m_TitleTop = m_DataTextHeight * g_TitleVerticalOffset;
   m_DataTop = m_TitleHeight;
-  if ( (g_TitleAlignment & wxALIGN_BOTTOM) != 0 ) {
-    m_TitleTop = drawHeight + (m_DataTextHeight*g_TitleVerticalOffset);
+  if ((g_TitleAlignment & wxALIGN_BOTTOM) != 0) {
+    m_TitleTop = drawHeight + (m_DataTextHeight * g_TitleVerticalOffset);
     m_DataTop = 0;
   }
 }
 
 int DashboardInstrument::GetFullHeight(int drawHeight) {
-  int h=m_TitleTop + m_TitleHeight + drawHeight + m_InstrumentSpacing;
-  if ( (g_TitleAlignment & wxALIGN_BOTTOM) != 0 ) {
-    h=m_TitleTop + m_TitleHeight + m_InstrumentSpacing;
+  int h = m_TitleTop + m_TitleHeight + drawHeight + m_InstrumentSpacing;
+  if ((g_TitleAlignment & wxALIGN_BOTTOM) != 0) {
+    h = m_TitleTop + m_TitleHeight + m_InstrumentSpacing;
   }
 
   return h;
 }
 
 int DashboardInstrument::GetDataBottom(int clientHeight) {
-  if ( (g_TitleAlignment & wxALIGN_BOTTOM) != 0 ) {
-    return clientHeight-m_TitleHeight-m_InstrumentSpacing-3;
+  if ((g_TitleAlignment & wxALIGN_BOTTOM) != 0) {
+    return clientHeight - m_TitleHeight - m_InstrumentSpacing - 3;
   }
-  return clientHeight-m_InstrumentSpacing;
+  return clientHeight - m_InstrumentSpacing;
 }
 
 void DashboardInstrument::SetDataFont(wxGCDC* dc) {
   wxFont f;
 
   if (m_Properties) {
-      f = m_Properties->m_DataFont.GetChosenFont();
-      dc->SetFont((f));
-      dc->SetTextForeground(GetColourSchemeFont(m_Properties->m_DataFont.GetColour()));
+    f = m_Properties->m_DataFont.GetChosenFont();
+    dc->SetFont((f));
+    dc->SetTextForeground(
+        GetColourSchemeFont(m_Properties->m_DataFont.GetColour()));
   } else {
     f = g_pFontData->GetChosenFont();
-      dc->SetFont((f));
-      dc->SetTextForeground(GetColourSchemeFont(g_pFontData->GetColour()));
+    dc->SetFont((f));
+    dc->SetTextForeground(GetColourSchemeFont(g_pFontData->GetColour()));
   }
 }
 
 void DashboardInstrument::OnPaint(wxPaintEvent& WXUNUSED(event)) {
-    wxAutoBufferedPaintDC pdc(this);
-    if (!pdc.IsOk()) {
-        wxLogMessage(
-            _T("DashboardInstrument::OnPaint() fatal: ")
-            _T("wxAutoBufferedPaintDC.IsOk() false."));
-        return;
-    }
+  wxAutoBufferedPaintDC pdc(this);
+  if (!pdc.IsOk()) {
+    wxLogMessage(
+        _T("DashboardInstrument::OnPaint() fatal: ")
+        _T("wxAutoBufferedPaintDC.IsOk() false."));
+    return;
+  }
 
-    wxSize size = GetClientSize();
-    if (size.x == 0 || size.y == 0) {
-        wxLogMessage(_T("DashboardInstrument::OnPaint() fatal: Zero size DC."));
-        return;
-    }
+  wxSize size = GetClientSize();
+  if (size.x == 0 || size.y == 0) {
+    wxLogMessage(_T("DashboardInstrument::OnPaint() fatal: Zero size DC."));
+    return;
+  }
 
 #if wxUSE_GRAPHICS_CONTEXT
-    wxGCDC dc(pdc);
+  wxGCDC dc(pdc);
 #else
-    wxDC& dc(pdc);
+  wxDC& dc(pdc);
 #endif
-    wxColour cl;
-    if (m_Properties)
-    {
-        dc.SetBackground(GetColourSchemeBackgroundColour(m_Properties->m_DataBackgroundColour));
-    }
-    else
-    {
-        GetGlobalColor(_T("DASHB"), &cl);
-        dc.SetBackground(cl);
-    }
+  wxColour cl;
+  if (m_Properties) {
+    dc.SetBackground(
+        GetColourSchemeBackgroundColour(m_Properties->m_DataBackgroundColour));
+  } else {
+    GetGlobalColor(_T("DASHB"), &cl);
+    dc.SetBackground(cl);
+  }
 #ifdef __WXGTK__
   dc.SetBrush(cl);
   dc.SetPen(*wxTRANSPARENT_PEN);
@@ -330,43 +330,43 @@ void DashboardInstrument::OnPaint(wxPaintEvent& WXUNUSED(event)) {
   Draw(&dc);
 
   if (!m_drawSoloInPane) {
-      wxPen pen;
-      pen.SetStyle(wxPENSTYLE_SOLID);
-      if (m_Properties)
-      {
-          pen.SetColour(GetColourSchemeBackgroundColour(m_Properties->m_TitleBackgroundColour));
-          dc.SetPen(pen);
-          dc.SetBrush(GetColourSchemeBackgroundColour(m_Properties->m_TitleBackgroundColour));
-      }
-      else
-      {
-          GetGlobalColor(_T("DASHL"), &cl);
-          pen.SetColour(cl);
-          dc.SetPen(pen);
-          dc.SetBrush(cl);
-      }
+    wxPen pen;
+    pen.SetStyle(wxPENSTYLE_SOLID);
+    if (m_Properties) {
+      pen.SetColour(GetColourSchemeBackgroundColour(
+          m_Properties->m_TitleBackgroundColour));
+      dc.SetPen(pen);
+      dc.SetBrush(GetColourSchemeBackgroundColour(
+          m_Properties->m_TitleBackgroundColour));
+    } else {
+      GetGlobalColor(_T("DASHL"), &cl);
+      pen.SetColour(cl);
+      dc.SetPen(pen);
+      dc.SetBrush(cl);
+    }
 
     dc.DrawRoundedRectangle(0, m_TitleTop, size.x, m_TitleHeight, 3);
     wxFont f;
-    if (m_Properties)
-    {
-        f = m_Properties->m_TitleFont.GetChosenFont();
-        dc.SetFont(f);
-        dc.SetTextForeground(GetColourSchemeFont(m_Properties->m_TitleFont.GetColour()));
-        dc.SetTextBackground(GetColourSchemeBackgroundColour(m_Properties->m_TitleBackgroundColour));
-    }
-    else
-    {
-        f = g_pFontTitle->GetChosenFont();
-        dc.SetFont(f);
-        dc.SetTextForeground(GetColourSchemeFont(g_pFontTitle->GetColour()));
-        GetGlobalColor(_T("DASHL"), &cl);
-        dc.SetTextBackground(cl);
+    if (m_Properties) {
+      f = m_Properties->m_TitleFont.GetChosenFont();
+      dc.SetFont(f);
+      dc.SetTextForeground(
+          GetColourSchemeFont(m_Properties->m_TitleFont.GetColour()));
+      dc.SetTextBackground(GetColourSchemeBackgroundColour(
+          m_Properties->m_TitleBackgroundColour));
+    } else {
+      f = g_pFontTitle->GetChosenFont();
+      dc.SetFont(f);
+      dc.SetTextForeground(GetColourSchemeFont(g_pFontTitle->GetColour()));
+      GetGlobalColor(_T("DASHL"), &cl);
+      dc.SetTextBackground(cl);
     }
     // GetGlobalColor(_T("DASHF"), &cl);
-    //dc.SetTextForeground(cl);
+    // dc.SetTextForeground(cl);
     if (m_TitleRightAlign) {
-      dc.DrawText(m_title, GetClientSize().GetWidth()-m_TitleWidth-g_iTitleMargin, m_TitleTop);
+      dc.DrawText(m_title,
+                  GetClientSize().GetWidth() - m_TitleWidth - g_iTitleMargin,
+                  m_TitleTop);
     } else {
       dc.DrawText(m_title, g_iTitleMargin, m_TitleTop);
     }
@@ -379,46 +379,42 @@ void DashboardInstrument::OnPaint(wxPaintEvent& WXUNUSED(event)) {
 //
 //----------------------------------------------------------------
 
-DashboardInstrument_Single::DashboardInstrument_Single(wxWindow* pparent,
-                                                       wxWindowID id,
-                                                       wxString title,
-                                                       InstrumentProperties* Properties,
-                                                       DASH_CAP cap_flag,
-                                                       wxString format)
+DashboardInstrument_Single::DashboardInstrument_Single(
+    wxWindow* pparent, wxWindowID id, wxString title,
+    InstrumentProperties* Properties, DASH_CAP cap_flag, wxString format)
     : DashboardInstrument(pparent, id, title, cap_flag, Properties) {
   m_format = format;
   m_data = _T("---");
 }
 
 wxSize DashboardInstrument_Single::GetSize(int orient, wxSize hint) {
-
   InitTitleSize();
   int w;
-  InitDataTextHeight(_T("000"),w);
+  InitDataTextHeight(_T("000"), w);
 
-  int drawHeight=m_DataTextHeight * (1 + g_TitleVerticalOffset);
+  int drawHeight = m_DataTextHeight * (1 + g_TitleVerticalOffset);
   InitTitleAndDataPosition(drawHeight);
   int h = GetFullHeight(drawHeight);
 
   if (orient == wxHORIZONTAL) {
-    return wxSize(wxMax(w + m_DataMargin,DefaultWidth), wxMax(hint.y, h));
+    return wxSize(wxMax(w + m_DataMargin, DefaultWidth), wxMax(hint.y, h));
   } else {
-    return wxSize(wxMax(hint.x, wxMax(w + m_DataMargin,DefaultWidth)), h);
+    return wxSize(wxMax(hint.x, wxMax(w + m_DataMargin, DefaultWidth)), h);
   }
 }
 
 void DashboardInstrument_Single::Draw(wxGCDC* dc) {
-
   SetDataFont(dc);
 
   int x1;
-  if ( m_DataMargin<0 ) m_DataMargin=m_TitleHeight; // Use default, if not initialized properly
-  x1=m_DataMargin;
+  if (m_DataMargin < 0)
+    m_DataMargin = m_TitleHeight;  // Use default, if not initialized properly
+  x1 = m_DataMargin;
 
-  if ( m_DataRightAlign ) {
-    int w,h;
+  if (m_DataRightAlign) {
+    int w, h;
     dc->GetTextExtent(m_data, &w, &h, 0, 0);
-    x1=GetClientSize().GetWidth() - w - m_DataMargin;
+    x1 = GetClientSize().GetWidth() - w - m_DataMargin;
   }
 
   dc->DrawText(m_data, x1, m_DataTop);
@@ -428,22 +424,31 @@ void DashboardInstrument_Single::SetData(DASH_CAP st, double data,
                                          wxString unit) {
   if (m_cap_flag.test(st)) {
     if (!std::isnan(data)) {
-      bool showUnit = (m_Properties ? (m_Properties->m_ShowUnit==1) : g_bShowUnit);
-      wxString format = (m_Properties && m_Properties->m_Format != "" ? m_Properties->m_Format : m_format);
+      bool showUnit =
+          (m_Properties ? (m_Properties->m_ShowUnit == 1) : g_bShowUnit);
+      wxString format =
+          (m_Properties && m_Properties->m_Format != "" ? m_Properties->m_Format
+                                                        : m_format);
       if (unit == _T("C"))
-        m_data = wxString::Format(format, data) + (showUnit ? DEGREE_SIGN + _T("C"):"");
+        m_data = wxString::Format(format, data) +
+                 (showUnit ? DEGREE_SIGN + _T("C") : "");
       else if (unit == _T("\u00B0"))
         m_data = wxString::Format(format, data) + (showUnit ? DEGREE_SIGN : "");
       else if (unit == _T("\u00B0T"))
-        m_data = wxString::Format(format, data) + (showUnit ? DEGREE_SIGN + _(" true") : "");
+        m_data = wxString::Format(format, data) +
+                 (showUnit ? DEGREE_SIGN + _(" true") : "");
       else if (unit == _T("\u00B0M"))
-        m_data = wxString::Format(format, data) + (showUnit ? DEGREE_SIGN + _(" mag") : "");
+        m_data = wxString::Format(format, data) +
+                 (showUnit ? DEGREE_SIGN + _(" mag") : "");
       else if (unit == _T("\u00B0L"))
-        m_data = _T(">") + wxString::Format(format, data) + (showUnit ? DEGREE_SIGN : "");
+        m_data = _T(">") + wxString::Format(format, data) +
+                 (showUnit ? DEGREE_SIGN : "");
       else if (unit == _T("\u00B0R"))
-        m_data = wxString::Format(format, data) + (showUnit ? DEGREE_SIGN + _T("<") : "");
+        m_data = wxString::Format(format, data) +
+                 (showUnit ? DEGREE_SIGN + _T("<") : "");
       else if (unit == _T("N"))  // Knots
-        m_data = wxString::Format(format, data) + (showUnit ? _T(" Kts") : _T(""));
+        m_data =
+            wxString::Format(format, data) + (showUnit ? _T(" Kts") : _T(""));
       /* maybe in the future ...
                       else if (unit == _T("M")) // m/s
                         m_data = wxString::Format(m_format, data)+_T(" m/s");
@@ -452,7 +457,8 @@ void DashboardInstrument_Single::SetData(DASH_CAP st, double data,
        ... to be completed
        */
       else
-        m_data = wxString::Format(format, data) + (showUnit ? _T(" ") + unit : "");
+        m_data =
+            wxString::Format(format, data) + (showUnit ? _T(" ") + unit : "");
     } else
       m_data = _T("---");
 
@@ -466,12 +472,9 @@ void DashboardInstrument_Single::SetData(DASH_CAP st, double data,
 //
 //----------------------------------------------------------------
 
-DashboardInstrument_Position::DashboardInstrument_Position(wxWindow* pparent,
-                                                           wxWindowID id,
-                                                           wxString title,
-                                                           InstrumentProperties* Properties,
-                                                           DASH_CAP cap_flag1,
-                                                           DASH_CAP cap_flag2)
+DashboardInstrument_Position::DashboardInstrument_Position(
+    wxWindow* pparent, wxWindowID id, wxString title,
+    InstrumentProperties* Properties, DASH_CAP cap_flag1, DASH_CAP cap_flag2)
     : DashboardInstrument(pparent, id, title, cap_flag1, Properties) {
   m_cap_flag.set(cap_flag2);
 
@@ -482,35 +485,34 @@ DashboardInstrument_Position::DashboardInstrument_Position(wxWindow* pparent,
 }
 
 wxSize DashboardInstrument_Position::GetSize(int orient, wxSize hint) {
-
   InitTitleSize();
   int w;
-  InitDataTextHeight(_T("000  00.0000 W"),w);
+  InitDataTextHeight(_T("000  00.0000 W"), w);
 
-  int drawHeight=m_DataTextHeight * 2 + m_DataTextHeight*g_TitleVerticalOffset;
+  int drawHeight =
+      m_DataTextHeight * 2 + m_DataTextHeight * g_TitleVerticalOffset;
   InitTitleAndDataPosition(drawHeight);
   int h = GetFullHeight(drawHeight);
 
   if (orient == wxHORIZONTAL) {
-    return wxSize(wxMax(w + m_DataMargin,DefaultWidth), wxMax(hint.y, h));
+    return wxSize(wxMax(w + m_DataMargin, DefaultWidth), wxMax(hint.y, h));
   } else {
-    return wxSize(wxMax(hint.x, wxMax(w + m_DataMargin,DefaultWidth)), h);
+    return wxSize(wxMax(hint.x, wxMax(w + m_DataMargin, DefaultWidth)), h);
   }
 }
 
 void DashboardInstrument_Position::Draw(wxGCDC* dc) {
-
   SetDataFont(dc);
 
-  int x1,x2;
-  x1=x2=m_DataMargin;
+  int x1, x2;
+  x1 = x2 = m_DataMargin;
 
-  if ( m_DataRightAlign ) {
-    int w,h;
+  if (m_DataRightAlign) {
+    int w, h;
     dc->GetTextExtent(m_data1, &w, &h, 0, 0);
-    x1=GetClientSize().GetWidth() - w - m_DataMargin;
+    x1 = GetClientSize().GetWidth() - w - m_DataMargin;
     dc->GetTextExtent(m_data2, &w, &h, 0, 0);
-    x2=GetClientSize().GetWidth() - w - m_DataMargin;
+    x2 = GetClientSize().GetWidth() - w - m_DataMargin;
   }
 
   dc->DrawText(m_data1, x1, m_DataTop);
