@@ -1,10 +1,4 @@
-/******************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:  GRIB Object
- * Author:   David Register
- *
- ***************************************************************************
+/***************************************************************************
  *   Copyright (C) 2014 by David S. Register                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,10 +15,11 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
- ***************************************************************************
- *
+ ***************************************************************************/
+/**
+ * \file
+ * \implements \ref GribOverlayFactory.h
  */
-
 #include "wx/wxprec.h"
 
 #ifndef WX_PRECOMP
@@ -110,20 +105,6 @@ static wxString MToString( int DataCenterModel )
 }
 #endif
 
-#if 0
-static wxString TToString( const wxDateTime date_time, const int time_zone )
-{
-    wxDateTime t( date_time );
-    t.MakeFromTimezone( wxDateTime::UTC );
-    if( t.IsDST() ) t.Subtract( wxTimeSpan( 1, 0, 0, 0 ) );
-    switch( time_zone ) {
-        case 0: return t.Format( _T(" %a %d-%b-%Y  %H:%M "), wxDateTime::Local ) + _T("LOC");//:%S
-        case 1:
-        default: return t.Format( _T(" %a %d-%b-%Y %H:%M  "), wxDateTime::UTC ) + _T("UTC");
-    }
-}
-#endif
-
 #ifdef ocpnUSE_GL
 static GLuint texture_format = 0;
 #endif
@@ -144,7 +125,7 @@ static GLboolean QueryExtension( const char *extName )
     extNameLen = strlen( extName );
 
     p = (char *) glGetString( GL_EXTENSIONS );
-    if( NULL == p ) {
+    if( nullptr == p ) {
         return GL_FALSE;
     }
 
@@ -238,23 +219,23 @@ GRIBOverlayFactory::GRIBOverlayFactory(GRIBUICtrlBar &dlg)
 
   // qDebug() <<  "m_pixelMM: " << m_pixelMM;
 
-  m_pGribTimelineRecordSet = NULL;
+  m_pGribTimelineRecordSet = nullptr;
   m_last_vp_scale = 0.;
 
-  m_oDC = NULL;
+  m_oDC = nullptr;
 #if wxUSE_GRAPHICS_CONTEXT
-  m_gdc = NULL;
+  m_gdc = nullptr;
 #endif
-  m_Font_Message = NULL;
+  m_Font_Message = nullptr;
 
   InitColorsTable();
   for (int i = 0; i < GribOverlaySettings::SETTINGS_COUNT; i++)
-    m_pOverlay[i] = NULL;
+    m_pOverlay[i] = nullptr;
 
-  m_ParticleMap = NULL;
+  m_ParticleMap = nullptr;
   m_tParticleTimer.Connect(
       wxEVT_TIMER, wxTimerEventHandler(GRIBOverlayFactory::OnParticleTimer),
-      NULL, this);
+      nullptr, this);
   m_bUpdateParticles = false;
 
   // Generate the wind arrow cache
@@ -386,7 +367,7 @@ GRIBOverlayFactory::~GRIBOverlayFactory() {
 }
 
 void GRIBOverlayFactory::Reset() {
-  m_pGribTimelineRecordSet = NULL;
+  m_pGribTimelineRecordSet = nullptr;
 
   ClearCachedData();
 }
@@ -394,9 +375,9 @@ void GRIBOverlayFactory::Reset() {
 void GRIBOverlayFactory::SetMessageFont() {
   wxFont fo;
 #ifdef __WXQT__
-  fo = GetOCPNGUIScaledFont_PlugIn(_T("Dialog"));
+  fo = GetOCPNGUIScaledFont_PlugIn(_("Dialog"));
 #else
-  fo = *OCPNGetFont(_("Dialog"), 10);
+  fo = *OCPNGetFont(_("Dialog"));
   fo.SetPointSize(
       (fo.GetPointSize() * g_ContentScaleFactor / OCPN_GetWinDIPScaleFactor()));
 #endif
@@ -414,7 +395,7 @@ void GRIBOverlayFactory::ClearCachedData(void) {
   //    Clear out the cached bitmaps
   for (int i = 0; i < GribOverlaySettings::SETTINGS_COUNT; i++) {
     delete m_pOverlay[i];
-    m_pOverlay[i] = NULL;
+    m_pOverlay[i] = nullptr;
   }
 }
 
@@ -446,9 +427,9 @@ bool GRIBOverlayFactory::RenderGLGribOverlay(wxGLContext *pcontext,
   }
 
   m_oDC->SetVP(vp);
-  m_oDC->SetDC(NULL);
+  m_oDC->SetDC(nullptr);
 
-  m_pdc = NULL;  // inform lower layers that this is OpenGL render
+  m_pdc = nullptr;  // inform lower layers that this is OpenGL render
 
   bool rv = DoRenderGribOverlay(vp);
 
@@ -472,7 +453,7 @@ bool GRIBOverlayFactory::RenderGribOverlay(wxDC &dc, PlugIn_ViewPort *vp) {
 #if 0
 #if wxUSE_GRAPHICS_CONTEXT
     wxMemoryDC *pmdc;
-    pmdc = wxDynamicCast(&dc, wxMemoryDC);
+    pmdc = dynamic_cast<wxMemoryDC*>(&dc);
     wxGraphicsContext *pgc = wxGraphicsContext::Create( *pmdc );
     m_gdc = pgc;
 #endif
@@ -625,7 +606,7 @@ bool GRIBOverlayFactory::DoRenderGribOverlay(PlugIn_ViewPort *vp) {
   }
   if (m_dlg.ProjectionEnabled()) {
     int x, y;
-    m_dlg.GetProjectedLatLon(x, y);
+    m_dlg.GetProjectedLatLon(x, y, vp);
     DrawProjectedPosition(x, y);
   }
   if (!m_Message_Hiden.IsEmpty()) m_Message_Hiden.Append(_T("\n"));
@@ -1251,7 +1232,7 @@ wxImage &GRIBOverlayFactory::getLabel(double value, int settings,
 
   wxScreenDC sdc;
   int w, h;
-  sdc.GetTextExtent(labels, &w, &h, NULL, NULL, &mfont);
+  sdc.GetTextExtent(labels, &w, &h, nullptr, nullptr, &mfont);
 
   int label_offset = 5;
 
@@ -1319,24 +1300,51 @@ void GRIBOverlayFactory::RenderGribBarbedArrows(int settings, GribRecord **pGR,
 #endif
 
   if (m_Settings.Settings[settings].m_bBarbArrFixSpac) {
-    // set spacing between arrows
-    int space = adjustSpacing(m_Settings.Settings[settings].m_iBarbArrSpacing);
-
-    PlugIn_ViewPort uvp = *vp;
-    uvp.rotation = uvp.skew = 0;
-
+    // Get spacing in pixels from settings
+    int space_pixels =
+        adjustSpacing(m_Settings.Settings[settings].m_iBarbArrSpacing);
     int arrowSize = 16;
+    int total_spacing = space_pixels + arrowSize;  // Physical pixels.
 
-    for (int i = 0; i < m_ParentSize.GetWidth(); i += (space + arrowSize)) {
-      for (int j = 0; j < m_ParentSize.GetHeight(); j += (space + arrowSize)) {
-        double lat, lon;
-        GetCanvasLLPix(vp, wxPoint(i, j), &lat, &lon);
+    // Convert pixel spacing to geographic spacing
+    // We need to create a reference point and move it by the spacing to find
+    // the geo difference
+    wxPoint center(vp->pix_width / 2, vp->pix_height / 2);
+    double center_lat, center_lon;
+    GetCanvasLLPix(vp, center, &center_lat, &center_lon);
 
+    // Find lat/lon of a point offset by total_spacing
+    wxPoint offset_point(center.x + total_spacing, center.y + total_spacing);
+    double offset_lat, offset_lon;
+    GetCanvasLLPix(vp, offset_point, &offset_lat, &offset_lon);
+
+    // Calculate spacing in geographic coordinates
+    double lat_spacing = fabs(center_lat - offset_lat);
+    double lon_spacing = fabs(center_lon - offset_lon);
+
+    // Generate grid in geographic coordinates
+    // Find grid origin that aligns with whole-number multiples of spacing
+    double start_lat = floor(vp->lat_min / lat_spacing) * lat_spacing;
+    double start_lon = floor(vp->lon_min / lon_spacing) * lon_spacing;
+
+    // Expand bounds slightly to ensure we cover the viewport edges
+    double end_lat = vp->lat_max + lat_spacing;
+    double end_lon = vp->lon_max + lon_spacing;
+
+    // Draw grid of arrows based on geographical coordinates
+    for (double lat = start_lat; lat <= end_lat; lat += lat_spacing) {
+      for (double lon = start_lon; lon <= end_lon; lon += lon_spacing) {
+        // Convert geographic point to screen coordinates
+        wxPoint p;
+        GetCanvasPixLL(vp, &p, lat, lon);
+
+        // Get data value at this location
         double vkn, ang;
-        if (GribRecord::getInterpolatedValues(vkn, ang, pGRX, pGRY, lon, lat))
-          drawWindArrowWithBarbs(settings, i, j, vkn * 3.6 / 1.852,
+        if (GribRecord::getInterpolatedValues(vkn, ang, pGRX, pGRY, lon, lat)) {
+          drawWindArrowWithBarbs(settings, p.x, p.y, vkn * 3.6 / 1.852,
                                  (ang - 90) * M_PI / 180, (lat < 0.), colour,
                                  vp->rotation);
+        }
       }
     }
   } else {
@@ -1417,7 +1425,7 @@ void GRIBOverlayFactory::RenderGribIsobar(int settings, GribRecord **pGR,
   SettingsIdToGribId(settings, idx, idy, polar);
   if (idx < 0) return;
 
-  GribRecord *pGRA = pGR[idx], *pGRM = NULL;
+  GribRecord *pGRA = pGR[idx], *pGRM = nullptr;
 
   if (!pGRA) return;
 
@@ -1460,7 +1468,7 @@ void GRIBOverlayFactory::RenderGribIsobar(int settings, GribRecord **pGR,
         wxDateTime now = wxDateTime::Now();
         if ((now - start).GetSeconds() > 3 && press - min < (max - min) / 2) {
           progressdialog = new wxGenericProgressDialog(
-              _("Building Isobar map"), _("Wind"), max - min + 1, NULL,
+              _("Building Isobar map"), _("Wind"), max - min + 1, nullptr,
               wxPD_SMOOTH | wxPD_ELAPSED_TIME | wxPD_REMAINING_TIME);
         }
       }
@@ -1592,22 +1600,52 @@ void GRIBOverlayFactory::RenderGribDirectionArrows(int settings,
 #endif
 
   if (m_Settings.Settings[settings].m_bDirArrFixSpac) {  // fixed spacing
+    // Get spacing in pixels from settings
+    int space_pixels =
+        adjustSpacing(m_Settings.Settings[settings].m_iBarbArrSpacing);
+    int arrowSize = 16;
+    int total_spacing = space_pixels + arrowSize;  // Physical pixels.
 
-    // Set spacing between arrows
-    int space = adjustSpacing(m_Settings.Settings[settings].m_iDirArrSpacing);
+    // Convert pixel spacing to geographic spacing
+    // We need to create a reference point and move it by the spacing to find
+    // the geo difference
+    wxPoint center(vp->pix_width / 2, vp->pix_height / 2);
+    double center_lat, center_lon;
+    GetCanvasLLPix(vp, center, &center_lat, &center_lon);
 
-    for (int i = 0; i < m_ParentSize.GetWidth(); i += (space + arrowSize)) {
-      for (int j = 0; j < m_ParentSize.GetHeight(); j += (space + arrowSize)) {
-        double lat, lon, sh, dir;
+    // Find lat/lon of a point offset by total_spacing
+    wxPoint offset_point(center.x + total_spacing, center.y + total_spacing);
+    double offset_lat, offset_lon;
+    GetCanvasLLPix(vp, offset_point, &offset_lat, &offset_lon);
+
+    // Calculate spacing in geographic coordinates
+    double lat_spacing = fabs(center_lat - offset_lat);
+    double lon_spacing = fabs(center_lon - offset_lon);
+
+    // Generate grid in geographic coordinates
+    // Find grid origin that aligns with whole-number multiples of spacing
+    double start_lat = floor(vp->lat_min / lat_spacing) * lat_spacing;
+    double start_lon = floor(vp->lon_min / lon_spacing) * lon_spacing;
+
+    // Expand bounds slightly to ensure we cover the viewport edges
+    double end_lat = vp->lat_max + lat_spacing;
+    double end_lon = vp->lon_max + lon_spacing;
+
+    // Draw grid of arrows based on geographical coordinates
+    for (double lat = start_lat; lat <= end_lat; lat += lat_spacing) {
+      for (double lon = start_lon; lon <= end_lon; lon += lon_spacing) {
+        // Convert geographic point to screen coordinates
+        wxPoint p;
+        GetCanvasPixLL(vp, &p, lat, lon);
+
+        double sh, dir;
         double scale = 1.0;
-        GetCanvasLLPix(vp, wxPoint(i, j), &lat, &lon);
 
         if (polar) {  // wave arrows
           sh = pGRX->getInterpolatedValue(lon, lat, true);
           dir = pGRY->getInterpolatedValue(lon, lat, true, true);
 
           if (dir == GRIB_NOTDEF || sh == GRIB_NOTDEF) continue;
-
         } else {  // current arrows
           if (!GribRecord::getInterpolatedValues(sh, dir, pGRX, pGRY, lon, lat))
             continue;
@@ -1618,13 +1656,13 @@ void GRIBOverlayFactory::RenderGribDirectionArrows(int settings,
 
         // draw arrows
         if (m_Settings.Settings[settings].m_iDirectionArrowForm == 0)
-          drawSingleArrow(i, j, dir + vp->rotation, colour, arrowWidth,
+          drawSingleArrow(p.x, p.y, dir + vp->rotation, colour, arrowWidth,
                           arrowSizeIdx, scale);
         else if (m_Settings.Settings[settings].m_iDirectionArrowForm == 1)
-          drawDoubleArrow(i, j, dir + vp->rotation, colour, arrowWidth,
+          drawDoubleArrow(p.x, p.y, dir + vp->rotation, colour, arrowWidth,
                           arrowSizeIdx, scale);
         else
-          drawSingleArrow(i, j, dir + vp->rotation, colour,
+          drawSingleArrow(p.x, p.y, dir + vp->rotation, colour,
                           wxMax(1, wxMin(8, (int)(sh + 0.5))), arrowSizeIdx,
                           scale);
       }
@@ -1728,7 +1766,7 @@ void GRIBOverlayFactory::RenderGribOverlayMap(int settings, GribRecord **pGR,
   SettingsIdToGribId(settings, idx, idy, polar);
   if (idx < 0 || !pGR[idx]) return;
 
-  GribRecord *pGRA = pGR[idx], *pGRM = NULL;
+  GribRecord *pGRA = pGR[idx], *pGRM = nullptr;
   if (!pGRA) return;
 
   if (idy >= 0 && !polar && pGR[idy]) {
@@ -1836,7 +1874,7 @@ void GRIBOverlayFactory::RenderGribNumbers(int settings, GribRecord **pGR,
   SettingsIdToGribId(settings, idx, idy, polar);
   if (idx < 0) return;
 
-  GribRecord *pGRA = pGR[idx], *pGRM = NULL;
+  GribRecord *pGRA = pGR[idx], *pGRM = nullptr;
 
   if (!pGRA) return;
 
@@ -1854,7 +1892,7 @@ void GRIBOverlayFactory::RenderGribNumbers(int settings, GribRecord **pGR,
 
   // set an arbitrary width for numbers
   int wstring;
-  m_TexFontNumbers.GetTextExtent(_T("1234"), &wstring, NULL);
+  m_TexFontNumbers.GetTextExtent(_T("1234"), &wstring, nullptr);
 
   if (m_Settings.Settings[settings].m_bNumFixSpac) {  // fixed spacing
 
@@ -2004,7 +2042,7 @@ void GRIBOverlayFactory::DrawNumbers(wxPoint p, double value, int settings,
 #else
 
 #ifdef __WXQT__
-    wxFont font = GetOCPNGUIScaledFont_PlugIn(_T("Dialog"));
+    wxFont font = GetOCPNGUIScaledFont_PlugIn(_("Dialog"));
 #else
     wxFont font(9, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL,
                 wxFONTWEIGHT_NORMAL);
@@ -2230,12 +2268,12 @@ void GRIBOverlayFactory::RenderGribParticles(int settings, GribRecord **pGR,
     double vkn, ang;
     for (int i = 0; i < 20; i++) {
       // random position in the grib area
-      p[0] =
-          (float)rand() / RAND_MAX * (pGRX->getLonMax() - pGRX->getLonMin()) +
-          pGRX->getLonMin();
-      p[1] =
-          (float)rand() / RAND_MAX * (pGRX->getLatMax() - pGRX->getLatMin()) +
-          pGRX->getLatMin();
+      p[0] = static_cast<float>(rand()) / static_cast<float>(RAND_MAX) *
+                 (pGRX->getLonMax() - pGRX->getLonMin()) +
+             pGRX->getLonMin();
+      p[1] = static_cast<float>(rand()) / static_cast<float>(RAND_MAX) *
+                 (pGRX->getLatMax() - pGRX->getLatMin()) +
+             pGRX->getLatMin();
 
       if (GribRecord::getInterpolatedValues(vkn, ang, pGRX, pGRY, p[0], p[1]) &&
           vkn > 0 && vkn < 100)
@@ -2306,7 +2344,7 @@ void GRIBOverlayFactory::RenderGribParticles(int settings, GribRecord **pGR,
     int i = it->m_HistoryPos;
 
     bool lip_valid = false;
-    float *lp = NULL, lip[2];
+    float *lp = nullptr, lip[2];
     wxUint8 lc[4];
     float lcf[4];
 
