@@ -1,11 +1,5 @@
-/******************************************************************************
- *
- * Project:  OpenCPN
- * Purpose:  GRIB Object
- * Author:   David Register
- *
- ***************************************************************************
- *   Copyright (C) 2010 by David S. Register   *
+/***************************************************************************
+ *   Copyright (C) 2010 by David S. Register                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,10 +15,11 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
- ***************************************************************************
- *
+ ***************************************************************************/
+/**
+ * \file
+ * \implements \ref GribUIDialog.h
  */
-
 #include "wx/wx.h"
 #include "wx/tokenzr.h"
 #include "wx/datetime.h"
@@ -42,6 +37,7 @@
 #include <math.h>
 #include <time.h>
 
+#include "ocpn_plugin.h"
 #include "pi_gl.h"
 #include "grib_pi.h"
 #include "GribTable.h"
@@ -58,7 +54,30 @@
 double m_cursor_lat, m_cursor_lon;
 int m_Altitude;
 int m_DialogStyle;
+/**
+ * Persisted version of the GRIB area selection mode.
+ *
+ * This value is saved to and loaded from the OpenCPN config file, allowing the
+ * user's preferred selection mode to persist between sessions. The value is
+ * used to:
+ * - Restore the last used selection mode on startup.
+ * - Keep track of the mode when dialog is closed/reopened.
+ * - Revert to previous mode if changes are cancelled.
+ */
 int m_SavedZoneSelMode;
+/**
+ * Tracks the current state of GRIB area selection for zone coordinates.
+ *
+ * This state controls:
+ * - Whether coordinates come from viewport or mouse area selection.
+ * - When to display the selection overlay during drawing.
+ * - When to update the lat/lon input fields.
+ *
+ * A typical mouse area selection flow:
+ * 1. START_SELECTION when manual mode chosen.
+ * 2. DRAW_SELECTION when user starts Shift+drag.
+ * 3. COMPLETE_SELECTION when user releases mouse button.
+ */
 int m_ZoneSelMode;
 
 extern grib_pi *g_pi;
@@ -101,22 +120,6 @@ static int CompareFileStringTime(const wxString &first,
   //      ::wxFileModificationTime(second);
 }
 
-// date/time in the desired time zone format
-static wxString TToString(const wxDateTime date_time, const int time_zone) {
-  wxDateTime t(date_time);
-  switch (time_zone) {
-    case 0:
-      if ((wxDateTime::Now() == (wxDateTime::Now().ToGMT())) &&
-          t.IsDST())  // bug in wxWingets 3.0 for UTC meridien ?
-        t.Add(wxTimeSpan(1, 0, 0, 0));
-      return t.Format(_T(" %a %d-%b-%Y  %H:%M "), wxDateTime::Local) +
-             _T("LOC");
-    case 1:
-    default:
-      return t.Format(_T(" %a %d-%b-%Y %H:%M  "), wxDateTime::UTC) + _T("UTC");
-  }
-}
-
 wxWindow *GetGRIBCanvas() {
   wxWindow *wx;
   // If multicanvas are active, render the overlay on the right canvas only
@@ -137,7 +140,7 @@ wxWindow *GetGRIBCanvas() {
    screen */
 GribTimelineRecordSet::GribTimelineRecordSet(unsigned int cnt)
     : GribRecordSet(cnt) {
-  for (int i = 0; i < Idx_COUNT; i++) m_IsobarArray[i] = NULL;
+  for (int i = 0; i < Idx_COUNT; i++) m_IsobarArray[i] = nullptr;
 }
 
 GribTimelineRecordSet::~GribTimelineRecordSet() {
@@ -148,13 +151,13 @@ GribTimelineRecordSet::~GribTimelineRecordSet() {
 void GribTimelineRecordSet::ClearCachedData() {
   for (int i = 0; i < Idx_COUNT; i++) {
     if (m_IsobarArray[i]) {
-      //    Clear out the cached isobars
+      // Clear out the cached isobars
       for (unsigned int j = 0; j < m_IsobarArray[i]->GetCount(); j++) {
         IsoLine *piso = (IsoLine *)m_IsobarArray[i]->Item(j);
         delete piso;
       }
       delete m_IsobarArray[i];
-      m_IsobarArray[i] = NULL;
+      m_IsobarArray[i] = nullptr;
     }
   }
 }
@@ -165,18 +168,19 @@ void GribTimelineRecordSet::ClearCachedData() {
 
 GRIBUICtrlBar::GRIBUICtrlBar(wxWindow *parent, wxWindowID id,
                              const wxString &title, const wxPoint &pos,
-                             const wxSize &size, long style, grib_pi *ppi)
-    : GRIBUICtrlBarBase(parent, id, title, pos, size, style) {
+                             const wxSize &size, long style, grib_pi *ppi,
+                             double scale_factor)
+    : GRIBUICtrlBarBase(parent, id, title, pos, size, style, scale_factor) {
   pParent = parent;
   pPlugIn = ppi;
   // Preinitialize the vierwport with an existing value, see
   // https://github.com/OpenCPN/OpenCPN/pull/4002/files
-  m_vp = new PlugIn_ViewPort(pPlugIn->GetCurrentViewPort());
-  pReq_Dialog = NULL;
-  m_bGRIBActiveFile = NULL;
-  m_pTimelineSet = NULL;
-  m_gCursorData = NULL;
-  m_gGRIBUICData = NULL;
+  m_vpMouse = new PlugIn_ViewPort(pPlugIn->GetCurrentViewPort());
+  pReq_Dialog = nullptr;
+  m_bGRIBActiveFile = nullptr;
+  m_pTimelineSet = nullptr;
+  m_gCursorData = nullptr;
+  m_gGRIBUICData = nullptr;
   m_gtk_started = false;
 
   wxFileConfig *pConf = GetOCPNConfigObject();
@@ -188,6 +192,19 @@ GRIBUICtrlBar::GRIBUICtrlBar(wxWindow *parent, wxWindowID id,
   this->Layout();
   m_fgCtrlBarSizer->Fit(this);
 
+  // Initialize the time format check timer
+  m_tFormatRefresh.Connect(
+      wxEVT_TIMER, wxTimerEventHandler(GRIBUICtrlBar::OnFormatRefreshTimer),
+      nullptr, this);
+
+  // Sample the current time format using a fixed reference date (January 1,
+  // 2021 at noon)
+  wxDateTime referenceDate(1, wxDateTime::Jan, 2021, 12, 0, 0);
+  m_sLastTimeFormat = toUsrDateTimeFormat_Plugin(referenceDate);
+
+  // Start timer to check for time format changes (every 5 seconds)
+  m_tFormatRefresh.Start(5000);
+
   if (pConf) {
     pConf->SetPath(_T ( "/Settings/GRIB" ));
     pConf->Read(_T ( "WindPlot" ), &m_bDataPlot[GribOverlaySettings::WIND],
@@ -262,8 +279,8 @@ GRIBUICtrlBar::GRIBUICtrlBar(wxWindow *parent, wxWindowID id,
 
   // connect Timer
   m_tPlayStop.Connect(wxEVT_TIMER,
-                      wxTimerEventHandler(GRIBUICtrlBar::OnPlayStopTimer), NULL,
-                      this);
+                      wxTimerEventHandler(GRIBUICtrlBar::OnPlayStopTimer),
+                      nullptr, this);
   // connect functions
   Connect(wxEVT_MOVE, wxMoveEventHandler(GRIBUICtrlBar::OnMove));
 
@@ -281,6 +298,15 @@ GRIBUICtrlBar::GRIBUICtrlBar(wxWindow *parent, wxWindowID id,
   m_highlight_lonmax = 0;
   m_highlight_latmin = 0;
   m_highlight_lonmin = 0;
+
+#ifndef __OCPN__ANDROID__
+  // Create the dialog for downloading GRIB files.
+  // This dialog is created here, but not shown until the user requests it.
+  // This is done such that user can draw bounding box on the chart before
+  // the dialog is shown.
+
+  createRequestDialog();
+#endif
 }
 
 GRIBUICtrlBar::~GRIBUICtrlBar() {
@@ -350,38 +376,10 @@ GRIBUICtrlBar::~GRIBUICtrlBar() {
     pConf->Write(_T( "WaveHeight" ), xyGribConfig.waveHeight);
     pConf->Write(_T( "WindWaves" ), xyGribConfig.windWaves);
   }
-  delete m_vp;
+  delete m_vpMouse;
   delete m_pTimelineSet;
 }
 
-wxBitmap GRIBUICtrlBar::GetScaledBitmap(wxBitmap bitmap,
-                                        const wxString svgFileName,
-                                        double scale_factor) {
-  int margin = 4;  // there is a small margin around the bitmap drawn by the
-                   // wxBitmapButton
-  int w = bitmap.GetWidth() - margin;
-  int h = bitmap.GetHeight() - margin;
-  w *= scale_factor;
-  h *= scale_factor;
-
-#ifdef ocpnUSE_SVG
-  wxString shareLocn = *GetpSharedDataLocation() + _T("plugins") +
-                       wxFileName::GetPathSeparator() + _T("grib_pi") +
-                       wxFileName::GetPathSeparator() + _T("data") +
-                       wxFileName::GetPathSeparator();
-  wxString filename = shareLocn + svgFileName + _T(".svg");
-
-  wxBitmap svgbm = GetBitmapFromSVGFile(filename, w, h);
-  if (svgbm.GetWidth() > 0 && svgbm.GetHeight() > 0)
-    return svgbm;
-  else
-#endif  // ocpnUSE_SVG
-  {
-    wxImage a = bitmap.ConvertToImage();
-    return wxBitmap(a.Scale(w, h), wxIMAGE_QUALITY_HIGH);
-  }
-}
-
 void GRIBUICtrlBar::SetScaledBitmap(double factor) {
   //  Round to the nearest "quarter", to avoid rendering artifacts
   m_ScaledFactor = wxRound(factor * 4.0) / 4.0;
@@ -407,7 +405,7 @@ void GRIBUICtrlBar::SetScaledBitmap(double factor) {
   m_bpSettings->SetBitmapLabel(
       GetScaledBitmap(wxBitmap(setting), _T("setting"), m_ScaledFactor));
 
-  SetRequestBitmap(m_ZoneSelMode);
+  SetRequestButtonBitmap(m_ZoneSelMode);
 
   // Careful here, this MinSize() sets the final width of the control bar,
   // overriding the width of the wxChoice above it.
@@ -420,29 +418,11 @@ void GRIBUICtrlBar::SetScaledBitmap(double factor) {
 #endif
 }
 
-void GRIBUICtrlBar::SetRequestBitmap(int type) {
-  if (NULL == m_bpRequest) return;
-
-  switch (type) {
-    case AUTO_SELECTION:
-    case SAVED_SELECTION:
-    case START_SELECTION:
-      m_bpRequest->SetBitmapLabel(
-          GetScaledBitmap(wxBitmap(request), _T("request"), m_ScaledFactor));
-      m_bpRequest->SetToolTip(_("Start a request"));
-      break;
-    case DRAW_SELECTION:
-      m_bpRequest->SetBitmapLabel(
-          GetScaledBitmap(wxBitmap(selzone), _T("selzone"), m_ScaledFactor));
-      m_bpRequest->SetToolTip(
-          _("Draw requested Area\nor Click here to stop request"));
-      break;
-    case COMPLETE_SELECTION:
-      m_bpRequest->SetBitmapLabel(GetScaledBitmap(
-          wxBitmap(request_end), _T("request_end"), m_ScaledFactor));
-      m_bpRequest->SetToolTip(_("Valid Area and Continue"));
-      break;
-  }
+void GRIBUICtrlBar::SetRequestButtonBitmap(int type) {
+  if (nullptr == m_bpRequest) return;
+  m_bpRequest->SetBitmapLabel(
+      GetScaledBitmap(wxBitmap(request), _T("request"), m_ScaledFactor));
+  m_bpRequest->SetToolTip(_("Start a download request"));
 }
 
 void GRIBUICtrlBar::OpenFile(bool newestFile) {
@@ -454,7 +434,7 @@ void GRIBUICtrlBar::OpenFile(bool newestFile) {
   m_FileIntervalIndex = m_OverlaySettings.m_SlicesPerUpdate;
   delete m_bGRIBActiveFile;
   delete m_pTimelineSet;
-  m_pTimelineSet = NULL;
+  m_pTimelineSet = nullptr;
   m_sTimeline->SetValue(0);
   m_TimeLineHours = 0;
   m_InterpolateMode = false;
@@ -485,14 +465,14 @@ void GRIBUICtrlBar::OpenFile(bool newestFile) {
     title.Append(fn.GetFullName());
     if (rsa->GetCount() == 0) {  // valid but empty file
       delete m_bGRIBActiveFile;
-      m_bGRIBActiveFile = NULL;
+      m_bGRIBActiveFile = nullptr;
       title.Prepend(_("Error! ")).Append(_(" contains no valid data!"));
     } else {
       PopulateComboDataList();
-      title.append(_T(" (") +
-                   TToString(m_bGRIBActiveFile->GetRefDateTime(),
-                             pPlugIn->GetTimeZone()) +
-                   _T(" )"));
+      title.append(" (" +
+                   toUsrDateTimeFormat_Plugin(
+                       wxDateTime(m_bGRIBActiveFile->GetRefDateTime())) +
+                   ")");
 
       if (rsa->GetCount() > 1) {
         GribRecordSet &first = rsa->Item(0), &second = rsa->Item(1),
@@ -520,7 +500,7 @@ void GRIBUICtrlBar::OpenFile(bool newestFile) {
     }
   } else {
     delete m_bGRIBActiveFile;
-    m_bGRIBActiveFile = NULL;
+    m_bGRIBActiveFile = nullptr;
     title = _("No valid GRIB file");
   }
   pPlugIn->GetGRIBOverlayFactory()->SetMessage(title);
@@ -548,21 +528,21 @@ void GRIBUICtrlBar::OpenFile(bool newestFile) {
 #ifdef __OCPN__ANDROID__
   m_bpSettings->Enable(true);
 #else
-  m_bpSettings->Enable(m_pTimelineSet != NULL);
+  m_bpSettings->Enable(m_pTimelineSet != nullptr);
 #endif
-  m_bpZoomToCenter->Enable(m_pTimelineSet != NULL);
+  m_bpZoomToCenter->Enable(m_pTimelineSet != nullptr);
 
-  m_sTimeline->Enable(m_pTimelineSet != NULL && m_TimeLineHours);
-  m_bpPlay->Enable(m_pTimelineSet != NULL && m_TimeLineHours);
+  m_sTimeline->Enable(m_pTimelineSet != nullptr && m_TimeLineHours);
+  m_bpPlay->Enable(m_pTimelineSet != nullptr && m_TimeLineHours);
 
-  m_bpPrev->Enable(m_pTimelineSet != NULL && m_TimeLineHours);
-  m_bpNext->Enable(m_pTimelineSet != NULL && m_TimeLineHours);
-  m_bpNow->Enable(m_pTimelineSet != NULL && m_TimeLineHours);
+  m_bpPrev->Enable(m_pTimelineSet != nullptr && m_TimeLineHours);
+  m_bpNext->Enable(m_pTimelineSet != nullptr && m_TimeLineHours);
+  m_bpNow->Enable(m_pTimelineSet != nullptr && m_TimeLineHours);
 
   SetCanvasContextMenuItemViz(pPlugIn->m_MenuItem, m_TimeLineHours != 0);
 
   //
-  if (m_bGRIBActiveFile == NULL) {
+  if (m_bGRIBActiveFile == nullptr) {
     // there's no data we can use in this file
     return;
   }
@@ -684,8 +664,8 @@ void GRIBUICtrlBar::SetCursorLatLon(double lat, double lon) {
   m_cursor_lon = lon;
   m_cursor_lat = lat;
 
-  if (m_vp && ((lat > m_vp->lat_min) && (lat < m_vp->lat_max)) &&
-      ((lon > m_vp->lon_min) && (lon < m_vp->lon_max)))
+  if (m_vpMouse && ((lat > m_vpMouse->lat_min) && (lat < m_vpMouse->lat_max)) &&
+      ((lon > m_vpMouse->lon_min) && (lon < m_vpMouse->lon_max)))
     UpdateTrackingControl();
 }
 
@@ -759,7 +739,7 @@ void GRIBUICtrlBar::SetDialogsStyleSizePosition(bool force_recompute) {
   // necessary )
   if (m_gGRIBUICData) {
     m_gGRIBUICData->Destroy();
-    m_gGRIBUICData = NULL;
+    m_gGRIBUICData = nullptr;
   }
 
   if ((m_DialogStyle >> 1 == SEPARATED || !m_CDataIsShown) &&
@@ -776,7 +756,7 @@ void GRIBUICtrlBar::SetDialogsStyleSizePosition(bool force_recompute) {
       pPlugIn->SetDialogFont(m_gCursorData);
       m_gCursorData->PopulateTrackingControls(false);
       // attach CursorData to CtrlBar if necessary
-      if (m_fgCDataSizer->GetItem(m_gCursorData) == NULL)
+      if (m_fgCDataSizer->GetItem(m_gCursorData) == nullptr)
         m_fgCDataSizer->Add(m_gCursorData, 0);
       m_gCursorData->Show();
 
@@ -834,7 +814,7 @@ void GRIBUICtrlBar::SetDialogsStyleSizePosition(bool force_recompute) {
         sFont = FindOrCreateFont_PlugIn(pointSize, wxFONTFAMILY_DEFAULT,
                                         wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
                                         FALSE);
-        dc.GetTextExtent(_T("W"), &width, &height, NULL, NULL, sFont);
+        dc.GetTextExtent(_T("W"), &width, &height, nullptr, nullptr, sFont);
         if (width <= target_char_width) bOK = true;
         pointSize--;
         if (pointSize <= 10) bOK = true;
@@ -865,7 +845,7 @@ void GRIBUICtrlBar::OnAltitude(wxCommandEvent &event) {
 
   wxMenu *amenu = new wxMenu();
   amenu->Connect(wxEVT_COMMAND_MENU_SELECTED,
-                 wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), NULL, this);
+                 wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), nullptr, this);
 
   for (int i = 0; i < 5; i++) {
     if (((m_pTimelineSet &&
@@ -939,7 +919,7 @@ void GRIBUICtrlBar::OnMenuEvent(wxMenuEvent &event) {
       OnSettings(evt);
       break;
     case ID_BTNREQUEST:
-      OnRequest(evt);
+      OnRequestForecastData(evt);
   }
   if (alt != m_Altitude) {
     SetDialogsStyleSizePosition(true);
@@ -952,14 +932,16 @@ void GRIBUICtrlBar::MenuAppend(wxMenu *menu, int id, wxString label,
                                wxMenu *submenu) {
   wxMenuItem *item = new wxMenuItem(menu, id, label, _T(""), kind);
   // add a submenu to this item if necessary
-  if (submenu) item->SetSubMenu(submenu);
+  if (submenu) {
+    item->SetSubMenu(submenu);
+  }
 
-    /* Menu font do not work properly for MSW (wxWidgets 3.2.1)
-    #ifdef __WXMSW__
-      wxFont *qFont = OCPNGetFont(_("Menu"), 10);
-      item->SetFont(*qFont);
-    #endif
-    */
+  /* Menu font do not work properly for MSW (wxWidgets 3.2.1)
+  #ifdef __WXMSW__
+    wxFont *qFont = OCPNGetFont(_("Menu"), 0);
+    item->SetFont(*qFont);
+  #endif
+  */
 
 #if defined(__WXMSW__) || defined(__WXGTK__)
   if (!bitmap.IsSameAs(wxNullBitmap)) item->SetBitmap(bitmap);
@@ -973,12 +955,13 @@ void GRIBUICtrlBar::OnMouseEvent(wxMouseEvent &event) {
     // populate menu
     wxMenu *xmenu = new wxMenu();
     xmenu->Connect(wxEVT_COMMAND_MENU_SELECTED,
-                   wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), NULL, this);
+                   wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), nullptr,
+                   this);
 
     if (m_HasAltitude) {  // eventually populate altitude choice
       wxMenu *smenu = new wxMenu();
       smenu->Connect(wxEVT_COMMAND_MENU_SELECTED,
-                     wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), NULL,
+                     wxMenuEventHandler(GRIBUICtrlBar::OnMenuEvent), nullptr,
                      this);
 
       for (int i = 0; i < 5; i++) {
@@ -1031,7 +1014,7 @@ void GRIBUICtrlBar::OnMouseEvent(wxMouseEvent &event) {
                          m_ZoneSelMode == START_SELECTION;
     bool requeststate3 = m_ZoneSelMode == DRAW_SELECTION;
     MenuAppend(xmenu, ID_BTNREQUEST,
-               requeststate1 ? _("Start a request")
+               requeststate1 ? _("Request forecast data")
                : requeststate3
                    ? _("Draw requested Area or Click here to stop request")
                    : _("Valid Area and Continue"),
@@ -1072,9 +1055,8 @@ void GRIBUICtrlBar::ContextMenuItemCallback(int id) {
   ArrayOfGribRecordSets *rsa = m_bGRIBActiveFile->GetRecordSetArrayPtr();
   GRIBTable *table = new GRIBTable(*this);
 
-  table->InitGribTable(pPlugIn->GetTimeZone(), rsa,
-                       GetNearestIndex(GetNow(), 0));
-  table->SetTableSizePosition(m_vp->pix_width, m_vp->pix_height);
+  table->InitGribTable(rsa, GetNearestIndex(GetNow(), 0));
+  table->SetTableSizePosition(m_vpMouse->pix_width, m_vpMouse->pix_height);
 
   table->ShowModal();
 
@@ -1083,13 +1065,17 @@ void GRIBUICtrlBar::ContextMenuItemCallback(int id) {
   delete table;
 }
 
-void GRIBUICtrlBar::SetViewPort(PlugIn_ViewPort *vp) {
-  if (m_vp == vp) return;
+void GRIBUICtrlBar::SetViewPortUnderMouse(PlugIn_ViewPort *vp) {
+  if (m_vpMouse == vp) return;
 
-  delete m_vp;
-  m_vp = new PlugIn_ViewPort(*vp);
+  delete m_vpMouse;
+  m_vpMouse = new PlugIn_ViewPort(*vp);
 
-  if (pReq_Dialog) pReq_Dialog->OnVpChange(vp);
+  if (pReq_Dialog) pReq_Dialog->OnVpUnderMouseChange(vp);
+}
+
+void GRIBUICtrlBar::SetViewPortWithFocus(PlugIn_ViewPort *vp) {
+  if (pReq_Dialog) pReq_Dialog->OnVpWithFocusChange(vp);
 }
 
 void GRIBUICtrlBar::OnClose(wxCloseEvent &event) {
@@ -1099,7 +1085,7 @@ void GRIBUICtrlBar::OnClose(wxCloseEvent &event) {
     if (m_ZoneSelMode > START_SELECTION) {
       pReq_Dialog->StopGraphicalZoneSelection();
       m_ZoneSelMode = START_SELECTION;
-      // SetRequestBitmap( m_ZoneSelMode );
+      // SetRequestButtonBitmap( m_ZoneSelMode );
     }
   pPlugIn->SendTimelineMessage(wxInvalidDateTime);
 
@@ -1119,62 +1105,42 @@ void GRIBUICtrlBar::OnPaint(wxPaintEvent &event) {
   wxPaintDC dc(this);
   while (node) {
     wxWindow *win = node->GetData();
-    if (win->IsKindOf(CLASSINFO(wxBitmapButton)))
-#if wxCHECK_VERSION(3, 0, 0)
-      dc.DrawBitmap(((wxBitmapButton *)win)->GetBitmap(), 5, 5, false);
-#else
-      dc.DrawBitmap(((wxBitmapButton *)win)->GetBitmapSelected(), 5, 5, false);
-#endif
+    if (dynamic_cast<wxBitmapButton *>(win))
+      dc.DrawBitmap(dynamic_cast<wxBitmapButton *>(win)->GetBitmap(), 5, 5,
+                    false);
     node = node->GetNext();
   }
 }
 
-void GRIBUICtrlBar::OnRequest(wxCommandEvent &event) {
+void GRIBUICtrlBar::createRequestDialog() {
+  ::wxBeginBusyCursor();
+
+  delete pReq_Dialog;  // delete to be re-created
+
+  pReq_Dialog = new GribRequestSetting(*this);
+  pPlugIn->SetDialogFont(pReq_Dialog);
+  pPlugIn->SetDialogFont(pReq_Dialog->m_sScrolledDialog);
+  pReq_Dialog->OnVpUnderMouseChange(m_vpMouse);
+  pReq_Dialog->SetRequestDialogSize();
+  if (::wxIsBusy()) ::wxEndBusyCursor();
+}
+
+void GRIBUICtrlBar::OnRequestForecastData(wxCommandEvent &event) {
   if (m_tPlayStop.IsRunning())
     return;  // do nothing when play back is running !
 
   /*if there is one instance of the dialog already visible, do nothing*/
   if (pReq_Dialog && pReq_Dialog->IsShown()) return;
 
-  /*a second click without selection cancel the process*/
-  if (m_ZoneSelMode == DRAW_SELECTION) {
-    assert(pReq_Dialog);
-    m_ZoneSelMode = START_SELECTION;
-    pReq_Dialog->StopGraphicalZoneSelection();
-    SetRequestBitmap(m_ZoneSelMode);
-    return;
-  }
-
   /*create new request dialog*/
-  if (m_ZoneSelMode == AUTO_SELECTION || m_ZoneSelMode == SAVED_SELECTION ||
-      m_ZoneSelMode == START_SELECTION) {
-    ::wxBeginBusyCursor();
+  createRequestDialog();
+  // need to set a position at start
+  int w;
+  ::wxDisplaySize(&w, nullptr);
+  pReq_Dialog->Move((w - pReq_Dialog->GetSize().GetX()) / 2, 30);
+  pReq_Dialog->Show();
 
-    delete pReq_Dialog;  // delete to be re-created
-
-    pReq_Dialog = new GribRequestSetting(*this);
-    pPlugIn->SetDialogFont(pReq_Dialog);
-    pPlugIn->SetDialogFont(pReq_Dialog->m_sScrolledDialog);
-    pReq_Dialog->OnVpChange(m_vp);
-    pReq_Dialog->SetRequestDialogSize();
-    // need to set a position at start
-    int w;
-    ::wxDisplaySize(&w, NULL);
-    pReq_Dialog->Move((w - pReq_Dialog->GetSize().GetX()) / 2, 30);
-
-  }  // end create new request dialog
-
-  pReq_Dialog->Show(m_ZoneSelMode == AUTO_SELECTION ||
-                    m_ZoneSelMode == SAVED_SELECTION ||
-                    m_ZoneSelMode == COMPLETE_SELECTION);
-  m_ZoneSelMode = m_ZoneSelMode == START_SELECTION      ? DRAW_SELECTION
-                  : m_ZoneSelMode == COMPLETE_SELECTION ? START_SELECTION
-                                                        : m_ZoneSelMode;
-  if (m_ZoneSelMode == START_SELECTION)
-    pReq_Dialog->StopGraphicalZoneSelection();
-  SetRequestBitmap(m_ZoneSelMode);  // set appopriate bitmap
-
-  if (::wxIsBusy()) ::wxEndBusyCursor();
+  SetRequestButtonBitmap(m_ZoneSelMode);  // set appopriate bitmap
 }
 
 void GRIBUICtrlBar::OnSettings(wxCommandEvent &event) {
@@ -1198,7 +1164,7 @@ void GRIBUICtrlBar::OnSettings(wxCommandEvent &event) {
   dialog->SetSettingsDialogSize();
   // need to set a position at start
   int w;
-  ::wxDisplaySize(&w, NULL);
+  ::wxDisplaySize(&w, nullptr);
   dialog->Move((w - dialog->GetSize().GetX()) / 2, 30);
   // end set position
 
@@ -1362,7 +1328,7 @@ void GRIBUICtrlBar::StopPlayBack() {
 
 void GRIBUICtrlBar::TimelineChanged() {
   if (!m_bGRIBActiveFile || (m_bGRIBActiveFile && !m_bGRIBActiveFile->IsOK())) {
-    pPlugIn->GetGRIBOverlayFactory()->SetGribTimelineRecordSet(NULL);
+    pPlugIn->GetGRIBOverlayFactory()->SetGribTimelineRecordSet(nullptr);
     return;
   }
 
@@ -1385,12 +1351,12 @@ void GRIBUICtrlBar::TimelineChanged() {
   } else {
     m_cRecordForecast->SetSelection(GetNearestIndex(time, 2));
     SaveSelectionString();  // memorize index and label
-    m_cRecordForecast->SetString(
-        m_Selection_index,
-        TToString(time, pPlugIn->GetTimeZone()));  // replace it by the
-                                                   // interpolated time label
-    m_cRecordForecast->SetStringSelection(TToString(
-        time, pPlugIn->GetTimeZone()));  // ensure it's visible in the box
+    wxString formattedTime = toUsrDateTimeFormat_Plugin(time);
+    m_cRecordForecast->SetString(m_Selection_index,
+                                 formattedTime);  // replace it by the
+                                                  // interpolated time label
+    m_cRecordForecast->SetStringSelection(
+        formattedTime);  // ensure it's visible in the box
   }
 
   UpdateTrackingControl();
@@ -1447,7 +1413,7 @@ wxDateTime GRIBUICtrlBar::GetNow() {
 
   ArrayOfGribRecordSets *rsa = m_bGRIBActiveFile->GetRecordSetArrayPtr();
 
-  // verifie if we are outside of the file time range
+  // Verify if we are outside of the file time range
   now = (now > rsa->Item(rsa->GetCount() - 1).m_Reference_Time)
             ? rsa->Item(rsa->GetCount() - 1).m_Reference_Time
         : (now < rsa->Item(0).m_Reference_Time) ? rsa->Item(0).m_Reference_Time
@@ -1482,16 +1448,16 @@ wxDateTime GRIBUICtrlBar::MinTime() {
 }
 
 GribTimelineRecordSet *GRIBUICtrlBar::GetTimeLineRecordSet(wxDateTime time) {
-  if (m_bGRIBActiveFile == NULL) return NULL;
+  if (m_bGRIBActiveFile == nullptr) return nullptr;
   ArrayOfGribRecordSets *rsa = m_bGRIBActiveFile->GetRecordSetArrayPtr();
 
-  if (rsa->GetCount() == 0) return NULL;
+  if (rsa->GetCount() == 0) return nullptr;
 
   GribTimelineRecordSet *set =
       new GribTimelineRecordSet(m_bGRIBActiveFile->GetCounter());
   for (int i = 0; i < Idx_COUNT; i++) {
-    GribRecordSet *GRS1 = NULL, *GRS2 = NULL;
-    GribRecord *GR1 = NULL, *GR2 = NULL;
+    GribRecordSet *GRS1 = nullptr, *GRS2 = nullptr;
+    GribRecord *GR1 = nullptr, *GR2 = nullptr;
     wxDateTime GR1time, GR2time;
 
     // already computed using polar interpolation from first axis
@@ -1566,7 +1532,7 @@ GribTimelineRecordSet *GRIBUICtrlBar::GetTimeLineRecordSet(wxDateTime time) {
   return set;
 }
 
-void GRIBUICtrlBar::GetProjectedLatLon(int &x, int &y) {
+void GRIBUICtrlBar::GetProjectedLatLon(int &x, int &y, PlugIn_ViewPort *vp) {
   wxPoint p(0, 0);
   auto now = TimelineTime();
   auto sog = m_ProjectBoatPanel->GetSpeed();
@@ -1576,8 +1542,8 @@ void GRIBUICtrlBar::GetProjectedLatLon(int &x, int &y) {
   PositionBearingDistanceMercator_Plugin(pPlugIn->m_boat_lat,
                                          pPlugIn->m_boat_lon, cog, dist,
                                          &m_projected_lat, &m_projected_lon);
-  if (m_vp) {
-    GetCanvasPixLL(m_vp, &p, m_projected_lat, m_projected_lon);
+  if (vp) {
+    GetCanvasPixLL(vp, &p, m_projected_lat, m_projected_lon);
   }
   x = p.x;
   y = p.y;
@@ -1711,7 +1677,7 @@ void GRIBUICtrlBar::OnOpenFile(wxCommandEvent &event) {
   if (wxDir::Exists(m_grib_dir)) l_grib_dir = m_grib_dir;
 
   wxFileDialog *dialog =
-      new wxFileDialog(NULL, _("Select a GRIB file"), l_grib_dir, _T(""),
+      new wxFileDialog(nullptr, _("Select a GRIB file"), l_grib_dir, _T(""),
                        wxT("Grib files "
                            "(*.grb;*.bz2;*.gz;*.grib2;*.grb2)|*.grb;*.bz2;*.gz;"
                            "*.grib2;*.grb2|All files (*)|*.*"),
@@ -1738,7 +1704,7 @@ void GRIBUICtrlBar::OnOpenFile(wxCommandEvent &event) {
 
   wxString file;
   int response = PlatformFileSelectorDialog(
-      NULL, &file, _("Select a GRIB file"), m_grib_dir, _T(""), _T("*.*"));
+      nullptr, &file, _("Select a GRIB file"), m_grib_dir, _T(""), _T("*.*"));
 
   if (response == wxID_OK) {
     wxFileName fn(file);
@@ -1753,7 +1719,7 @@ void GRIBUICtrlBar::OnOpenFile(wxCommandEvent &event) {
 
 void GRIBUICtrlBar::CreateActiveFileFromNames(const wxArrayString &filenames) {
   if (filenames.GetCount() != 0) {
-    m_bGRIBActiveFile = NULL;
+    m_bGRIBActiveFile = nullptr;
     m_bGRIBActiveFile = new GRIBFile(filenames, pPlugIn->GetCopyFirstCumRec(),
                                      pPlugIn->GetCopyMissWaveRec());
   }
@@ -1769,8 +1735,7 @@ void GRIBUICtrlBar::PopulateComboDataList() {
   ArrayOfGribRecordSets *rsa = m_bGRIBActiveFile->GetRecordSetArrayPtr();
   for (size_t i = 0; i < rsa->GetCount(); i++) {
     wxDateTime t(rsa->Item(i).m_Reference_Time);
-
-    m_cRecordForecast->Append(TToString(t, pPlugIn->GetTimeZone()));
+    m_cRecordForecast->Append(toUsrDateTimeFormat_Plugin(t));
   }
   m_cRecordForecast->SetSelection(index);
 }
@@ -1807,8 +1772,8 @@ void GRIBUICtrlBar::OnZoomToCenterClick(wxCommandEvent &event) {
 
     //Calculate overlay width & height in nm (around the center)
     double ow, oh;
-    DistanceBearingMercator_Plugin(clat, lonmin, clat, lonmax, NULL, &ow );
-    DistanceBearingMercator_Plugin( latmin, clon, latmax, clon, NULL, &oh );
+    DistanceBearingMercator_Plugin(clat, lonmin, clat, lonmax, nullptr, &ow );
+    DistanceBearingMercator_Plugin( latmin, clon, latmax, clon, nullptr, &oh );
 
     //calculate screen size
     int w = pPlugIn->GetGRIBOverlayFactory()->m_ParentSize.GetWidth();
@@ -1855,8 +1820,8 @@ void GRIBUICtrlBar::DoZoomToCenter() {
 
   // Calculate overlay width & height in nm (around the center)
   double ow, oh;
-  DistanceBearingMercator_Plugin(clat, lonmin, clat, lonmax, NULL, &ow);
-  DistanceBearingMercator_Plugin(latmin, clon, latmax, clon, NULL, &oh);
+  DistanceBearingMercator_Plugin(clat, lonmin, clat, lonmax, nullptr, &ow);
+  DistanceBearingMercator_Plugin(latmin, clon, latmax, clon, nullptr, &oh);
 
   wxWindow *wx = GetGRIBCanvas();
   // calculate screen size
@@ -1925,7 +1890,7 @@ void GRIBUICtrlBar::OnNext(wxCommandEvent &event) {
 
 void GRIBUICtrlBar::ComputeBestForecastForNow() {
   if (!m_bGRIBActiveFile || (m_bGRIBActiveFile && !m_bGRIBActiveFile->IsOK())) {
-    pPlugIn->GetGRIBOverlayFactory()->SetGribTimelineRecordSet(NULL);
+    pPlugIn->GetGRIBOverlayFactory()->SetGribTimelineRecordSet(nullptr);
     return;
   }
 
@@ -1954,13 +1919,11 @@ void GRIBUICtrlBar::ComputeBestForecastForNow() {
                               // wxChoice date time label
   m_cRecordForecast->SetSelection(GetNearestIndex(now, 2));
   SaveSelectionString();  // memorize the new selected wxChoice date time label
-  m_cRecordForecast->SetString(
-      m_Selection_index,
-      TToString(now,
-                pPlugIn->GetTimeZone()));  // write the now date time label
-                                           // in the right place in wxChoice
-  m_cRecordForecast->SetStringSelection(
-      TToString(now, pPlugIn->GetTimeZone()));  // put it in the box
+  wxString nowTime = toUsrDateTimeFormat_Plugin(now);
+  m_cRecordForecast->SetString(m_Selection_index,
+                               nowTime);  // write the now date time label
+                                          // in the right place in wxChoice
+  m_cRecordForecast->SetStringSelection(nowTime);  // put it in the box
 
   UpdateTrackingControl();
 
@@ -2011,6 +1974,29 @@ void GRIBUICtrlBar::SetFactoryOptions() {
   RequestRefresh(GetGRIBCanvas());
 }
 
+void GRIBUICtrlBar::OnFormatRefreshTimer(wxTimerEvent &event) {
+  // Check if time format has changed by comparing current format with saved
+  // format
+  wxDateTime referenceDate(1, wxDateTime::Jan, 2021, 12, 0, 0);
+  wxString currentFormat = toUsrDateTimeFormat_Plugin(referenceDate);
+
+  if (currentFormat != m_sLastTimeFormat) {
+    // Time format has changed, update all time displays
+    m_sLastTimeFormat = currentFormat;
+
+    if (m_bGRIBActiveFile && m_bGRIBActiveFile->IsOK()) {
+      // Refresh the time format in the dropdown list
+      PopulateComboDataList();
+
+      // Update the timeline display
+      TimelineChanged();
+
+      // Request a refresh to update any on-screen displays
+      RequestRefresh(GetGRIBCanvas());
+    }
+  }
+}
+
 //----------------------------------------------------------------------------------------------------------
 //          GRIBFile Object Implementation
 //----------------------------------------------------------------------------------------------------------
@@ -2020,7 +2006,7 @@ GRIBFile::GRIBFile(const wxArrayString &file_names, bool CumRec, bool WaveRec,
                    bool newestFile)
     : m_counter(++ID) {
   m_bOK = false;  // Assume ok until proven otherwise
-  m_pGribReader = NULL;
+  m_pGribReader = nullptr;
   m_last_message = wxEmptyString;
   for (unsigned int i = 0; i < file_names.GetCount(); i++) {
     wxString file_name = file_names[i];
@@ -2430,7 +2416,7 @@ void GRIBUICData::OnMove(wxMoveEvent &event) {
 
 bool CheckPendingJNIException() {
   if (!java_vm) {
-    // qDebug() << "java_vm is NULL.";
+    // qDebug() << "java_vm is nullptr.";
     return true;
   }
 
@@ -2450,7 +2436,7 @@ bool CheckPendingJNIException() {
 
 wxString callActivityMethod_ss(const char *method, wxString parm) {
   if (!java_vm) {
-    // qDebug() << "java_vm is NULL.";
+    // qDebug() << "java_vm is nullptr.";
     return _T("NOK");
   }
 
@@ -2489,7 +2475,7 @@ wxString callActivityMethod_ss(const char *method, wxString parm) {
   jstring s = data.object<jstring>();
 
   if ((jenv)->GetStringLength(s)) {
-    const char *ret_string = (jenv)->GetStringUTFChars(s, NULL);
+    const char *ret_string = (jenv)->GetStringUTFChars(s, nullptr);
     return_string = wxString(ret_string, wxConvUTF8);
   }
 
